@@ -1,5 +1,6 @@
 import argparse
 import asyncio
+import contextlib
 import functools
 import logging
 import logging.config
@@ -25,17 +26,14 @@ if __file__.endswith((".pyc", ".pyo")):
     __file__ = __file__[:-1]
 
 if __name__ == "__main__" and __package__ is None or __package__ == "":
-
     file = Path(__file__).resolve()
     parent, top = file.parent, file.parents[2]
 
     if str(top) not in sys.path:
         sys.path.append(str(top))
 
-    try:
+    with contextlib.suppress(ValueError):
         sys.path.remove(str(parent))
-    except ValueError:  # Already removed
-        pass
 
     __package__ = "robotcode.debugger"
 
@@ -109,13 +107,12 @@ async def start_debugpy_async(
 
     port = find_free_port(debugpy_port)
     if port != debugpy_port:
-        _logger.warning(f"start debugpy session on port {port}")
+        _logger.warning(lambda: f"start debugpy session on port {port}")
 
     if enable_debugpy(port, addresses):
         global config_done_callback
 
         def connect_debugpy(server: "DebugAdapterServer") -> None:
-
             server.protocol.send_event(Event(event="debugpyStarted", body={"port": port, "addresses": addresses}))
 
             if wait_for_debugpy_client:
@@ -207,7 +204,6 @@ async def run_robot(
 
         exit_code = -1
         try:
-
             exit_code = robot.run_cli(args, False)
         finally:
             if server.protocol.connected:
@@ -348,7 +344,7 @@ def main() -> None:
     split_index = sys_args.index("--") if "--" in sys_args else -1
 
     my_args = sys_args[:split_index] if split_index >= 0 else sys_args
-    robot_args = sys_args[split_index + 1 :] if split_index >= 0 else []  # noqa: E203
+    robot_args = sys_args[split_index + 1 :] if split_index >= 0 else []
 
     args = parser.parse_args(my_args)
 
@@ -396,8 +392,8 @@ def main() -> None:
                 logging.getLogger("robotcode.jsonrpc2").propagate = True
                 logging.getLogger("robotcode.jsonrpc2").setLevel(logging.CRITICAL)
 
-    _logger.info(f"starting {__package__} version={__version__}")
-    _logger.debug(f"args={args}")
+    _logger.info(lambda: f"starting {__package__} version={__version__}")
+    _logger.debug(lambda: f"args={args}")
 
     asyncio.run(
         run_robot(
