@@ -12,9 +12,10 @@ from pathlib import Path, PurePath
 from typing import (
     Any,
     Callable,
+    ClassVar,
     Deque,
     Dict,
-    Generator,
+    Iterator,
     List,
     Literal,
     NamedTuple,
@@ -114,7 +115,7 @@ class StackTraceResult(NamedTuple):
     total_frames: int
 
 
-class InvalidThreadId(Exception):
+class InvalidThreadIdError(Exception):
     def __init__(self, thread_id: Any) -> None:
         super().__init__(f"Invalid thread id {thread_id}")
 
@@ -158,7 +159,7 @@ class StackFrameEntry:
     def __repr__(self) -> str:
         return (
             f"StackFrameEntry({repr(self.name)}, {repr(self.type)}, "
-            + f"{repr(self.source)}, {repr(self.line)}, {repr(self.column)})"
+            f"{repr(self.source)}, {repr(self.line)}, {repr(self.column)})"
         )
 
     def get_first_or_self(self) -> StackFrameEntry:
@@ -195,9 +196,9 @@ class PathMapping(NamedTuple):
 
 
 class Debugger:
-    __instance = None
-    __lock = threading.RLock()
-    __inside_instance = False
+    __instance: ClassVar[Optional[Debugger]] = None
+    __lock: ClassVar = threading.RLock()
+    __inside_instance: ClassVar = False
 
     _logger = LoggingDescriptor()
 
@@ -289,21 +290,17 @@ class Debugger:
     def robot_output_file(self, value: Optional[str]) -> None:
         self._robot_output_file = value
 
-    @_logger.call
     def terminate_requested(self) -> None:
         self.terminated_requested = True
 
-    @_logger.call
     def terminate(self) -> None:
         self.terminated = True
 
-    @_logger.call
     def start(self) -> None:
         with self.condition:
             self.state = State.Running
             self.condition.notify_all()
 
-    @_logger.call
     def stop(self) -> None:
         with self.condition:
             self.state = State.Stopped
@@ -318,15 +315,13 @@ class Debugger:
 
             self.condition.notify_all()
 
-    @_logger.call
     def continue_all(self, send_event: bool = True) -> None:
         if self.main_thread is not None and self.main_thread.ident is not None:
             self.continue_thread(self.main_thread.ident, send_event)
 
-    @_logger.call
     def continue_thread(self, thread_id: int, send_event: bool = False) -> None:
         if self.main_thread is None or thread_id != self.main_thread.ident:
-            raise InvalidThreadId(thread_id)
+            raise InvalidThreadIdError(thread_id)
 
         with self.condition:
             if send_event:
@@ -339,10 +334,9 @@ class Debugger:
             self.state = State.Running
             self.condition.notify_all()
 
-    @_logger.call
     def pause_thread(self, thread_id: int) -> None:
         if self.main_thread is None or thread_id != self.main_thread.ident:
-            raise InvalidThreadId(thread_id)
+            raise InvalidThreadIdError(thread_id)
 
         with self.condition:
             self.requested_state = RequestedState.Pause
@@ -350,10 +344,9 @@ class Debugger:
 
             self.condition.notify_all()
 
-    @_logger.call
     def next(self, thread_id: int, granularity: Optional[SteppingGranularity] = None) -> None:
         if self.main_thread is None or thread_id != self.main_thread.ident:
-            raise InvalidThreadId(thread_id)
+            raise InvalidThreadIdError(thread_id)
 
         with self.condition:
             self.state = State.Running
@@ -380,12 +373,11 @@ class Debugger:
 
             self.condition.notify_all()
 
-    @_logger.call
     def step_in(
         self, thread_id: int, target_id: Optional[int] = None, granularity: Optional[SteppingGranularity] = None
     ) -> None:
         if self.main_thread is None or thread_id != self.main_thread.ident:
-            raise InvalidThreadId(thread_id)
+            raise InvalidThreadIdError(thread_id)
 
         with self.condition:
             self.requested_state = RequestedState.StepIn
@@ -393,10 +385,9 @@ class Debugger:
 
             self.condition.notify_all()
 
-    @_logger.call
     def step_out(self, thread_id: int, granularity: Optional[SteppingGranularity] = None) -> None:
         if self.main_thread is None or thread_id != self.main_thread.ident:
-            raise InvalidThreadId(thread_id)
+            raise InvalidThreadIdError(thread_id)
 
         with self.condition:
             self.requested_state = RequestedState.StepOut
@@ -433,7 +424,6 @@ class Debugger:
         lines: Optional[List[int]] = None,
         source_modified: Optional[bool] = None,
     ) -> List[Breakpoint]:
-
         if self.is_windows_path(source.path or ""):
             path: pathlib.PurePath = pathlib.PureWindowsPath(source.path or "")
         else:
@@ -449,8 +439,8 @@ class Debugger:
                 Breakpoint(id=id(v), source=Source(path=str(path)), verified=True, line=v.line)
                 for v in result.breakpoints
             ]
-        else:
-            self._logger.error("not supported breakpoint")
+
+        self._logger.error("not supported breakpoint")
 
         return []
 
@@ -461,7 +451,7 @@ class Debugger:
         if self.state == State.Stopped:
             return
 
-        elif self.requested_state == RequestedState.Pause:
+        if self.requested_state == RequestedState.Pause:
             self.state = State.Paused
             self.send_event(
                 self,
@@ -498,19 +488,18 @@ class Debugger:
                 ),
             )
             self.requested_state = RequestedState.Nothing
-        elif self.requested_state == RequestedState.StepOut:
-            if len(self.full_stack_frames) <= self.stop_stack_len:
-                self.state = State.Paused
-                self.send_event(
-                    self,
-                    StoppedEvent(
-                        body=StoppedEventBody(
-                            reason=StoppedReason.STEP,
-                            thread_id=threading.current_thread().ident,
-                        )
-                    ),
-                )
-                self.requested_state = RequestedState.Nothing
+        elif self.requested_state == RequestedState.StepOut and len(self.full_stack_frames) <= self.stop_stack_len:
+            self.state = State.Paused
+            self.send_event(
+                self,
+                StoppedEvent(
+                    body=StoppedEventBody(
+                        reason=StoppedReason.STEP,
+                        thread_id=threading.current_thread().ident,
+                    )
+                ),
+            )
+            self.requested_state = RequestedState.Nothing
 
         if source is not None:
             source_path = self.map_path_to_client(str(Path(source).absolute()))
@@ -564,18 +553,18 @@ class Debugger:
                                 ),
                             )
                             return
-                        else:
-                            self.state = State.Paused
-                            self.send_event(
-                                self,
-                                StoppedEvent(
-                                    body=StoppedEventBody(
-                                        reason=StoppedReason.BREAKPOINT,
-                                        thread_id=threading.current_thread().ident,
-                                        hit_breakpoint_ids=[id(v) for v in breakpoints],
-                                    )
-                                ),
-                            )
+
+                        self.state = State.Paused
+                        self.send_event(
+                            self,
+                            StoppedEvent(
+                                body=StoppedEventBody(
+                                    reason=StoppedReason.BREAKPOINT,
+                                    thread_id=threading.current_thread().ident,
+                                    hit_breakpoint_ids=[id(v) for v in breakpoints],
+                                )
+                            ),
+                        )
 
     def process_end_state(self, status: str, filter_id: Set[str], description: str, text: Optional[str]) -> None:
         if (
@@ -603,7 +592,6 @@ class Debugger:
             )
             self.wait_for_running()
 
-    @_logger.call
     def wait_for_running(self) -> None:
         if self.attached:
             while True:
@@ -646,7 +634,7 @@ class Debugger:
                 ),
             )
 
-    def end_output_group(self, name: str, attributes: Dict[str, Any]) -> None:
+    def end_output_group(self, name: str, attributes: Dict[str, Any], type: Optional[str] = None) -> None:
         if self.group_output:
             source = attributes.get("source", None)
             line_no = attributes.get("lineno", None)
@@ -862,7 +850,7 @@ class Debugger:
 
             self.wait_for_running()
 
-    CAUGHTED_KEYWORDS = [
+    CAUGHTED_KEYWORDS: ClassVar = [
         "BuiltIn.Run Keyword And Expect Error",
         "BuiltIn.Run Keyword And Ignore Error",
         "BuiltIn.Run Keyword And Warn On Failure",
@@ -920,7 +908,7 @@ class Debugger:
 
         return [Thread(id=main_thread.ident if main_thread.ident else 0, name=main_thread.name or "")]
 
-    WINDOW_PATH_REGEX = re.compile(r"^(([a-z]:[\\/])|(\\\\)).*$", re.RegexFlag.IGNORECASE)
+    WINDOW_PATH_REGEX: ClassVar = re.compile(r"^(([a-z]:[\\/])|(\\\\)).*$", re.RegexFlag.IGNORECASE)
 
     @classmethod
     def is_windows_path(cls, path: Union[os.PathLike[str], str]) -> bool:
@@ -941,7 +929,6 @@ class Debugger:
             return path
 
         for mapping in self.path_mappings:
-
             remote_root_path = Path(mapping.remote_root or ".").absolute()
 
             if (
@@ -950,8 +937,8 @@ class Debugger:
             ):
                 if self.is_windows_path(mapping.local_root):
                     return pathlib.PureWindowsPath(mapping.local_root, relative_path)
-                else:
-                    return pathlib.PurePath(mapping.local_root, relative_path)
+
+                return pathlib.PurePath(mapping.local_root, relative_path)
 
         return path
 
@@ -963,7 +950,7 @@ class Debugger:
         format: Optional[StackFrameFormat] = None,
     ) -> StackTraceResult:
         if self.main_thread is None or thread_id != self.main_thread.ident:
-            raise InvalidThreadId(thread_id)
+            raise InvalidThreadIdError(thread_id)
 
         start_frame = start_frame or 0
         levels = start_frame + (levels or len(self.stack_frames))
@@ -971,10 +958,10 @@ class Debugger:
         def source_from_entry(entry: StackFrameEntry) -> Optional[Source]:
             if entry.source is not None and entry.is_file:
                 return Source(path=str(self.map_path_to_client(entry.source)))
-            else:
-                return None
 
-        def yield_stack() -> Generator[StackFrame, None, None]:
+            return None
+
+        def yield_stack() -> Iterator[StackFrame]:
             for i, v in enumerate(itertools.islice(self.stack_frames, start_frame, levels)):
                 if v.stack_frames:
                     yield StackFrame(
@@ -1001,7 +988,7 @@ class Debugger:
 
         return StackTraceResult(frames, len(self.stack_frames))
 
-    MESSAGE_COLORS = {
+    MESSAGE_COLORS: ClassVar = {
         "INFO": "\u001b[38;5;2m",
         "WARN": "\u001b[38;5;3m",
         "ERROR": "\u001b[38;5;1m",
@@ -1190,10 +1177,10 @@ class Debugger:
 
         return list(result.values())
 
-    IS_VARIABLE_RE = re.compile(r"^[$@&%]\{.*\}(\[[^\]]*\])?$")
-    IS_VARIABLE_ASSIGNMENT_RE = re.compile(r"^[$@&%]\{.*\}=?$")
-    SPLIT_LINE = re.compile(r"(?= {2,}| ?\t)\s*")
-    CURRDIR = re.compile(r"(?i)\$\{CURDIR\}")
+    IS_VARIABLE_RE: ClassVar = re.compile(r"^[$@&%]\{.*\}(\[[^\]]*\])?$")
+    IS_VARIABLE_ASSIGNMENT_RE: ClassVar = re.compile(r"^[$@&%]\{.*\}=?$")
+    SPLIT_LINE: ClassVar = re.compile(r"(?= {2,}| ?\t)\s*")
+    CURRDIR: ClassVar = re.compile(r"(?i)\$\{CURDIR\}")
 
     def evaluate(
         self,
