@@ -75,7 +75,6 @@ TResult = TypeVar("TResult", bound=Any)
 
 
 class DebugAdapterProtocol(JsonRPCProtocolBase):
-
     _logger = LoggingDescriptor()
 
     def __init__(self) -> None:
@@ -123,7 +122,7 @@ class DebugAdapterProtocol(JsonRPCProtocolBase):
         def inner(d: Dict[Any, Any]) -> ProtocolMessage:
             result = from_dict(d, (Request, Response, Event))
             if isinstance(result, Response) and not result.success:
-                result = from_dict(d, ErrorResponse)
+                return from_dict(d, ErrorResponse)
             return result
 
         if isinstance(data, list):
@@ -174,8 +173,8 @@ class DebugAdapterProtocol(JsonRPCProtocolBase):
         if param_type is None:
             if isinstance(params, Mapping):
                 return [], dict(**params)
-            else:
-                return [params], {}
+
+            return [params], {}
 
         converted_params = from_dict(params, param_type)
 
@@ -248,7 +247,7 @@ class DebugAdapterProtocol(JsonRPCProtocolBase):
             try:
                 self.send_response(message.seq, message.command, t.result())
             except asyncio.CancelledError:
-                self._logger.debug(f"request message {repr(message)} canceled")
+                self._logger.debug(lambda: f"request message {repr(message)} canceled")
             except (SystemExit, KeyboardInterrupt):
                 raise
             except DebugAdapterRPCErrorException as ex:
@@ -301,7 +300,6 @@ class DebugAdapterProtocol(JsonRPCProtocolBase):
         request: Request,
         return_type: Optional[Type[TResult]] = None,
     ) -> asyncio.Future[TResult]:
-
         result: asyncio.Future[TResult] = asyncio.get_event_loop().create_future()
 
         with self._sended_request_lock:
@@ -362,4 +360,4 @@ class DebugAdapterProtocol(JsonRPCProtocolBase):
 
     @_logger.call
     def handle_event(self, message: Event) -> None:
-        raise NotImplementedError()
+        raise NotImplementedError
