@@ -9,11 +9,13 @@ import time
 import weakref
 from abc import ABC, abstractmethod
 from collections import OrderedDict
-from dataclasses import dataclass, field
+from dataclasses import dataclass, field, fields, is_dataclass
 from typing import (
     Any,
     Callable,
+    ClassVar,
     Dict,
+    Final,
     Generic,
     Iterator,
     List,
@@ -68,15 +70,15 @@ _TResult = TypeVar("_TResult", bound=Any)
 
 
 class JsonRPCErrors:
-    PARSE_ERROR = -32700
-    INVALID_REQUEST = -32600
-    METHOD_NOT_FOUND = -32601
-    INVALID_PARAMS = -32602
-    INTERNAL_ERROR = -32603
-    SERVER_ERROR_START = -32000
-    SERVER_ERROR_END = -32099
+    PARSE_ERROR: Final = -32700
+    INVALID_REQUEST: Final = -32600
+    METHOD_NOT_FOUND: Final = -32601
+    INVALID_PARAMS: Final = -32602
+    INTERNAL_ERROR: Final = -32603
+    SERVER_ERROR_START: Final = -32000
+    SERVER_ERROR_END: Final = -32099
 
-    REQUEST_CANCELLED = -32800
+    REQUEST_CANCELLED: Final = -32800
 
 
 PROTOCOL_VERSION = "2.0"
@@ -123,7 +125,7 @@ class JsonRPCError(_JsonRPCResponseBase):
     result: Optional[Any] = None
 
 
-class JsonRPCException(Exception):
+class JsonRPCException(Exception):  # noqa: N818
     pass
 
 
@@ -178,14 +180,13 @@ def rpc_method(
     cancelable: bool = True,
 ) -> Callable[[_F], _F]:
     def _decorator(func: _F) -> Callable[[_F], _F]:
-
         if inspect.isclass(_func):
             raise TypeError(f"Not supported type {type(func)}.")
 
         if isinstance(func, classmethod):
-            f = func.__func__
+            f = func.__func__  # type: ignore
         elif isinstance(func, staticmethod):
-            f = func.__func__
+            f = func.__func__  # type: ignore
         else:
             f = func
 
@@ -207,7 +208,7 @@ class HasRpcRegistry(Protocol):
 
 
 class RpcRegistry:
-    _class_registries: Dict[Type[Any], RpcRegistry] = {}
+    class_registries: ClassVar[Dict[Type[Any], RpcRegistry]] = {}
 
     def __init__(self, owner: Any = None) -> None:
         self.__owner = owner
@@ -229,10 +230,10 @@ class RpcRegistry:
 
             return cast(HasRpcRegistry, obj).__rpc_registry__
 
-        if obj_type not in RpcRegistry._class_registries:
-            RpcRegistry._class_registries[obj_type] = RpcRegistry(obj_type)
+        if obj_type not in RpcRegistry.class_registries:
+            RpcRegistry.class_registries[obj_type] = RpcRegistry(obj_type)
 
-        return RpcRegistry._class_registries[obj_type]
+        return RpcRegistry.class_registries[obj_type]
 
     def _reset(self) -> None:
         self.__methods.clear()
@@ -268,7 +269,6 @@ class RpcRegistry:
             }
 
         if not self.__initialized:
-
             if inspect.isclass(self.__owner):
                 self.__methods = get_methods(self.__owner)
 
@@ -277,11 +277,11 @@ class RpcRegistry:
             else:
                 registries: List[RpcRegistry] = []
                 for m in inspect.getmro(type(self.__owner)):
-                    r = self._class_registries.get(m, None)
+                    r = RpcRegistry.class_registries.get(m, None)
                     if r is not None:
                         registries.insert(0, r)
                 for r in registries:
-                    for k in r.__class_parts.keys():
+                    for k in r.__class_parts:
                         getattr(self.__owner, k)
 
                 self.__methods = get_methods(self.__owner)
@@ -340,9 +340,7 @@ class ReceivedRequestEntry(NamedTuple):
 
 
 class JsonRPCProtocolBase(asyncio.Protocol, ABC):
-
-    _logger = LoggingDescriptor()
-    registry = RpcRegistry()
+    registry: ClassVar = RpcRegistry()
 
     def __init__(self) -> None:
         self.read_transport: Optional[asyncio.ReadTransport] = None
@@ -362,7 +360,6 @@ class JsonRPCProtocolBase(asyncio.Protocol, ABC):
     async def on_connection_lost(sender, exc: Optional[BaseException]) -> None:
         ...
 
-    @_logger.call
     def connection_made(self, transport: asyncio.BaseTransport) -> None:
         super().connection_made(transport)
         self._loop = asyncio.get_running_loop()
@@ -373,24 +370,22 @@ class JsonRPCProtocolBase(asyncio.Protocol, ABC):
 
         create_sub_task(self.on_connection_made(self, transport))
 
-    @_logger.call
     def connection_lost(self, exc: Optional[BaseException]) -> None:
         create_sub_task(self.on_connection_lost(self, exc))
         self._loop = None
 
-    @_logger.call
     def eof_received(self) -> Optional[bool]:
         return False
 
-    CHARSET = "utf-8"
-    CONTENT_TYPE = "application/vscode-jsonrpc"
+    CHARSET: Final = "utf-8"
+    CONTENT_TYPE: Final = "application/vscode-jsonrpc"
 
-    MESSAGE_PATTERN = re.compile(
+    MESSAGE_PATTERN: Final = re.compile(
         rb"(?:[^\r\n]*\r\n)*"
-        + rb"(Content-Length: ?(?P<length>\d+)\r\n)"
-        + rb"((Content-Type: ?(?P<content_type>[^\r\n;]+)"
-        + rb"(; *(charset=(?P<charset>[^\r\n]+))?)?\r\n)|(?:[^\r\n]+\r\n))*"
-        + rb"\r\n(?P<body>.*)",
+        rb"(Content-Length: ?(?P<length>\d+)\r\n)"
+        rb"((Content-Type: ?(?P<content_type>[^\r\n;]+)"
+        rb"(; *(charset=(?P<charset>[^\r\n]+))?)?\r\n)|(?:[^\r\n]+\r\n))*"
+        rb"\r\n(?P<body>.*)",
         re.DOTALL,
     )
 
@@ -423,7 +418,7 @@ class JsonRPCProtocolBase(asyncio.Protocol, ABC):
 
 
 class JsonRPCProtocol(JsonRPCProtocolBase):
-    _logger = LoggingDescriptor()
+    __logger = LoggingDescriptor()
     _data_logger = LoggingDescriptor(postfix="_data")
 
     def __init__(self) -> None:
@@ -472,7 +467,7 @@ class JsonRPCProtocol(JsonRPCProtocolBase):
         except (asyncio.CancelledError, SystemExit, KeyboardInterrupt):
             raise
         except BaseException as e:
-            self._logger.exception(e)
+            self.__logger.exception(e)
             self.send_error(JsonRPCErrors.PARSE_ERROR, f"{type(e).__name__}: {e}")
 
     def _handle_messages(self, iterator: Iterator[JsonRPCMessage]) -> None:
@@ -486,7 +481,7 @@ class JsonRPCProtocol(JsonRPCProtocolBase):
         for m in iterator:
             create_sub_task(self.handle_message(m)).add_done_callback(done)
 
-    @_logger.call
+    @__logger.call
     async def handle_message(self, message: JsonRPCMessage) -> None:
         if isinstance(message, JsonRPCRequest):
             await self.handle_request(message)
@@ -497,11 +492,11 @@ class JsonRPCProtocol(JsonRPCProtocolBase):
         elif isinstance(message, JsonRPCResponse):
             await self.handle_response(message)
 
-    @_logger.call
+    @__logger.call
     def send_response(self, id: Optional[Union[str, int, None]], result: Optional[Any] = None) -> None:
         self.send_message(JsonRPCResponse(id=id, result=result))
 
-    @_logger.call
+    @__logger.call
     def send_error(
         self,
         code: int,
@@ -520,7 +515,7 @@ class JsonRPCProtocol(JsonRPCProtocolBase):
             )
         )
 
-    @_logger.call
+    @__logger.call
     def send_message(self, message: JsonRPCMessage) -> None:
         message.jsonrpc = PROTOCOL_VERSION
 
@@ -538,14 +533,13 @@ class JsonRPCProtocol(JsonRPCProtocolBase):
             if self._loop:
                 self._loop.call_soon_threadsafe(self.write_transport.write, msg)
 
-    @_logger.call
+    @__logger.call
     def send_request(
         self,
         method: str,
         params: Optional[Any] = None,
         return_type_or_converter: Optional[Type[_TResult]] = None,
     ) -> asyncio.Future[Optional[_TResult]]:
-
         with self._sended_request_lock:
             result: asyncio.Future[Optional[_TResult]] = create_sub_future()
             self._sended_request_count += 1
@@ -564,18 +558,17 @@ class JsonRPCProtocol(JsonRPCProtocolBase):
         params: Optional[Any] = None,
         return_type: Optional[Type[_TResult]] = None,
     ) -> Optional[_TResult]:
-
         return await self.send_request(method, params, return_type)
 
-    @_logger.call
+    @__logger.call
     def send_notification(self, method: str, params: Any) -> None:
         self.send_message(JsonRPCNotification(method=method, params=params))
 
-    @_logger.call(exception=True)
+    @__logger.call(exception=True)
     async def handle_response(self, message: JsonRPCResponse) -> None:
         if message.id is None:
             error = "Invalid response. Response id is null."
-            self._logger.warning(error)
+            self.__logger.warning(error)
             self.send_error(JsonRPCErrors.INTERNAL_ERROR, error)
             return
 
@@ -584,7 +577,7 @@ class JsonRPCProtocol(JsonRPCProtocolBase):
 
         if entry is None:
             error = f"Invalid response. Could not find id '{message.id}' in request list."
-            self._logger.warning(error)
+            self.__logger.warning(error)
             self.send_error(JsonRPCErrors.INTERNAL_ERROR, error)
             return
 
@@ -611,14 +604,13 @@ class JsonRPCProtocol(JsonRPCProtocolBase):
 
                         start = time.monotonic()
                         while not done.is_set():
-
                             if time.monotonic() - start > 120:
                                 raise TimeoutError("Can't set future result.")
 
                             await asyncio.sleep(0)
 
                     else:
-                        self._logger.warning(f"Response {repr(entry)} loop is not running.")
+                        self.__logger.warning(lambda: f"Response {repr(entry)} loop is not running.")
 
         except (SystemExit, KeyboardInterrupt):
             raise
@@ -630,7 +622,7 @@ class JsonRPCProtocol(JsonRPCProtocolBase):
                     if entry.future.get_loop().is_running():
                         entry.future.get_loop().call_soon_threadsafe(entry.future.set_exception, e)
 
-    @_logger.call
+    @__logger.call
     async def handle_error(self, message: JsonRPCError) -> None:
         raise JsonRPCErrorException(message.error.code, message.error.message, message.error.data)
 
@@ -643,8 +635,8 @@ class JsonRPCProtocol(JsonRPCProtocolBase):
         if params_type is None:
             if isinstance(params, Mapping):
                 return [], dict(**params)
-            else:
-                return [params], {}
+
+            return [params], {}
 
         # try to convert the dict to correct type
         converted_params = from_dict(params, params_type)
@@ -656,16 +648,24 @@ class JsonRPCProtocol(JsonRPCProtocolBase):
         kw_args = {}
         args = []
         params_added = False
-        rest = set(converted_params.__dict__.keys())
+
+        field_names = (
+            [f.name for f in fields(converted_params)]
+            if is_dataclass(converted_params)
+            else list(converted_params.__dict__.keys())
+        )
+
+        rest = set(field_names)
         if isinstance(params, dict):
             rest = set.union(rest, params.keys())
 
         for v in signature.parameters.values():
-            if v.name in converted_params.__dict__:
+            if v.name in field_names:
                 if v.kind == inspect.Parameter.POSITIONAL_ONLY:
                     args.append(getattr(converted_params, v.name))
                 else:
                     kw_args[v.name] = getattr(converted_params, v.name)
+
                 rest.remove(v.name)
             elif v.name == "params":
                 if v.kind == inspect.Parameter.POSITIONAL_ONLY:
@@ -690,7 +690,6 @@ class JsonRPCProtocol(JsonRPCProtocolBase):
                 kw_args["params"] = converted_params
         return args, kw_args
 
-    @_logger.call
     async def handle_request(self, message: JsonRPCRequest) -> None:
         e = self.registry.get_entry(message.method)
 
@@ -700,12 +699,14 @@ class JsonRPCProtocol(JsonRPCProtocolBase):
                 f"Unknown method: {message.method}",
                 id=message.id,
             )
-            return None
+            return
 
         params = self._convert_params(e.method, e.param_type, message.params)
 
-        if isinstance(e.method, HasThreaded) and cast(HasThreaded, e.method).__threaded__:
-            task = run_coroutine_in_thread(ensure_coroutine(e.method), *params[0], **params[1])
+        if isinstance(e.method, HasThreaded) and e.method.__threaded__:
+            task = run_coroutine_in_thread(
+                ensure_coroutine(cast(Callable[..., Any], e.method)), *params[0], **params[1]
+            )
         else:
             task = create_sub_task(
                 ensure_coroutine(e.method)(*params[0], **params[1]),
@@ -715,24 +716,24 @@ class JsonRPCProtocol(JsonRPCProtocolBase):
         with self._received_request_lock:
             self._received_request[message.id] = ReceivedRequestEntry(task, message, e.cancelable)
 
-        def done(t: asyncio.Task[Any]) -> None:
+        def done(t: asyncio.Future[Any]) -> None:
             try:
                 if not t.cancelled():
                     ex = t.exception()
                     if ex is not None:
-                        self._logger.exception(ex, exc_info=ex)
+                        self.__logger.exception(ex, exc_info=ex)
                         raise JsonRPCErrorException(JsonRPCErrors.INTERNAL_ERROR, f"{type(ex).__name__}: {ex}") from ex
 
                 self.send_response(message.id, t.result())
             except asyncio.CancelledError:
-                self._logger.debug(f"request message {repr(message)} canceled")
+                self.__logger.debug(lambda: f"request message {repr(message)} canceled")
                 self.send_error(JsonRPCErrors.REQUEST_CANCELLED, "Request canceled.", id=message.id)
             except (SystemExit, KeyboardInterrupt):
                 raise
             except JsonRPCErrorException as e:
                 self.send_error(e.code, e.message or f"{type(e).__name__}: {e}", id=message.id, data=e.data)
             except BaseException as e:
-                self._logger.exception(e)
+                self.__logger.exception(e)
                 self.send_error(JsonRPCErrors.INTERNAL_ERROR, f"{type(e).__name__}: {e}", id=message.id)
             finally:
                 with self._received_request_lock:
@@ -742,33 +743,35 @@ class JsonRPCProtocol(JsonRPCProtocolBase):
 
         await task
 
-    @_logger.call
+    @__logger.call
     def cancel_request(self, id: Union[int, str, None]) -> None:
         with self._received_request_lock:
             entry = self._received_request.get(id, None)
 
         if entry is not None and entry.future is not None and not entry.future.cancelled():
-            self._logger.debug(f"try to cancel request {entry.request}")
+            self.__logger.debug(lambda: f"try to cancel request {entry.request if entry is not None else ''}")
             entry.future.cancel()
 
-    @_logger.call
+    @__logger.call
     async def cancel_all_received_request(self) -> None:
         for entry in self._received_request.values():
             if entry is not None and entry.cancelable and entry.future is not None and not entry.future.cancelled():
                 entry.future.cancel()
 
-    @_logger.call
+    @__logger.call
     async def handle_notification(self, message: JsonRPCNotification) -> None:
         e = self.registry.get_entry(message.method)
 
         if e is None or not callable(e.method):
-            self._logger.warning(f"Unknown method: {message.method}")
+            self.__logger.warning(lambda: f"Unknown method: {message.method}")
             return
         try:
             params = self._convert_params(e.method, e.param_type, message.params)
 
-            if isinstance(e.method, HasThreaded) and cast(HasThreaded, e.method).__threaded__:
-                task = run_coroutine_in_thread(ensure_coroutine(e.method), *params[0], **params[1])
+            if isinstance(e.method, HasThreaded) and e.method.__threaded__:
+                task = run_coroutine_in_thread(
+                    ensure_coroutine(cast(Callable[..., Any], e.method)), *params[0], **params[1]
+                )
             else:
                 task = create_sub_task(
                     ensure_coroutine(e.method)(*params[0], **params[1]),
@@ -781,7 +784,7 @@ class JsonRPCProtocol(JsonRPCProtocolBase):
         except (SystemExit, KeyboardInterrupt):
             raise
         except BaseException as e:
-            self._logger.exception(e)
+            self.__logger.exception(e)
 
 
 TProtocol = TypeVar("TProtocol", bound=JsonRPCProtocol)
@@ -820,7 +823,7 @@ class ProtocolPartDescriptor(Generic[TProtocolPart]):
 
     def __set_name__(self, owner: Type[Any], name: str) -> None:
         if not issubclass(owner, JsonRPCProtocol):
-            raise AttributeError()
+            raise TypeError
         owner.registry.add_class_part(name, self._instance_type)
 
     def __get__(self, obj: Optional[Any], objtype: Type[Any]) -> TProtocolPart:
