@@ -4,7 +4,7 @@ import inspect
 import typing
 import uuid
 from dataclasses import dataclass
-from typing import TYPE_CHECKING, Any, Awaitable, Callable, Dict, List, Optional, cast
+from typing import TYPE_CHECKING, Any, Awaitable, Callable, Dict, Final, List, Optional, cast
 
 from ....jsonrpc2.protocol import JsonRPCErrorException, rpc_method
 from ....utils.async_tools import threaded
@@ -35,10 +35,9 @@ class CommandEntry:
 
 
 class CommandsProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities):
+    _logger: Final = LoggingDescriptor()
 
-    _logger = LoggingDescriptor()
-
-    PREFIX = f"{uuid.uuid4()}"
+    PREFIX: Final = f"{uuid.uuid4()}"
 
     def __init__(self, parent: LanguageServerProtocol) -> None:
         super().__init__(parent)
@@ -50,7 +49,7 @@ class CommandsProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities):
         command = f"{self.PREFIX}.{name}"
 
         if command in self.commands:
-            self._logger.critical(f"command '{command}' already registered.")
+            self._logger.critical(lambda: f"command '{command}' already registered.")
         else:
             self.commands[command] = CommandEntry(name, callback)
 
@@ -70,7 +69,6 @@ class CommandsProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities):
         return f"{self.PREFIX}.{name}"
 
     def extend_capabilities(self, capabilities: ServerCapabilities) -> None:
-
         capabilities.execute_command_provider = ExecuteCommandOptions(list(self.commands.keys()))
 
     @rpc_method(name="workspace/executeCommand", param_type=ExecuteCommandParams)
@@ -78,7 +76,7 @@ class CommandsProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities):
     async def _workspace_execute_command(
         self, command: str, arguments: Optional[List[LSPAny]], *args: Any, **kwargs: Any
     ) -> Optional[LSPAny]:
-        self._logger.debug(f"execute command {command}")
+        self._logger.debug(lambda: f"execute command {command}")
 
         entry = self.commands.get(command, None)
         if entry is None or entry.callback is None:
@@ -91,7 +89,6 @@ class CommandsProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities):
 
         if arguments:
             for i, v in enumerate(signature.parameters.values()):
-
                 if i < len(arguments):
                     command_args.append(from_dict(arguments[i], type_hints[i]))
 
