@@ -2,7 +2,7 @@ from __future__ import annotations
 
 from asyncio import CancelledError
 from itertools import chain
-from typing import TYPE_CHECKING, Any, List, Optional, Union, cast
+from typing import TYPE_CHECKING, Any, Final, List, Optional, Union, cast
 
 from ....jsonrpc2.protocol import rpc_method
 from ....utils.async_tools import async_tasking_event, threaded
@@ -32,8 +32,7 @@ from .protocol_part import LanguageServerProtocolPart
 
 
 class CompletionProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities):
-
-    _logger = LoggingDescriptor()
+    _logger: Final = LoggingDescriptor()
 
     def __init__(self, parent: LanguageServerProtocol) -> None:
         super().__init__(parent)
@@ -50,27 +49,25 @@ class CompletionProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities):
 
     def extend_capabilities(self, capabilities: ServerCapabilities) -> None:
         if len(self.collect):
-            trigger_chars = [
-                k
-                for k in chain(
+            trigger_chars = list(
+                chain(
                     *[
                         cast(HasTriggerCharacters, e).__trigger_characters__
                         for e in self.collect
                         if isinstance(e, HasTriggerCharacters)
                     ]
                 )
-            ]
+            )
 
-            commit_chars = [
-                k
-                for k in chain(
+            commit_chars = list(
+                chain(
                     *[
                         cast(HasAllCommitCharacters, e).__all_commit_characters__
                         for e in self.collect
                         if isinstance(e, HasAllCommitCharacters)
                     ]
                 )
-            ]
+            )
             capabilities.completion_provider = CompletionOptions(
                 trigger_characters=trigger_chars if trigger_chars else None,
                 all_commit_characters=commit_chars if commit_chars else None,
@@ -88,7 +85,6 @@ class CompletionProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities):
         *args: Any,
         **kwargs: Any,
     ) -> Union[List[CompletionItem], CompletionList, None]:
-
         results: List[Union[List[CompletionItem], CompletionList]] = []
 
         document = await self.parent.documents.get(text_document.uri)
@@ -113,17 +109,17 @@ class CompletionProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities):
             if any(e for e in results if isinstance(e, CompletionList)):
                 result = CompletionList(
                     is_incomplete=any(e for e in results if isinstance(e, CompletionList) and e.is_incomplete),
-                    items=[e for e in chain(*[r.items if isinstance(r, CompletionList) else r for r in results])],
+                    items=list(chain(*[r.items if isinstance(r, CompletionList) else r for r in results])),
                 )
                 if len(result.items) == 0:
                     return None
                 return result
-            else:
-                result = [e for e in chain(*[k for k in results if isinstance(k, list)])]
-                if len(result) == 0:
-                    return None
 
-                return result
+            result = list(chain(*[k for k in results if isinstance(k, list)]))
+            if len(result) == 0:
+                return None
+
+            return result
 
         return None
 
@@ -135,7 +131,6 @@ class CompletionProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities):
         *args: Any,
         **kwargs: Any,
     ) -> CompletionItem:
-
         results: List[CompletionItem] = []
 
         for result in await self.resolve(self, params):
