@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 from asyncio import CancelledError
-from typing import TYPE_CHECKING, Any, List, Optional, Union
+from typing import TYPE_CHECKING, Any, Final, List, Optional, Union
 
 from ....jsonrpc2.protocol import rpc_method
 from ....utils.async_tools import async_tasking_event, threaded
@@ -25,8 +25,7 @@ from .protocol_part import LanguageServerProtocolPart
 
 
 class DefinitionProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities):
-
-    _logger = LoggingDescriptor()
+    _logger: Final = LoggingDescriptor()
 
     def __init__(self, parent: LanguageServerProtocol) -> None:
         super().__init__(parent)
@@ -54,7 +53,6 @@ class DefinitionProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities):
     async def _text_document_definition(
         self, text_document: TextDocumentIdentifier, position: Position, *args: Any, **kwargs: Any
     ) -> Optional[Union[Location, List[Location], List[LocationLink]]]:
-
         locations: List[Location] = []
         location_links: List[LocationLink] = []
 
@@ -82,8 +80,8 @@ class DefinitionProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities):
         if len(locations) > 0 and len(location_links) == 0:
             if len(locations) == 1:
                 return locations[0]
-            else:
-                return locations
+
+            return locations
 
         if len(locations) > 0 and len(location_links) > 0:
             self._logger.warning("can't mix Locations and LocationLinks")
