@@ -7,7 +7,7 @@ import time
 import uuid
 from dataclasses import dataclass, field
 from enum import Enum
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, cast
+from typing import TYPE_CHECKING, Any, Dict, Final, List, Optional, cast
 
 from ....jsonrpc2.protocol import JsonRPCErrorException, rpc_method
 from ....utils.async_tools import (
@@ -30,7 +30,7 @@ from ..lsp_types import (
     DiagnosticServerCancellationData,
     DocumentDiagnosticParams,
     DocumentDiagnosticReport,
-    ErrorCodes,
+    LSPErrorCodes,
     PreviousResultId,
     ProgressToken,
     PublishDiagnosticsParams,
@@ -51,6 +51,7 @@ __all__ = ["DiagnosticsProtocolPart", "DiagnosticsResult"]
 
 
 class DiagnosticsMode(Enum):
+    OFF = "off"
     WORKSPACE = "workspace"
     OPENFILESONLY = "openFilesOnly"
 
@@ -93,7 +94,7 @@ def _cancel_all_tasks(loop: asyncio.AbstractEventLoop) -> None:
     for task in to_cancel:
         task.cancel()
 
-    loop.run_until_complete(asyncio.gather(*to_cancel, loop=loop, return_exceptions=True))
+    loop.run_until_complete(asyncio.gather(*to_cancel, return_exceptions=True))
 
     for task in to_cancel:
         if task.cancelled():
@@ -109,7 +110,7 @@ def _cancel_all_tasks(loop: asyncio.AbstractEventLoop) -> None:
 
 
 class DiagnosticsProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities):
-    _logger = LoggingDescriptor()
+    _logger: Final = LoggingDescriptor()
 
     def __init__(self, protocol: LanguageServerProtocol) -> None:
         super().__init__(protocol)
@@ -333,7 +334,7 @@ class DiagnosticsProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities)
                     await asyncio.sleep(1)
                     continue
 
-                self._logger.info(f"start collecting workspace diagnostics for {len(documents)} documents")
+                self._logger.info(lambda: f"start collecting workspace diagnostics for {len(documents)} documents")
 
                 done_something = False
 
@@ -342,6 +343,11 @@ class DiagnosticsProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities)
                     "Analyse workspace", cancellable=False, current=0, max=len(documents) + 1, start=False
                 ) as progress:
                     for i, document in enumerate(documents):
+                        mode = await self.get_diagnostics_mode(document.uri)
+                        if mode == DiagnosticsMode.OFF:
+                            self.get_diagnostics_data(document).version = document.version
+                            continue
+
                         if document.opened_in_editor:
                             continue
 
@@ -353,10 +359,7 @@ class DiagnosticsProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities)
                             progress.begin()
                             path = document.uri.to_path()
                             folder = self.parent.workspace.get_workspace_folder(document.uri)
-                            if folder is None:
-                                name = path
-                            else:
-                                name = path.relative_to(folder.uri.to_path())
+                            name = path if folder is None else path.relative_to(folder.uri.to_path())
 
                             progress.report(f"Analyse {name}", current=i + 1)
                         elif analysis_mode == AnalysisProgressMode.SIMPLE:
@@ -367,22 +370,22 @@ class DiagnosticsProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities)
                             document,
                             False,
                             False,
-                            await self.get_diagnostics_mode(document.uri) == DiagnosticsMode.WORKSPACE,
+                            mode == DiagnosticsMode.WORKSPACE,
                         )
 
                 if not done_something:
                     await asyncio.sleep(1)
 
                 self._logger.info(
-                    f"collecting workspace diagnostics for for {len(documents)} "
+                    lambda: f"collecting workspace diagnostics for for {len(documents)} "
                     f"documents takes {time.monotonic() - start}s"
                 )
-                self._logger.info(f"{len(self.parent.documents)} documents loaded")
 
             except (SystemExit, KeyboardInterrupt, asyncio.CancelledError):
                 raise
             except BaseException as e:
-                self._logger.exception(f"Error in workspace diagnostics loop: {e}", exc_info=e)
+                ex = e
+                self._logger.exception(lambda: f"Error in workspace diagnostics loop: {ex}", exc_info=e)
 
     def create_document_diagnostics_task(
         self, document: TextDocument, single: bool, debounce: bool = True, send_diagnostics: bool = True
@@ -440,7 +443,6 @@ class DiagnosticsProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities)
 
         collected_keys: List[Any] = []
         try:
-
             async for result_any in self.collect(
                 self, document, callback_filter=language_id_filter(document), return_exceptions=True
             ):
@@ -449,27 +451,28 @@ class DiagnosticsProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities)
                 if isinstance(result_any, BaseException):
                     if not isinstance(result_any, asyncio.CancelledError):
                         self._logger.exception(result_any, exc_info=result_any)
-                elif result_any is None:
                     continue
-                else:
-                    result = cast(DiagnosticsResult, result_any)
+                if result_any is None:
+                    continue
 
-                    data.id = str(uuid.uuid4())
-                    data.entries[result.key] = result.diagnostics
-                    if result.diagnostics is not None:
-                        collected_keys.append(result.key)
+                result = cast(DiagnosticsResult, result_any)
 
-                    if data.entries and send_diagnostics:
-                        self.parent.send_notification(
-                            "textDocument/publishDiagnostics",
-                            PublishDiagnosticsParams(
-                                uri=document.document_uri,
-                                version=document._version,
-                                diagnostics=[
-                                    e for e in itertools.chain(*(i for i in data.entries.values() if i is not None))
-                                ],
-                            ),
-                        )
+                data.id = str(uuid.uuid4())
+                data.entries[result.key] = result.diagnostics
+                if result.diagnostics is not None:
+                    collected_keys.append(result.key)
+
+                if data.entries and send_diagnostics:
+                    self.parent.send_notification(
+                        "textDocument/publishDiagnostics",
+                        PublishDiagnosticsParams(
+                            uri=document.document_uri,
+                            version=document._version,
+                            diagnostics=[
+                                l for l in itertools.chain(*[i for i in data.entries.values() if i is not None])
+                            ],
+                        ),
+                    )
 
         except asyncio.CancelledError:
             self._logger.debug(lambda: f"_get_diagnostics cancelled for {document}")
@@ -490,12 +493,12 @@ class DiagnosticsProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities)
         try:
             if not self.parent.is_initialized:
                 raise JsonRPCErrorException(
-                    ErrorCodes.SERVER_CANCELLED, "Server not initialized.", DiagnosticServerCancellationData(True)
+                    LSPErrorCodes.SERVER_CANCELLED, "Server not initialized.", DiagnosticServerCancellationData(True)
                 )
 
             document = await self.parent.documents.get(text_document.uri)
             if document is None:
-                raise JsonRPCErrorException(ErrorCodes.SERVER_CANCELLED, f"Document {text_document!r} not found.")
+                raise JsonRPCErrorException(LSPErrorCodes.SERVER_CANCELLED, f"Document {text_document!r} not found.")
 
             self.create_document_diagnostics_task(document, True)
 
@@ -508,7 +511,7 @@ class DiagnosticsProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities)
         data: DiagnosticsData = document.get_data(self, None)
 
         if data is None:
-            data = DiagnosticsData(str(uuid.uuid4()))
+            data = DiagnosticsData(str(uuid.uuid4()))  # type: ignore
             document.set_data(self, data)
 
         return data
