@@ -5,6 +5,7 @@ from typing import (
     TYPE_CHECKING,
     Any,
     Callable,
+    Final,
     List,
     Optional,
     Protocol,
@@ -21,8 +22,8 @@ from ..decorators import language_id_filter
 from ..has_extend_capabilities import HasExtendCapabilities
 from ..lsp_types import (
     DocumentSymbol,
-    DocumentSymbolClientCapabilitiesSymbolKind,
-    DocumentSymbolClientCapabilitiesTagSupport,
+    DocumentSymbolClientCapabilitiesSymbolKindType,
+    DocumentSymbolClientCapabilitiesTagSupportType,
     DocumentSymbolOptions,
     DocumentSymbolParams,
     ServerCapabilities,
@@ -54,14 +55,13 @@ def symbol_information_label(label: str) -> Callable[[_F], _F]:
 
 
 class DocumentSymbolsProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities):
-
-    _logger = LoggingDescriptor()
+    _logger: Final = LoggingDescriptor()
 
     def __init__(self, parent: LanguageServerProtocol) -> None:
         super().__init__(parent)
         self.hierarchical_document_symbol_support = False
-        self.symbol_kind: Optional[DocumentSymbolClientCapabilitiesSymbolKind] = None
-        self.tag_support: Optional[DocumentSymbolClientCapabilitiesTagSupport] = None
+        self.symbol_kind: Optional[DocumentSymbolClientCapabilitiesSymbolKindType] = None
+        self.tag_support: Optional[DocumentSymbolClientCapabilitiesTagSupportType] = None
 
     @async_tasking_event
     async def collect(
@@ -70,7 +70,6 @@ class DocumentSymbolsProtocolPart(LanguageServerProtocolPart, HasExtendCapabilit
         ...
 
     def extend_capabilities(self, capabilities: ServerCapabilities) -> None:
-
         if (
             self.parent.client_capabilities
             and self.parent.client_capabilities.text_document
@@ -102,7 +101,6 @@ class DocumentSymbolsProtocolPart(LanguageServerProtocolPart, HasExtendCapabilit
     async def _text_document_symbol(
         self, text_document: TextDocumentIdentifier, *args: Any, **kwargs: Any
     ) -> Optional[Union[List[DocumentSymbol], List[SymbolInformation], None]]:
-
         document_symbols: List[DocumentSymbol] = []
         symbol_informations: List[SymbolInformation] = []
 
