@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 from asyncio import CancelledError
-from typing import TYPE_CHECKING, Any, List, Optional
+from typing import TYPE_CHECKING, Any, Final, List, Optional
 
 from ....jsonrpc2.protocol import rpc_method
 from ....utils.async_tools import async_tasking_event, threaded
@@ -23,8 +23,7 @@ from .protocol_part import LanguageServerProtocolPart
 
 
 class FoldingRangeProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities):
-
-    _logger = LoggingDescriptor()
+    _logger: Final = LoggingDescriptor()
 
     def __init__(self, parent: LanguageServerProtocol) -> None:
         super().__init__(parent)
@@ -42,7 +41,6 @@ class FoldingRangeProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities
     async def _text_document_folding_range(
         self, text_document: TextDocumentIdentifier, *args: Any, **kwargs: Any
     ) -> Optional[List[FoldingRange]]:
-
         results: List[FoldingRange] = []
         document = await self.parent.documents.get(text_document.uri)
         if document is None:
