@@ -2,7 +2,7 @@ from __future__ import annotations
 
 from asyncio import CancelledError
 from enum import Enum
-from typing import TYPE_CHECKING, Any, List, Union
+from typing import TYPE_CHECKING, Any, Final, List, Union
 
 from ....jsonrpc2.protocol import rpc_method
 from ....utils.async_tools import async_tasking_event, threaded
@@ -18,7 +18,7 @@ from ..lsp_types import (
     SemanticTokensDeltaPartialResult,
     SemanticTokensLegend,
     SemanticTokensOptions,
-    SemanticTokensOptionsFull,
+    SemanticTokensOptionsFullType1,
     SemanticTokensParams,
     SemanticTokensPartialResult,
     SemanticTokensRangeParams,
@@ -35,11 +35,12 @@ from .protocol_part import LanguageServerProtocolPart
 
 
 class SemanticTokensProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities):
-
-    _logger = LoggingDescriptor()
+    _logger: Final = LoggingDescriptor()
 
     def __init__(self, parent: LanguageServerProtocol) -> None:
         super().__init__(parent)
+        self.token_types: List[Enum] = list(SemanticTokenTypes)
+        self.token_modifiers: List[Enum] = list(SemanticTokenModifiers)
 
     @async_tasking_event
     async def collect_full(
@@ -59,9 +60,6 @@ class SemanticTokensProtocolPart(LanguageServerProtocolPart, HasExtendCapabiliti
     ) -> Union[SemanticTokens, SemanticTokensPartialResult, None]:
         ...
 
-    token_types: List[Enum] = [e for e in SemanticTokenTypes]
-    token_modifiers: List[Enum] = [e for e in SemanticTokenModifiers]
-
     def extend_capabilities(self, capabilities: ServerCapabilities) -> None:
         if len(self.collect_full) or len(self.collect_range):
             capabilities.semantic_tokens_provider = SemanticTokensOptions(
@@ -69,7 +67,7 @@ class SemanticTokensProtocolPart(LanguageServerProtocolPart, HasExtendCapabiliti
                     token_types=[e.value for e in self.token_types],
                     token_modifiers=[e.value for e in self.token_modifiers],
                 ),
-                full=SemanticTokensOptionsFull(delta=True if len(self.collect_full_delta) else None)
+                full=SemanticTokensOptionsFullType1(delta=True if len(self.collect_full_delta) else None)
                 if len(self.collect_full) and len(self.collect_full_delta)
                 else True
                 if len(self.collect_full)
@@ -82,7 +80,6 @@ class SemanticTokensProtocolPart(LanguageServerProtocolPart, HasExtendCapabiliti
     async def _text_document_semantic_tokens_full(
         self, text_document: TextDocumentIdentifier, *args: Any, **kwargs: Any
     ) -> Union[SemanticTokens, SemanticTokensPartialResult, None]:
-
         results: List[Union[SemanticTokens, SemanticTokensPartialResult]] = []
 
         document = await self.parent.documents.get(text_document.uri)
@@ -113,7 +110,6 @@ class SemanticTokensProtocolPart(LanguageServerProtocolPart, HasExtendCapabiliti
     async def _text_document_semantic_tokens_full_delta(
         self, text_document: TextDocumentIdentifier, previous_result_id: str, *args: Any, **kwargs: Any
     ) -> Union[SemanticTokens, SemanticTokensDelta, SemanticTokensDeltaPartialResult, None]:
-
         results: List[Union[SemanticTokens, SemanticTokensDelta, SemanticTokensDeltaPartialResult]] = []
 
         document = await self.parent.documents.get(text_document.uri)
@@ -145,7 +141,6 @@ class SemanticTokensProtocolPart(LanguageServerProtocolPart, HasExtendCapabiliti
     async def _text_document_semantic_tokens_range(
         self, text_document: TextDocumentIdentifier, range: Range, *args: Any, **kwargs: Any
     ) -> Union[SemanticTokens, SemanticTokensPartialResult, None]:
-
         results: List[Union[SemanticTokens, SemanticTokensPartialResult]] = []
 
         document = await self.parent.documents.get(text_document.uri)
