@@ -2,7 +2,7 @@ from __future__ import annotations
 
 from asyncio import CancelledError
 from itertools import chain
-from typing import TYPE_CHECKING, Any, List, Optional, cast
+from typing import TYPE_CHECKING, Any, Final, List, Optional, cast
 
 from ....jsonrpc2.protocol import rpc_method
 from ....utils.async_tools import async_tasking_event, threaded
@@ -23,16 +23,14 @@ from ..lsp_types import (
     TextDocumentIdentifier,
 )
 from ..text_document import TextDocument
+from .protocol_part import LanguageServerProtocolPart
 
 if TYPE_CHECKING:
     from ..protocol import LanguageServerProtocol
 
-from .protocol_part import LanguageServerProtocolPart
-
 
 class SignatureHelpProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities):
-
-    _logger = LoggingDescriptor()
+    _logger: Final = LoggingDescriptor()
 
     def __init__(self, parent: LanguageServerProtocol) -> None:
         super().__init__(parent)
@@ -45,27 +43,25 @@ class SignatureHelpProtocolPart(LanguageServerProtocolPart, HasExtendCapabilitie
 
     def extend_capabilities(self, capabilities: ServerCapabilities) -> None:
         if len(self.collect):
-            trigger_chars = [
-                k
-                for k in chain(
+            trigger_chars = list(
+                chain(
                     *[
                         cast(HasTriggerCharacters, e).__trigger_characters__
                         for e in self.collect
                         if isinstance(e, HasTriggerCharacters)
                     ]
                 )
-            ]
+            )
 
-            retrigger_chars = [
-                k
-                for k in chain(
+            retrigger_chars = list(
+                chain(
                     *[
                         cast(HasRetriggerCharacters, e).__retrigger_characters__
                         for e in self.collect
                         if isinstance(e, HasRetriggerCharacters)
                     ]
                 )
-            ]
+            )
 
             capabilities.signature_help_provider = SignatureHelpOptions(
                 trigger_characters=trigger_chars if trigger_chars else None,
@@ -82,7 +78,6 @@ class SignatureHelpProtocolPart(LanguageServerProtocolPart, HasExtendCapabilitie
         *args: Any,
         **kwargs: Any,
     ) -> Optional[SignatureHelp]:
-
         results: List[SignatureHelp] = []
 
         document = await self.parent.documents.get(text_document.uri)
