@@ -1,6 +1,6 @@
 import contextlib
 import uuid
-from typing import Any, AsyncIterator, Dict, List, Optional
+from typing import TYPE_CHECKING, Any, AsyncIterator, Dict, List, Optional
 
 from ....jsonrpc2.protocol import rpc_method
 from ..lsp_types import (
@@ -23,6 +23,9 @@ from ..lsp_types import (
 )
 from .protocol_part import LanguageServerProtocolPart
 
+if TYPE_CHECKING:
+    from ..protocol import LanguageServerProtocol
+
 
 class Progress:
     def __init__(
@@ -102,6 +105,10 @@ class Progress:
 
 
 class WindowProtocolPart(LanguageServerProtocolPart):
+    def __init__(self, parent: "LanguageServerProtocol") -> None:
+        super().__init__(parent)
+        self.__progress_tokens: Dict[ProgressToken, bool] = {}
+
     def show_message(self, message: str, type: MessageType = MessageType.INFO) -> None:
         self.parent.send_notification("window/showMessage", ShowMessageParams(type=type, message=message))
 
@@ -132,8 +139,6 @@ class WindowProtocolPart(LanguageServerProtocolPart):
         )
         return r.success if r is not None else False
 
-    __progress_tokens: Dict[ProgressToken, bool] = {}
-
     @contextlib.asynccontextmanager
     async def progress(
         self,
@@ -147,7 +152,6 @@ class WindowProtocolPart(LanguageServerProtocolPart):
         start: bool = True,
         progress_token: Optional[ProgressToken] = None,
     ) -> AsyncIterator[Progress]:
-
         p = Progress(self, await self.create_progress() if progress_token is None else progress_token, message, max)
         if start:
             p.begin(
@@ -164,7 +168,6 @@ class WindowProtocolPart(LanguageServerProtocolPart):
             p.end()
 
     async def create_progress(self) -> Optional[ProgressToken]:
-
         if (
             self.parent.client_capabilities
             and self.parent.client_capabilities.window
@@ -184,7 +187,6 @@ class WindowProtocolPart(LanguageServerProtocolPart):
         *args: Any,
         **kwargs: Any,
     ) -> None:
-
         if token in self.__progress_tokens:
             self.__progress_tokens[token] = True
 
@@ -222,10 +224,10 @@ class WindowProtocolPart(LanguageServerProtocolPart):
             self.send_progress(
                 token,
                 WorkDoneProgressBegin(
-                    title or self.parent.short_name or self.parent.name or self._default_title,
-                    message,
-                    percentage,
-                    cancellable,
+                    title=title or self.parent.short_name or self.parent.name or self._default_title,
+                    message=message,
+                    percentage=percentage,
+                    cancellable=cancellable,
                 ),
             )
 
@@ -246,10 +248,9 @@ class WindowProtocolPart(LanguageServerProtocolPart):
             self.send_progress(
                 token,
                 WorkDoneProgressReport(
-                    title or self.parent.short_name or self.parent.name or self._default_title,
-                    message,
-                    percentage,
-                    cancellable,
+                    message=message,
+                    percentage=percentage,
+                    cancellable=cancellable,
                 ),
             )
 
@@ -265,7 +266,7 @@ class WindowProtocolPart(LanguageServerProtocolPart):
             and self.parent.client_capabilities.window.work_done_progress
         ):
             try:
-                self.send_progress(token, WorkDoneProgressEnd(message))
+                self.send_progress(token, WorkDoneProgressEnd(message=message))
             finally:
                 if token in self.__progress_tokens:
                     self.__progress_tokens.pop(token)
