@@ -10,6 +10,7 @@ from typing import (
     Callable,
     Coroutine,
     Dict,
+    Final,
     List,
     Mapping,
     NamedTuple,
@@ -25,7 +26,7 @@ from typing import (
 
 from ....jsonrpc2.protocol import rpc_method
 from ....utils.async_tools import Lock, async_tasking_event, create_sub_task, threaded
-from ....utils.dataclasses import from_dict
+from ....utils.dataclasses import CamelSnakeMixin, from_dict
 from ....utils.logging import LoggingDescriptor
 from ....utils.path import path_is_relative_to
 from ....utils.uri import Uri
@@ -46,21 +47,21 @@ from ..lsp_types import (
     FileDelete,
     FileEvent,
     FileOperationFilter,
+    FileOperationOptions,
     FileOperationPattern,
     FileOperationRegistrationOptions,
     FileRename,
     FileSystemWatcher,
-    Model,
     RenameFilesParams,
     ServerCapabilities,
-    ServerCapabilitiesWorkspace,
-    ServerCapabilitiesWorkspaceFileOperations,
+    ServerCapabilitiesWorkspaceType,
     TextEdit,
     WatchKind,
     WorkspaceEdit,
+    WorkspaceFoldersChangeEvent,
+    WorkspaceFoldersServerCapabilities,
 )
 from ..lsp_types import WorkspaceFolder as TypesWorkspaceFolder
-from ..lsp_types import WorkspaceFoldersChangeEvent, WorkspaceFoldersServerCapabilities
 from .protocol_part import LanguageServerProtocolPart
 
 __all__ = ["WorkspaceFolder", "Workspace", "ConfigBase", "config_section", "FileWatcherEntry"]
@@ -122,9 +123,8 @@ class HasConfigSection(Protocol):
     __config_section__: str
 
 
-@config_section("unknown")
 @dataclass
-class ConfigBase(Model):
+class ConfigBase(CamelSnakeMixin):
     pass
 
 
@@ -133,7 +133,7 @@ _F = TypeVar("_F", bound=Callable[..., Any])
 
 
 class Workspace(LanguageServerProtocolPart, HasExtendCapabilities):
-    _logger = LoggingDescriptor()
+    _logger: Final = LoggingDescriptor()
 
     def __init__(
         self,
@@ -169,11 +169,11 @@ class Workspace(LanguageServerProtocolPart, HasExtendCapabilities):
             await self.remove_file_watcher_entry(e)
 
     def extend_capabilities(self, capabilities: ServerCapabilities) -> None:
-        capabilities.workspace = ServerCapabilitiesWorkspace(
+        capabilities.workspace = ServerCapabilitiesWorkspaceType(
             workspace_folders=WorkspaceFoldersServerCapabilities(
                 supported=True, change_notifications=str(uuid.uuid4())
             ),
-            file_operations=ServerCapabilitiesWorkspaceFileOperations(
+            file_operations=FileOperationOptions(
                 did_create=FileOperationRegistrationOptions(
                     filters=[
                         FileOperationFilter(
@@ -232,7 +232,7 @@ class Workspace(LanguageServerProtocolPart, HasExtendCapabilities):
         ...
 
     @rpc_method(name="workspace/didChangeConfiguration", param_type=DidChangeConfigurationParams)
-    @_logger.call
+    @threaded()
     async def _workspace_did_change_configuration(self, settings: Dict[str, Any], *args: Any, **kwargs: Any) -> None:
         self.settings = settings
         await self.did_change_configuration(self, settings)
@@ -262,11 +262,11 @@ class Workspace(LanguageServerProtocolPart, HasExtendCapabilities):
         ...
 
     @rpc_method(name="workspace/willCreateFiles", param_type=CreateFilesParams)
-    @_logger.call
+    @threaded()
     async def _workspace_will_create_files(
         self, files: List[FileCreate], *args: Any, **kwargs: Any
     ) -> Optional[WorkspaceEdit]:
-        results = await self.will_create_files(self, list(f.uri for f in files))
+        results = await self.will_create_files(self, [f.uri for f in files])
         if len(results) == 0:
             return None
 
@@ -280,33 +280,33 @@ class Workspace(LanguageServerProtocolPart, HasExtendCapabilities):
         return WorkspaceEdit(changes=result)
 
     @rpc_method(name="workspace/didCreateFiles", param_type=CreateFilesParams)
-    @_logger.call
+    @threaded()
     async def _workspace_did_create_files(self, files: List[FileCreate], *args: Any, **kwargs: Any) -> None:
-        await self.did_create_files(self, list(f.uri for f in files))
+        await self.did_create_files(self, [f.uri for f in files])
 
     @rpc_method(name="workspace/willRenameFiles", param_type=RenameFilesParams)
-    @_logger.call
+    @threaded()
     async def _workspace_will_rename_files(self, files: List[FileRename], *args: Any, **kwargs: Any) -> None:
-        await self.will_rename_files(self, list((f.old_uri, f.new_uri) for f in files))
+        await self.will_rename_files(self, [(f.old_uri, f.new_uri) for f in files])
 
         # TODO: return WorkspaceEdit
 
     @rpc_method(name="workspace/didRenameFiles", param_type=RenameFilesParams)
-    @_logger.call
+    @threaded()
     async def _workspace_did_rename_files(self, files: List[FileRename], *args: Any, **kwargs: Any) -> None:
-        await self.did_rename_files(self, list((f.old_uri, f.new_uri) for f in files))
+        await self.did_rename_files(self, [(f.old_uri, f.new_uri) for f in files])
 
     @rpc_method(name="workspace/willDeleteFiles", param_type=DeleteFilesParams)
-    @_logger.call
+    @threaded()
     async def _workspace_will_delete_files(self, files: List[FileDelete], *args: Any, **kwargs: Any) -> None:
-        await self.will_delete_files(self, list(f.uri for f in files))
+        await self.will_delete_files(self, [f.uri for f in files])
 
         # TODO: return WorkspaceEdit
 
     @rpc_method(name="workspace/didDeleteFiles", param_type=DeleteFilesParams)
-    @_logger.call
+    @threaded()
     async def _workspace_did_delete_files(self, files: List[FileDelete], *args: Any, **kwargs: Any) -> None:
-        await self.did_delete_files(self, list(f.uri for f in files))
+        await self.did_delete_files(self, [f.uri for f in files])
 
     async def get_configuration(
         self, section: Type[_TConfig], scope_uri: Union[str, Uri, None] = None, request: bool = True
@@ -366,11 +366,10 @@ class Workspace(LanguageServerProtocolPart, HasExtendCapabilities):
         return None
 
     @rpc_method(name="workspace/didChangeWorkspaceFolders", param_type=DidChangeWorkspaceFoldersParams)
-    @_logger.call
+    @threaded()
     async def _workspace_did_change_workspace_folders(
         self, event: WorkspaceFoldersChangeEvent, *args: Any, **kwargs: Any
     ) -> None:
-
         async with self._workspace_folders_lock:
             to_remove: List[WorkspaceFolder] = []
             for removed in event.removed:
@@ -410,7 +409,6 @@ class Workspace(LanguageServerProtocolPart, HasExtendCapabilities):
         callback: Callable[[Any, List[FileEvent]], Coroutine[Any, Any, None]],
         watchers: List[Union[FileWatcher, str, Tuple[str, Optional[WatchKind]]]],
     ) -> FileWatcherEntry:
-
         async with self._file_watchers_lock:
             _watchers = [
                 e if isinstance(e, FileWatcher) else FileWatcher(*e) if isinstance(e, tuple) else FileWatcher(e)
