@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 import asyncio
-from typing import Any, List, NamedTuple, Optional, Set, Union, cast
+from typing import Any, ClassVar, Final, List, NamedTuple, Optional, Set, Union
 
 from ...jsonrpc2.protocol import (
     JsonRPCErrorException,
@@ -16,15 +16,15 @@ from ...utils.async_tools import Event, async_event
 from ...utils.logging import LoggingDescriptor
 from .has_extend_capabilities import HasExtendCapabilities
 from .lsp_types import (
-    UTF16,
     CancelParams,
     ClientCapabilities,
-    ClientInfo,
     InitializedParams,
     InitializeError,
     InitializeParams,
+    InitializeParamsClientInfoType,
     InitializeResult,
-    InitializeResultServerInfo,
+    InitializeResultServerInfoType,
+    PositionEncodingKind,
     ProgressToken,
     Registration,
     RegistrationParams,
@@ -33,7 +33,7 @@ from .lsp_types import (
     SetTraceParams,
     TextDocumentSyncKind,
     TextDocumentSyncOptions,
-    TraceValue,
+    TraceValues,
     Unregistration,
     UnregistrationParams,
     WorkspaceFolder,
@@ -77,46 +77,45 @@ class LanguageDefinition(NamedTuple):
 
 
 class LanguageServerProtocol(JsonRPCProtocol):
+    __logger = LoggingDescriptor()
 
-    _logger = LoggingDescriptor()
-
-    commands = ProtocolPartDescriptor(CommandsProtocolPart)
-    window = ProtocolPartDescriptor(WindowProtocolPart)
-    documents = ProtocolPartDescriptor(TextDocumentProtocolPart)
-    diagnostics = ProtocolPartDescriptor(DiagnosticsProtocolPart)
-    folding_ranges = ProtocolPartDescriptor(FoldingRangeProtocolPart)
-    definition = ProtocolPartDescriptor(DefinitionProtocolPart)
-    implementation = ProtocolPartDescriptor(ImplementationProtocolPart)
-    declaration = ProtocolPartDescriptor(DeclarationProtocolPart)
-    hover = ProtocolPartDescriptor(HoverProtocolPart)
-    completion = ProtocolPartDescriptor(CompletionProtocolPart)
-    signature_help = ProtocolPartDescriptor(SignatureHelpProtocolPart)
-    code_lens = ProtocolPartDescriptor(CodeLensProtocolPart)
-    document_symbols = ProtocolPartDescriptor(DocumentSymbolsProtocolPart)
-    formatting = ProtocolPartDescriptor(FormattingProtocolPart)
-    semantic_tokens = ProtocolPartDescriptor(SemanticTokensProtocolPart)
-    references = ProtocolPartDescriptor(ReferencesProtocolPart)
-    document_highlight = ProtocolPartDescriptor(DocumentHighlightProtocolPart)
-    linked_editing_range = ProtocolPartDescriptor(LinkedEditingRangeProtocolPart)
-    selection_range = ProtocolPartDescriptor(SelectionRangeProtocolPart)
-    rename = ProtocolPartDescriptor(RenameProtocolPart)
-    inline_value = ProtocolPartDescriptor(InlineValueProtocolPart)
-    inlay_hint = ProtocolPartDescriptor(InlayHintProtocolPart)
-    code_action = ProtocolPartDescriptor(CodeActionProtocolPart)
+    commands: Final = ProtocolPartDescriptor(CommandsProtocolPart)
+    window: Final = ProtocolPartDescriptor(WindowProtocolPart)
+    documents: Final = ProtocolPartDescriptor(TextDocumentProtocolPart)
+    diagnostics: Final = ProtocolPartDescriptor(DiagnosticsProtocolPart)
+    folding_ranges: Final = ProtocolPartDescriptor(FoldingRangeProtocolPart)
+    definition: Final = ProtocolPartDescriptor(DefinitionProtocolPart)
+    implementation: Final = ProtocolPartDescriptor(ImplementationProtocolPart)
+    declaration: Final = ProtocolPartDescriptor(DeclarationProtocolPart)
+    hover: Final = ProtocolPartDescriptor(HoverProtocolPart)
+    completion: Final = ProtocolPartDescriptor(CompletionProtocolPart)
+    signature_help: Final = ProtocolPartDescriptor(SignatureHelpProtocolPart)
+    code_lens: Final = ProtocolPartDescriptor(CodeLensProtocolPart)
+    document_symbols: Final = ProtocolPartDescriptor(DocumentSymbolsProtocolPart)
+    formatting: Final = ProtocolPartDescriptor(FormattingProtocolPart)
+    semantic_tokens: Final = ProtocolPartDescriptor(SemanticTokensProtocolPart)
+    references: Final = ProtocolPartDescriptor(ReferencesProtocolPart)
+    document_highlight: Final = ProtocolPartDescriptor(DocumentHighlightProtocolPart)
+    linked_editing_range: Final = ProtocolPartDescriptor(LinkedEditingRangeProtocolPart)
+    selection_range: Final = ProtocolPartDescriptor(SelectionRangeProtocolPart)
+    rename: Final = ProtocolPartDescriptor(RenameProtocolPart)
+    inline_value: Final = ProtocolPartDescriptor(InlineValueProtocolPart)
+    inlay_hint: Final = ProtocolPartDescriptor(InlayHintProtocolPart)
+    code_action: Final = ProtocolPartDescriptor(CodeActionProtocolPart)
 
     name: Optional[str] = None
     short_name: Optional[str] = None
     version: Optional[str] = None
 
-    file_extensions: Set[str] = set()
-    languages: List[LanguageDefinition] = []
+    file_extensions: ClassVar[Set[str]] = set()
+    languages: ClassVar[List[LanguageDefinition]] = []
 
     def __init__(self, server: JsonRPCServer[Any]):
         super().__init__()
         self.server = server
 
         self.initialization_options: Any = None
-        self.client_info: Optional[ClientInfo] = None
+        self.client_info: Optional[InitializeParamsClientInfoType] = None
         self._workspace: Optional[Workspace] = None
         self.client_capabilities: Optional[ClientCapabilities] = None
         self.shutdown_received = False
@@ -131,7 +130,7 @@ class LanguageServerProtocol(JsonRPCProtocol):
             )
         )
 
-        self._trace = TraceValue.OFF
+        self._trace = TraceValues.OFF
         self.is_initialized = Event()
 
     @async_event
@@ -143,11 +142,11 @@ class LanguageServerProtocol(JsonRPCProtocol):
         ...
 
     @property
-    def trace(self) -> TraceValue:
+    def trace(self) -> TraceValues:
         return self._trace
 
     @trace.setter
-    def trace(self, value: TraceValue) -> None:
+    def trace(self, value: TraceValues) -> None:
         self._trace = value
 
     @property
@@ -170,27 +169,26 @@ class LanguageServerProtocol(JsonRPCProtocol):
 
         for p in self.registry.parts:
             if isinstance(p, HasExtendCapabilities):
-                cast(HasExtendCapabilities, p).extend_capabilities(base_capabilities)
+                p.extend_capabilities(base_capabilities)
 
         return base_capabilities
 
     @rpc_method(name="initialize", param_type=InitializeParams)
-    @_logger.call
+    @__logger.call
     async def _initialize(
         self,
         capabilities: ClientCapabilities,
         root_path: Optional[str] = None,
         root_uri: Optional[str] = None,
         initialization_options: Optional[Any] = None,
-        trace: Optional[TraceValue] = None,
-        client_info: Optional[ClientInfo] = None,
+        trace: Optional[TraceValues] = None,
+        client_info: Optional[InitializeParamsClientInfoType] = None,
         workspace_folders: Optional[List[WorkspaceFolder]] = None,
         work_done_token: Optional[ProgressToken] = None,
         *args: Any,
         **kwargs: Any,
     ) -> InitializeResult:
-
-        self.trace = trace or TraceValue.OFF
+        self.trace = trace or TraceValues.OFF
         self.client_info = client_info
 
         self.client_capabilities = capabilities
@@ -211,9 +209,9 @@ class LanguageServerProtocol(JsonRPCProtocol):
                 if (
                     self.client_capabilities.general
                     and self.client_capabilities.general.position_encodings
-                    and UTF16 in self.client_capabilities.general.position_encodings
+                    and PositionEncodingKind.UTF16 in self.client_capabilities.general.position_encodings
                 ):
-                    self.capabilities.position_encoding = UTF16
+                    self.capabilities.position_encoding = PositionEncodingKind.UTF16
 
                 await self.on_initialize(self, initialization_options)
             except (asyncio.CancelledError, SystemExit, KeyboardInterrupt):
@@ -228,7 +226,7 @@ class LanguageServerProtocol(JsonRPCProtocol):
             return InitializeResult(
                 capabilities=self.capabilities,
                 **(
-                    {"server_info": InitializeResultServerInfo(name=self.name, version=self.version)}
+                    {"server_info": InitializeResultServerInfoType(name=self.name, version=self.version)}
                     if self.name is not None
                     else {}
                 ),
@@ -251,7 +249,7 @@ class LanguageServerProtocol(JsonRPCProtocol):
         ...
 
     @rpc_method(name="shutdown", cancelable=False)
-    @_logger.call
+    @__logger.call
     async def _shutdown(self, *args: Any, **kwargs: Any) -> None:
         if self.shutdown_received:
             return
@@ -261,24 +259,24 @@ class LanguageServerProtocol(JsonRPCProtocol):
         try:
             await asyncio.wait_for(self.cancel_all_received_request(), 1)
         except BaseException as e:  # NOSONAR
-            self._logger.exception(e)
+            self.__logger.exception(e)
 
         await self.on_shutdown(self)
 
     @rpc_method(name="exit")
-    @_logger.call
+    @__logger.call
     async def _exit(self, *args: Any, **kwargs: Any) -> None:
         await self.on_exit(self)
 
         raise SystemExit(0 if self.shutdown_received else 1)
 
     @rpc_method(name="$/setTrace", param_type=SetTraceParams)
-    @_logger.call
-    async def _set_trace(self, value: TraceValue, *args: Any, **kwargs: Any) -> None:
+    @__logger.call
+    async def _set_trace(self, value: TraceValues, *args: Any, **kwargs: Any) -> None:
         self.trace = value
 
     @rpc_method(name="$/cancelRequest", param_type=CancelParams)
-    @_logger.call
+    @__logger.call
     async def _cancel_request(self, id: Union[int, str], **kwargs: Any) -> None:
         self.cancel_request(id)
 
