@@ -5,7 +5,7 @@ import inspect
 import io
 import threading
 import weakref
-from typing import Any, Awaitable, Callable, Dict, List, Optional, TypeVar, Union, cast
+from typing import Any, Awaitable, Callable, Dict, Final, List, Optional, TypeVar, Union, cast
 
 from ...utils.async_tools import async_event, create_sub_task
 from ...utils.logging import LoggingDescriptor
@@ -28,7 +28,7 @@ class CacheEntry:
 
 
 class TextDocument:
-    _logger = LoggingDescriptor()
+    _logger: Final = LoggingDescriptor()
 
     def __init__(
         self,
@@ -71,9 +71,6 @@ class TextDocument:
             f")"
         )
 
-    def text_sync(self) -> str:
-        return self._text
-
     def text(self) -> str:
         with self._lock:
             return self._text
@@ -167,7 +164,6 @@ class TextDocument:
         self._cache.clear()
         create_sub_task(self.cache_invalidated(self))
 
-    @_logger.call
     def invalidate_cache(self) -> None:
         with self._lock:
             self._invalidate_cache()
@@ -175,7 +171,6 @@ class TextDocument:
     def _invalidate_data(self) -> None:
         self._data.clear()
 
-    @_logger.call
     def invalidate_data(self) -> None:
         with self._lock:
             self._invalidate_data()
@@ -186,19 +181,15 @@ class TextDocument:
                 self._cache.pop(ref)
 
     def __get_cache_reference(self, entry: Callable[..., Any], /, *, add_remove: bool = True) -> weakref.ref[Any]:
-
         if inspect.ismethod(entry):
-            reference: weakref.ref[Any] = weakref.WeakMethod(entry, self.__remove_cache_entry if add_remove else None)
-        else:
-            reference = weakref.ref(entry, self.__remove_cache_entry if add_remove else None)
+            return weakref.WeakMethod(entry, self.__remove_cache_entry if add_remove else None)
 
-        return reference
+        return weakref.ref(entry, self.__remove_cache_entry if add_remove else None)
 
     def get_cache_value(
         self,
         entry: Union[Callable[[TextDocument], Awaitable[_T]], Callable[..., Awaitable[_T]]],
     ) -> Optional[_T]:
-
         reference = self.__get_cache_reference(entry)
 
         e = self._cache.get(reference, None)
@@ -213,7 +204,6 @@ class TextDocument:
         *args: Any,
         **kwargs: Any,
     ) -> _T:
-
         reference = self.__get_cache_reference(entry)
 
         e = self._cache[reference]
@@ -231,7 +221,6 @@ class TextDocument:
         *args: Any,
         **kwargs: Any,
     ) -> _T:
-
         reference = self.__get_cache_reference(entry)
 
         e = self._cache[reference]
@@ -243,7 +232,6 @@ class TextDocument:
 
             return cast(_T, e.data)
 
-    @_logger.call
     async def remove_cache_entry(
         self, entry: Union[Callable[[TextDocument], Awaitable[_T]], Callable[..., Awaitable[_T]]]
     ) -> None:
