@@ -6,7 +6,7 @@ import itertools
 import os
 from collections import defaultdict
 from dataclasses import dataclass
-from typing import Any, Dict, Generator, List, Optional, Set, Tuple, Union, cast
+from typing import Any, Dict, Iterator, List, Optional, Set, Tuple, Union, cast
 
 from ....utils.uri import Uri
 from ...common.lsp_types import (
@@ -91,7 +91,7 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
 
         return AnalyzerResult(self._diagnostics, self._keyword_references, self._variable_references)
 
-    def yield_argument_name_and_rest(self, node: ast.AST, token: Token) -> Generator[Token, None, None]:
+    def yield_argument_name_and_rest(self, node: ast.AST, token: Token) -> Iterator[Token]:
         from robot.parsing.lexer.tokens import Token as RobotToken
         from robot.parsing.model.statements import Arguments
 
@@ -131,7 +131,6 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
         name = name_token.value
 
         if name is not None:
-
             match = search_variable(name, ignore_errors=True)
             if not match.is_assign(allow_assign_mark=True):
                 return
@@ -178,7 +177,7 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
                 DiagnosticSeverity.HINT if isinstance(node, DocumentationOrMetadata) else DiagnosticSeverity.ERROR
             )
 
-            if isinstance(node, Statement) and isinstance(node, KeywordCall) and node.keyword:
+            if isinstance(node, KeywordCall) and node.keyword:
                 kw_doc = self.finder.find_keyword(node.keyword)
                 if kw_doc is not None and kw_doc.longname in ["BuiltIn.Comment"]:
                     severity = DiagnosticSeverity.HINT
@@ -295,7 +294,6 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
         related_information: Optional[List[DiagnosticRelatedInformation]] = None,
         data: Optional[Any] = None,
     ) -> None:
-
         if self._should_ignore(range):
             return
 
@@ -339,7 +337,6 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
             kw_range = range_from_token(keyword_token)
 
             if keyword is not None:
-
                 for lib, name in iter_over_keyword_names_and_owners(keyword):
                     if (
                         lib is not None
@@ -419,7 +416,7 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
                         message=f"Keyword '{result.name}' is deprecated"
                         f"{f': {result.deprecated_message}' if result.deprecated_message else ''}.",
                         severity=DiagnosticSeverity.HINT,
-                        tags=[DiagnosticTag.Deprecated],
+                        tags=[DiagnosticTag.DEPRECATED],
                         code="DeprecatedKeyword",
                     )
                 if result.is_error_handler:
@@ -553,7 +550,8 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
             )
 
             return argument_tokens[1:]
-        elif keyword_doc.is_run_keyword_with_condition() and len(argument_tokens) > (
+
+        if keyword_doc.is_run_keyword_with_condition() and len(argument_tokens) > (
             cond_count := keyword_doc.run_keyword_condition_count()
         ):
             await self._analyze_keyword_call(
@@ -565,10 +563,10 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
                 ignore_errors_if_contains_variables=True,
             )
             return argument_tokens[cond_count + 1 :]
-        elif keyword_doc.is_run_keywords():
+
+        if keyword_doc.is_run_keywords():
             has_and = False
             while argument_tokens:
-
                 t = argument_tokens[0]
                 argument_tokens = argument_tokens[1:]
                 if t.value == "AND":
@@ -601,7 +599,7 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
 
             return []
 
-        elif keyword_doc.is_run_keyword_if() and len(argument_tokens) > 1:
+        if keyword_doc.is_run_keyword_if() and len(argument_tokens) > 1:
 
             def skip_args() -> List[Token]:
                 nonlocal argument_tokens
@@ -639,7 +637,6 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
 
             while argument_tokens:
                 if argument_tokens[0].value == "ELSE" and len(argument_tokens) > 1:
-
                     kwt = argument_tokens[1]
                     argument_tokens = argument_tokens[2:]
 
@@ -657,8 +654,8 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
                         argument_tokens = await self._analyse_run_keyword(result, node, argument_tokens)
 
                     break
-                elif argument_tokens[0].value == "ELSE IF" and len(argument_tokens) > 2:
 
+                if argument_tokens[0].value == "ELSE IF" and len(argument_tokens) > 2:
                     kwt = argument_tokens[2]
                     argument_tokens = argument_tokens[3:]
 
@@ -757,7 +754,7 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
                 range=range_from_node_or_token(value, value.get_token(RobotToken.ASSIGN)),
                 message="Code is unreachable.",
                 severity=DiagnosticSeverity.HINT,
-                tags=[DiagnosticTag.Unnecessary],
+                tags=[DiagnosticTag.UNNECESSARY],
                 code="CodeUnreachable",
             )
 
@@ -896,6 +893,6 @@ class Analyzer(AsyncVisitor, ModelHelperMixin):
                         f"for removing tags. Escape '{tag.value}' like '\\{tag.value}' to use the "
                         f"literal value and to avoid this warning.",
                         severity=DiagnosticSeverity.WARNING,
-                        tags=[DiagnosticTag.Deprecated],
+                        tags=[DiagnosticTag.DEPRECATED],
                         code="DeprecatedHyphenTag",
                     )
