@@ -18,7 +18,6 @@ def single_call(func: _F) -> _F:
     name = f"__single_result_{func.__name__}__"
 
     def wrapper(self: Any, *args: Any, **kwargs: Any) -> Any:
-
         result = self.__dict__.get(name, _NOT_SET)
         if result is _NOT_SET:
             result = func(self, *args, **kwargs)
@@ -138,13 +137,14 @@ class VariableMatcher:
 
         if isinstance(o, VariableMatcher):
             return o.normalized_name == self.normalized_name
-        elif isinstance(o, str):
+
+        if isinstance(o, str):
             match = search_variable(o, "$@&%", ignore_errors=True)
             base = match.base
             normalized = str(normalize(base))
             return self.normalized_name == normalized
-        else:
-            return False
+
+        return False
 
     def __hash__(self) -> int:
         return hash(self.name)
@@ -179,11 +179,9 @@ class VariableDefinition(SourceEntity):
     value: Any = field(default=None, compare=False)
     value_is_native: bool = field(default=False, compare=False)
 
-    __matcher: Optional[VariableMatcher] = None
-
     @property
     def matcher(self) -> VariableMatcher:
-        if self.__matcher is None:
+        if not hasattr(self, "__matcher"):
             self.__matcher = VariableMatcher(self.name)
         return self.__matcher
 
@@ -195,8 +193,8 @@ class VariableDefinition(SourceEntity):
     def name_range(self) -> Range:
         if self.name_token is not None:
             return range_from_token(self.name_token)
-        else:
-            return self.range
+
+        return self.range
 
     @property
     def range(self) -> Range:
