@@ -3,6 +3,7 @@ from __future__ import annotations
 import ast
 import asyncio
 import itertools
+import multiprocessing as mp
 import os
 import shutil
 import sys
@@ -30,7 +31,7 @@ from typing import (
 
 from ....__version__ import __version__
 from ....utils.async_cache import AsyncSimpleLRUCache
-from ....utils.async_tools import Lock, async_tasking_event, create_sub_task, threaded
+from ....utils.async_tools import Lock, async_tasking_event, create_sub_task
 from ....utils.dataclasses import as_json, from_json
 from ....utils.glob_path import Pattern, iter_files
 from ....utils.logging import LoggingDescriptor
@@ -311,7 +312,6 @@ class _ResourcesEntry(_ImportEntry):
 
     async def check_file_changed(self, changes: List[FileEvent]) -> Optional[FileChangeType]:
         async with self._lock:
-
             for change in changes:
                 uri = Uri(change.uri)
                 if uri.scheme != "file":
@@ -556,37 +556,31 @@ class ImportsManager:
     def clear_cache(self) -> None:
         if self.cache_path.exists():
             shutil.rmtree(self.cache_path)
-            self._logger.debug(f"Cleared cache {self.cache_path}")
+            self._logger.debug(lambda: f"Cleared cache {self.cache_path}")
 
     @_logger.call
     async def get_command_line_variables(self) -> List[VariableDefinition]:
         from robot.utils.text import split_args_from_name_or_path
 
         async with self._command_line_variables_lock:
-
             if self._command_line_variables is None:
-                command_line_vars: List[VariableDefinition] = []
+                command_line_vars: List[VariableDefinition] = [
+                    CommandLineVariableDefinition(0, 0, 0, 0, "", f"${{{k}}}", None, has_value=True, value=(v,))
+                    for k, v in self.config.robot.variables.items()
+                ]
+                for variable_file in self.config.robot.variable_files:
+                    name, args = split_args_from_name_or_path(variable_file)
+                    try:
+                        lib_doc = await self.get_libdoc_for_variables_import(
+                            name, tuple(args), str(self.folder.to_path()), self
+                        )
+                        if lib_doc is not None:
+                            command_line_vars += lib_doc.variables
 
-                if self.config.robot is None:
-                    self._command_line_variables = []
-                else:
-                    command_line_vars = [
-                        CommandLineVariableDefinition(0, 0, 0, 0, "", f"${{{k}}}", None, has_value=True, value=(v,))
-                        for k, v in self.config.robot.variables.items()
-                    ]
-                    for variable_file in self.config.robot.variable_files:
-                        name, args = split_args_from_name_or_path(variable_file)
-                        try:
-                            lib_doc = await self.get_libdoc_for_variables_import(
-                                name, tuple(args), str(self.folder.to_path()), self
-                            )
-                            if lib_doc is not None:
-                                command_line_vars += lib_doc.variables
-
-                        except (SystemExit, KeyboardInterrupt, asyncio.CancelledError):
-                            raise
-                        except BaseException as e:
-                            self._logger.exception(e)
+                    except (SystemExit, KeyboardInterrupt, asyncio.CancelledError):
+                        raise
+                    except BaseException as e:
+                        self._logger.exception(e)
 
                 self._command_line_variables = command_line_vars
 
@@ -608,13 +602,16 @@ class ImportsManager:
     async def imports_changed(sender, uri: DocumentUri) -> None:  # NOSONAR
         ...
 
-    @threaded()
     async def _do_imports_changed(self, sender: Any, uri: DocumentUri) -> None:  # NOSONAR
-        await self.imports_changed(self, uri)
+        create_sub_task(self.imports_changed(self, uri), loop=self.parent_protocol.diagnostics.diagnostics_loop)
 
     @language_id("robotframework")
-    @threaded()
     async def resource_document_changed(self, sender: Any, document: TextDocument) -> None:
+        create_sub_task(
+            self.__resource_document_changed(document), loop=self.parent_protocol.diagnostics.diagnostics_loop
+        )
+
+    async def __resource_document_changed(self, document: TextDocument) -> None:
         resource_changed: List[LibraryDoc] = []
 
         async with self._resources_lock:
@@ -681,21 +678,21 @@ class ImportsManager:
                     variables_changed.append((v_key, result, lib_doc))
 
         if libraries_changed:
-            for (l, t, _) in libraries_changed:
+            for l, t, _ in libraries_changed:
                 if t == FileChangeType.DELETED:
                     self.__remove_library_entry(l, self._libaries[l], True)
 
             await self.libraries_changed(self, [v for (_, _, v) in libraries_changed if v is not None])
 
         if resource_changed:
-            for (r, t, _) in resource_changed:
+            for r, t, _ in resource_changed:
                 if t == FileChangeType.DELETED:
                     self.__remove_resource_entry(r, self._resources[r], True)
 
             await self.resources_changed(self, [v for (_, _, v) in resource_changed if v is not None])
 
         if variables_changed:
-            for (v, t, _) in variables_changed:
+            for v, t, _ in variables_changed:
                 if t == FileChangeType.DELETED:
                     self.__remove_variables_entry(v, self._variables[v], True)
 
@@ -805,7 +802,10 @@ class ImportsManager:
                     or (p.matches(result.origin) if result.origin is not None else False)
                     for p in self.ignored_libraries_patters
                 ):
-                    self._logger.debug(f"Ignore library {result.name or ''} {result.origin or ''} for caching.")
+                    self._logger.debug(
+                        lambda: f"Ignore library {result.name or '' if result is not None else ''}"
+                        f" {result.origin or '' if result is not None else ''} for caching."
+                    )
                     return None, import_name
 
                 if result.origin is not None:
@@ -866,7 +866,10 @@ class ImportsManager:
                     or (p.matches(result.origin) if result.origin is not None else False)
                     for p in self.ignored_variables_patters
                 ):
-                    self._logger.debug(f"Ignore Variables {result.name or ''} {result.origin or ''} for caching.")
+                    self._logger.debug(
+                        lambda: f"Ignore Variables {result.name or '' if result is not None else ''}"
+                        f" {result.origin or '' if result is not None else ''} for caching."
+                    )
                     return None, import_name
 
                 if result.origin is not None:
@@ -914,7 +917,7 @@ class ImportsManager:
             result = name
 
         if is_library_by_path(result):
-            result = find_file_ex(result, base_dir, "Library")
+            return find_file_ex(result, base_dir, "Library")
 
         return result
 
@@ -958,13 +961,12 @@ class ImportsManager:
             )
 
         if get_robot_version() >= (5, 0):
-
             if is_variables_by_path(name):
-                return str(find_file_ex(name, base_dir, "Library"))
+                return str(find_file_ex(name, base_dir, "Variables"))
 
             return name
 
-        return str(find_file_ex(name, base_dir, "Library"))
+        return str(find_file_ex(name, base_dir, "Variables"))
 
     @_logger.call
     async def get_libdoc_for_library_import(
@@ -982,7 +984,6 @@ class ImportsManager:
         )
 
         async def _get_libdoc(name: str, args: Tuple[Any, ...], working_dir: str, base_dir: str) -> LibraryDoc:
-
             meta, source = await self.get_library_meta(
                 name,
                 base_dir,
@@ -1014,7 +1015,7 @@ class ImportsManager:
                     except BaseException as e:
                         self._logger.exception(e)
 
-            with ProcessPoolExecutor(max_workers=1) as executor:
+            with ProcessPoolExecutor(max_workers=1, mp_context=mp.get_context("spawn")) as executor:
                 result = await asyncio.wait_for(
                     asyncio.get_running_loop().run_in_executor(
                         executor,
@@ -1029,32 +1030,30 @@ class ImportsManager:
                     LOAD_LIBRARY_TIME_OUT,
                 )
 
-                if result.stdout:
-                    self._logger.warning(
-                        lambda: f"stdout captured at loading library {name}{repr(args)}:\n{result.stdout}"
-                    )
-                try:
-                    if meta is not None:
-                        meta_file = Path(self.lib_doc_cache_path, meta.filepath_base.with_suffix(".meta.json"))
-                        spec_file = Path(self.lib_doc_cache_path, meta.filepath_base.with_suffix(".spec.json"))
-                        spec_file.parent.mkdir(parents=True, exist_ok=True)
+            if result.stdout:
+                self._logger.warning(lambda: f"stdout captured at loading library {name}{repr(args)}:\n{result.stdout}")
+            try:
+                if meta is not None:
+                    meta_file = Path(self.lib_doc_cache_path, meta.filepath_base.with_suffix(".meta.json"))
+                    spec_file = Path(self.lib_doc_cache_path, meta.filepath_base.with_suffix(".spec.json"))
+                    spec_file.parent.mkdir(parents=True, exist_ok=True)
 
-                        try:
-                            spec_file.write_text(as_json(result), "utf-8")
-                        except (SystemExit, KeyboardInterrupt):
-                            raise
-                        except BaseException as e:
-                            raise RuntimeError(f"Cannot write spec file for library '{name}' to '{spec_file}'") from e
+                    try:
+                        spec_file.write_text(as_json(result), "utf-8")
+                    except (SystemExit, KeyboardInterrupt):
+                        raise
+                    except BaseException as e:
+                        raise RuntimeError(f"Cannot write spec file for library '{name}' to '{spec_file}'") from e
 
-                        meta_file.write_text(as_json(meta), "utf-8")
-                    else:
-                        self._logger.debug(lambda: f"Skip caching library {name}{repr(args)}")
-                except (SystemExit, KeyboardInterrupt):
-                    raise
-                except BaseException as e:
-                    self._logger.exception(e)
+                    meta_file.write_text(as_json(meta), "utf-8")
+                else:
+                    self._logger.debug(lambda: f"Skip caching library {name}{repr(args)}")
+            except (SystemExit, KeyboardInterrupt):
+                raise
+            except BaseException as e:
+                self._logger.exception(e)
 
-                return result
+            return result
 
         resolved_args = resolve_args(
             args,
@@ -1086,7 +1085,7 @@ class ImportsManager:
         return await entry.get_libdoc()
 
     @_logger.call
-    async def get_libdoc_from_model(
+    def get_libdoc_from_model(
         self,
         model: ast.AST,
         source: str,
@@ -1094,7 +1093,6 @@ class ImportsManager:
         scope: str = "GLOBAL",
         append_model_errors: bool = True,
     ) -> LibraryDoc:
-
         from robot.errors import DataError
         from robot.libdocpkg.robotbuilder import KeywordDocBuilder
         from robot.parsing.lexer.tokens import Token as RobotToken
@@ -1183,7 +1181,7 @@ class ImportsManager:
             keywords=[
                 KeywordDoc(
                     name=kw[0].name,
-                    args=list(KeywordArgumentDoc.from_robot(a) for a in kw[0].args),
+                    args=[KeywordArgumentDoc.from_robot(a) for a in kw[0].args],
                     doc=kw[0].doc,
                     tags=list(kw[0].tags),
                     source=kw[0].source,
@@ -1259,7 +1257,7 @@ class ImportsManager:
                     except BaseException as e:
                         self._logger.exception(e)
 
-            with ProcessPoolExecutor(max_workers=1) as executor:
+            with ProcessPoolExecutor(max_workers=1, mp_context=mp.get_context("spawn")) as executor:
                 result = await asyncio.wait_for(
                     asyncio.get_running_loop().run_in_executor(
                         executor,
@@ -1408,7 +1406,6 @@ class ImportsManager:
     async def complete_variables_import(
         self, name: Optional[str], base_dir: str = ".", variables: Optional[Dict[str, Any]] = None
     ) -> Optional[List[CompleteResult]]:
-
         return complete_variables_import(
             name,
             str(self.folder.to_path()),
