@@ -136,7 +136,6 @@ class KeywordMatcher:
 
     @property
     def normalized_name(self) -> str:
-
         if self._normalized_name is None:
             self._normalized_name = str(normalize(self.name))
 
@@ -165,8 +164,8 @@ class KeywordMatcher:
         if isinstance(o, KeywordMatcher):
             if not self.embedded_arguments:
                 return self.normalized_name == o.normalized_name
-            else:
-                o = o.name
+
+            o = o.name
 
         if not isinstance(o, str):
             return False
@@ -174,8 +173,8 @@ class KeywordMatcher:
         if self.embedded_arguments:
             if get_robot_version() >= (6, 0):
                 return self.embedded_arguments.match(o) is not None
-            else:
-                return self.embedded_arguments.name.match(o) is not None
+
+            return self.embedded_arguments.name.match(o) is not None
 
         return self.normalized_name == str(normalize(o))
 
@@ -194,7 +193,7 @@ class KeywordMatcher:
         return f"{type(self).__name__}(name={repr(self.name)})"
 
 
-RUN_KEYWORD_WITH_CONDITION_MATCHERS = [KeywordMatcher(e) for e in RUN_KEYWORD_WITH_CONDITION_NAMES.keys()]
+RUN_KEYWORD_WITH_CONDITION_MATCHERS = [KeywordMatcher(e) for e in RUN_KEYWORD_WITH_CONDITION_NAMES]
 
 RUN_KEYWORD_IF_MATCHER = KeywordMatcher(RUN_KEYWORD_IF_NAME)
 
@@ -290,9 +289,7 @@ class ArgumentSpec:
         dict_to_kwargs: bool = False,
     ) -> Any:
         from robot.running.arguments.argumentresolver import ArgumentResolver
-        from robot.running.arguments.argumentspec import (
-            ArgumentSpec as RobotArgumentSpec,
-        )
+        from robot.running.arguments.argumentspec import ArgumentSpec as RobotArgumentSpec
 
         if not hasattr(self, "__robot_arguments"):
             self.__robot_arguments = RobotArgumentSpec(
@@ -374,8 +371,8 @@ class KeywordDoc(SourceEntity):
     def name_range(self) -> Range:
         if self.name_token is not None:
             return range_from_token(self.name_token)
-        else:
-            return Range.invalid()
+
+        return Range.invalid()
 
     @single_call
     def normalized_tags(self) -> List[str]:
@@ -392,21 +389,21 @@ class KeywordDoc(SourceEntity):
     def range(self) -> Range:
         if self.name_token is not None:
             return range_from_token(self.name_token)
-        else:
-            return Range(
-                start=Position(
-                    line=self.line_no - 1 if self.line_no > 0 else 0,
-                    character=self.col_offset if self.col_offset >= 0 else 0,
-                ),
-                end=Position(
-                    line=self.end_line_no - 1 if self.end_line_no >= 0 else self.line_no if self.line_no > 0 else 0,
-                    character=self.end_col_offset
-                    if self.end_col_offset >= 0
-                    else self.col_offset
-                    if self.col_offset >= 0
-                    else 0,
-                ),
-            )
+
+        return Range(
+            start=Position(
+                line=self.line_no - 1 if self.line_no > 0 else 0,
+                character=self.col_offset if self.col_offset >= 0 else 0,
+            ),
+            end=Position(
+                line=self.end_line_no - 1 if self.end_line_no >= 0 else self.line_no if self.line_no > 0 else 0,
+                character=self.end_col_offset
+                if self.end_col_offset >= 0
+                else self.col_offset
+                if self.col_offset >= 0
+                else 0,
+            ),
+        )
 
     def to_markdown(self, add_signature: bool = True, header_level: int = 2, add_type: bool = True) -> str:
         result = ""
@@ -439,7 +436,6 @@ class KeywordDoc(SourceEntity):
                 result = ""
 
         if self.args:
-
             result += f"\n##{'#'*header_level} Arguments: \n\n"
 
             result += "\n| | | | |"
@@ -544,7 +540,7 @@ class KeywordStore:
         items = [(k, v) for k, v in self._matchers.items() if k == key]
 
         if not items:
-            raise KeyError()
+            raise KeyError
         if len(items) == 1:
             return items[0][1]
 
@@ -580,7 +576,7 @@ class KeywordStore:
         return {v.name for v in self.keywords}
 
     def values(self) -> AbstractSet[KeywordDoc]:
-        return {v for v in self.keywords}
+        return set(self.keywords)
 
     def __iter__(self) -> Iterator[KeywordDoc]:
         return self.keywords.__iter__()
@@ -705,7 +701,6 @@ class LibraryDoc:
                 write_lines("", "")
 
             if self.doc:
-
                 write_lines(f"##{'#'*header_level} Introduction", "")
 
                 if self.doc_format == ROBOT_DOC_FORMAT:
@@ -844,10 +839,10 @@ def get_module_spec(module_name: str) -> Optional[ModuleSpec]:
             module_name = splitted[0]
 
     if result is not None:
-        return ModuleSpec(
+        return ModuleSpec(  # type: ignore
             name=result.name,
             origin=result.origin,
-            submodule_search_locations=[i for i in result.submodule_search_locations]
+            submodule_search_locations=list(result.submodule_search_locations)
             if result.submodule_search_locations
             else None,
         )
@@ -982,7 +977,6 @@ def error_from_exception(ex: BaseException, default_source: Optional[str], defau
 
 @dataclass
 class _Variable(object):
-
     name: str
     value: Iterable[str]
     source: Optional[str] = None
@@ -1062,7 +1056,6 @@ def resolve_robot_variables(
             result[f"${{{k1}}}"] = v1
 
     if variables is not None:
-
         vars = [_Variable(k, v) for k, v in variables.items() if v is not None and not isinstance(v, NativeValue)]
         result.set_from_variable_table(vars)
 
@@ -1109,7 +1102,7 @@ def _std_capture() -> Iterator[io.StringIO]:
         sys.__stdout__ = old__stdout__
 
 
-class IgnoreEasterEggLibraryWarning(Exception):
+class IgnoreEasterEggLibraryWarning(Exception):  # noqa: N818
     pass
 
 
@@ -1120,7 +1113,6 @@ def _find_library_internal(
     command_line_variables: Optional[Dict[str, Optional[Any]]] = None,
     variables: Optional[Dict[str, Optional[Any]]] = None,
 ) -> Tuple[str, Any]:
-
     from robot.errors import DataError
     from robot.libraries import STDLIBS
     from robot.utils.robotpath import find_file as robot_find_file
@@ -1152,7 +1144,6 @@ def find_library(
     command_line_variables: Optional[Dict[str, Optional[Any]]] = None,
     variables: Optional[Dict[str, Optional[Any]]] = None,
 ) -> str:
-
     return _find_library_internal(name, working_dir, base_dir, command_line_variables, variables)[0]
 
 
@@ -1189,7 +1180,6 @@ def get_library_doc(
     command_line_variables: Optional[Dict[str, Optional[Any]]] = None,
     variables: Optional[Dict[str, Optional[Any]]] = None,
 ) -> LibraryDoc:
-
     import robot.running.testlibraries
     from robot.libdocpkg.robotbuilder import KeywordDocBuilder
     from robot.output import LOGGER
@@ -1210,7 +1200,6 @@ def get_library_doc(
     def import_test_library(
         name: str,
     ) -> Union[Any, Tuple[Any, str]]:
-
         with OutputCapturer(library_import=True):
             importer = Importer("test library", LOGGER)
             return importer.import_class_or_module(name, return_source=True)
@@ -1333,7 +1322,6 @@ def get_library_doc(
 
         if lib is not None:
             try:
-
                 libdoc.has_listener = lib.has_listener
 
                 if isinstance(lib, robot.running.testlibraries._ModuleLibrary):
@@ -1349,7 +1337,7 @@ def get_library_doc(
                     keywords=[
                         KeywordDoc(
                             name=libdoc.name,
-                            args=list(KeywordArgumentDoc.from_robot(a) for a in kw[0].args),
+                            args=[KeywordArgumentDoc.from_robot(a) for a in kw[0].args],
                             doc=kw[0].doc,
                             tags=list(kw[0].tags),
                             source=kw[0].source,
@@ -1392,7 +1380,7 @@ def get_library_doc(
                     keywords=[
                         KeywordDoc(
                             name=kw[0].name,
-                            args=list(KeywordArgumentDoc.from_robot(a) for a in kw[0].args),
+                            args=[KeywordArgumentDoc.from_robot(a) for a in kw[0].args],
                             doc=kw[0].doc,
                             tags=list(kw[0].tags),
                             source=kw[0].source,
@@ -1496,15 +1484,15 @@ def find_variables(
 ) -> str:
     if get_robot_version() >= (5, 0):
         return _find_variables_internal(name, working_dir, base_dir, command_line_variables, variables)[0]
-    else:
-        return find_file(
-            name,
-            working_dir,
-            base_dir,
-            command_line_variables,
-            variables,
-            file_type="Variables",
-        )
+
+    return find_file(
+        name,
+        working_dir,
+        base_dir,
+        command_line_variables,
+        variables,
+        file_type="Variables",
+    )
 
 
 def get_variables_doc(
@@ -1525,7 +1513,6 @@ def get_variables_doc(
     source: Optional[str] = None
     try:
         with _std_capture() as std_capturer:
-
             import_name = find_variables(name, working_dir, base_dir, command_line_variables, variables)
 
             if import_name.lower().endswith((".yaml", ".yml")):
@@ -1646,9 +1633,7 @@ class CompleteResult(NamedTuple):
 
 
 def is_file_like(name: Optional[str]) -> bool:
-    return name is not None and (
-        name.startswith(".") or name.startswith("/") or name.startswith(os.sep) or "/" in name or os.sep in name
-    )
+    return name is not None and (name.startswith((".", "/", os.sep)) or "/" in name or os.sep in name)
 
 
 def iter_module_names(name: Optional[str] = None) -> Iterator[str]:
@@ -1713,7 +1698,6 @@ def complete_library_import(
     command_line_variables: Optional[Dict[str, Optional[Any]]] = None,
     variables: Optional[Dict[str, Optional[Any]]] = None,
 ) -> Optional[List[CompleteResult]]:
-
     _update_env(working_dir)
 
     result: List[CompleteResult] = []
@@ -1731,9 +1715,9 @@ def complete_library_import(
         name = robot_variables.replace_string(name.replace("\\", "\\\\"), ignore_errors=True)
 
     if name is None or not name.startswith((".", "/", os.sep)):
-        result += [e for e in iter_modules_from_python_path(name)]
+        result += list(iter_modules_from_python_path(name))
 
-    if name is None or (is_file_like(name) and (name.endswith("/") or name.endswith(os.sep))):
+    if name is None or (is_file_like(name) and (name.endswith(("/", os.sep)))):
         name_path = Path(name if name else base_dir)
         if name_path.is_absolute():
             path = name_path.resolve()
@@ -1778,7 +1762,6 @@ def complete_resource_import(
     command_line_variables: Optional[Dict[str, Optional[Any]]] = None,
     variables: Optional[Dict[str, Optional[Any]]] = None,
 ) -> Optional[List[CompleteResult]]:
-
     _update_env(working_dir)
 
     result: List[CompleteResult] = []
@@ -1789,9 +1772,9 @@ def complete_resource_import(
         name = robot_variables.replace_string(name.replace("\\", "\\\\"), ignore_errors=True)
 
     if name is None or not name.startswith(".") and not name.startswith("/") and not name.startswith(os.sep):
-        result += [e for e in iter_resources_from_python_path(name)]
+        result += list(iter_resources_from_python_path(name))
 
-    if name is None or name.startswith(".") or name.startswith("/") or name.startswith(os.sep):
+    if name is None or name.startswith((".", "/", os.sep)):
         name_path = Path(name if name else base_dir)
         if name_path.is_absolute():
             path = name_path.resolve()
@@ -1865,7 +1848,6 @@ def complete_variables_import(
     command_line_variables: Optional[Dict[str, Optional[Any]]] = None,
     variables: Optional[Dict[str, Optional[Any]]] = None,
 ) -> Optional[List[CompleteResult]]:
-
     _update_env(working_dir)
 
     result: List[CompleteResult] = []
@@ -1876,9 +1858,9 @@ def complete_variables_import(
         name = robot_variables.replace_string(name.replace("\\", "\\\\"), ignore_errors=True)
 
     if name is None or not name.startswith(".") and not name.startswith("/") and not name.startswith(os.sep):
-        result += [e for e in iter_variables_from_python_path(name)]
+        result += list(iter_variables_from_python_path(name))
 
-    if name is None or name.startswith(".") or name.startswith("/") or name.startswith(os.sep):
+    if name is None or name.startswith((".", "/", os.sep)):
         name_path = Path(name if name else base_dir)
         if name_path.is_absolute():
             path = name_path.resolve()
