@@ -14,10 +14,10 @@ from itertools import chain
 from pathlib import Path
 from typing import (
     Any,
-    AsyncGenerator,
+    AsyncIterator,
     Dict,
-    Generator,
     Iterable,
+    Iterator,
     List,
     NamedTuple,
     Optional,
@@ -126,7 +126,6 @@ class VariablesVisitor(Visitor):
         name = name_token.value
 
         if name is not None:
-
             match = search_variable(name, ignore_errors=True)
             if not match.is_assign(allow_assign_mark=True):
                 return
@@ -171,7 +170,6 @@ class BlockVariableVisitor(Visitor):
         self.current_kw_doc: Optional[KeywordDoc] = None
 
     def get(self, model: ast.AST) -> List[VariableDefinition]:
-
         self._results = {}
 
         self.visit(model)
@@ -180,7 +178,7 @@ class BlockVariableVisitor(Visitor):
 
     def visit(self, node: ast.AST) -> None:
         if self.position is None or self.position >= range_from_node(node).start:
-            return super().visit(node)
+            super().visit(node)
 
     def visit_Keyword(self, node: ast.AST) -> None:  # noqa: N802
         try:
@@ -199,7 +197,6 @@ class BlockVariableVisitor(Visitor):
         name_token = cast(Token, n.get_token(RobotToken.KEYWORD_NAME))
 
         if name_token is not None and name_token.value:
-
             keyword = ModelHelperMixin.get_keyword_definition_at_token(self.library_doc, name_token)
             self.current_kw_doc = keyword
 
@@ -208,7 +205,6 @@ class BlockVariableVisitor(Visitor):
                 tokenize_variables(name_token, identifiers="$", ignore_errors=True),
             ):
                 if variable_token.value:
-
                     match = search_variable(variable_token.value, "$", ignore_errors=True)
                     if match.base is None:
                         continue
@@ -478,9 +474,7 @@ class ImportVisitor(Visitor):
 
     def visit_VariablesImport(self, node: ast.AST) -> None:  # noqa: N802
         from robot.parsing.lexer.tokens import Token as RobotToken
-        from robot.parsing.model.statements import (
-            VariablesImport as RobotVariablesImport,
-        )
+        from robot.parsing.model.statements import VariablesImport as RobotVariablesImport
 
         n = cast(RobotVariablesImport, node)
         name = cast(RobotToken, n.get_token(RobotToken.NAME))
@@ -531,13 +525,13 @@ class LibraryEntry:
 
 @dataclass
 class ResourceEntry(LibraryEntry):
-    imports: List[Import] = field(default_factory=lambda: [])
-    variables: List[VariableDefinition] = field(default_factory=lambda: [])
+    imports: List[Import] = field(default_factory=list)
+    variables: List[VariableDefinition] = field(default_factory=list)
 
 
 @dataclass
 class VariablesEntry(LibraryEntry):
-    variables: List[ImportedVariableDefinition] = field(default_factory=lambda: [])
+    variables: List[ImportedVariableDefinition] = field(default_factory=list)
 
 
 class DocumentType(enum.Enum):
@@ -641,30 +635,51 @@ class Namespace:
 
     @_logger.call
     async def libraries_changed(self, sender: Any, libraries: List[LibraryDoc]) -> None:
-        for p in libraries:
-            if any(e for e in self._libraries.values() if e.library_doc == p):
-                if self.document is not None:
-                    self.document.set_data(Namespace.DataEntry, None)
-                await self.invalidate()
-                break
+        invalidate = False
+
+        async with self._initialize_lock, self._library_doc_lock, self._analyze_lock:
+            for p in libraries:
+                if any(e for e in self._libraries.values() if e.library_doc == p):
+                    invalidate = True
+                    break
+
+        if invalidate:
+            if self.document is not None:
+                self.document.set_data(Namespace.DataEntry, None)
+
+            await self.invalidate()
 
     @_logger.call
     async def resources_changed(self, sender: Any, resources: List[LibraryDoc]) -> None:
-        for p in resources:
-            if any(e for e in self._resources.values() if e.library_doc.source == p.source):
-                if self.document is not None:
-                    self.document.set_data(Namespace.DataEntry, None)
-                await self.invalidate()
-                break
+        invalidate = False
+
+        async with self._initialize_lock, self._library_doc_lock, self._analyze_lock:
+            for p in resources:
+                if any(e for e in self._resources.values() if e.library_doc.source == p.source):
+                    invalidate = True
+                    break
+
+        if invalidate:
+            if self.document is not None:
+                self.document.set_data(Namespace.DataEntry, None)
+
+            await self.invalidate()
 
     @_logger.call
     async def variables_changed(self, sender: Any, variables: List[LibraryDoc]) -> None:
-        for p in variables:
-            if any(e for e in self._variables.values() if e.library_doc.source == p.source):
-                if self.document is not None:
-                    self.document.set_data(Namespace.DataEntry, None)
-                await self.invalidate()
-                break
+        invalidate = False
+
+        async with self._initialize_lock, self._library_doc_lock, self._analyze_lock:
+            for p in variables:
+                if any(e for e in self._variables.values() if e.library_doc.source == p.source):
+                    invalidate = True
+                    break
+
+        if invalidate:
+            if self.document is not None:
+                self.document.set_data(Namespace.DataEntry, None)
+
+            await self.invalidate()
 
     async def is_initialized(self) -> bool:
         async with self._initialize_lock:
@@ -759,7 +774,7 @@ class Namespace:
     async def get_library_doc(self) -> LibraryDoc:
         async with self._library_doc_lock:
             if self._library_doc is None:
-                self._library_doc = await self.imports_manager.get_libdoc_from_model(
+                self._library_doc = self.imports_manager.get_libdoc_from_model(
                     self.model,
                     self.source,
                     model_type="RESOURCE",
@@ -784,14 +799,13 @@ class Namespace:
 
         async with self._initialize_lock:
             if not self._initialized:
-
                 if self._in_initialize:
-                    self._logger.critical(f"already initialized {self.document}")
+                    self._logger.critical(lambda: f"already initialized {self.document}")
 
                 self._in_initialize = True
 
                 try:
-                    self._logger.debug(f"ensure_initialized -> initialize {self.document}")
+                    self._logger.debug(lambda: f"ensure_initialized -> initialize {self.document}")
 
                     imports = self.get_imports()
 
@@ -799,7 +813,7 @@ class Namespace:
                     if self.document is not None:
                         # check or save several data in documents data cache,
                         # if imports are different, then the data is invalid
-                        old_imports: List[Import] = self.document.get_data(Namespace)
+                        old_imports: Optional[List[Import]] = self.document.get_data(Namespace)
                         if old_imports is None:
                             self.document.set_data(Namespace, imports)
                         elif old_imports != imports:
@@ -922,7 +936,7 @@ class Namespace:
         nodes: Optional[List[ast.AST]] = None,
         position: Optional[Position] = None,
         skip_commandline_variables: bool = False,
-    ) -> AsyncGenerator[Tuple[VariableMatcher, VariableDefinition], None]:
+    ) -> AsyncIterator[Tuple[VariableMatcher, VariableDefinition]]:
         from robot.parsing.model.blocks import Keyword, TestCase
         from robot.parsing.model.statements import Arguments
 
@@ -981,7 +995,6 @@ class Namespace:
         skip_commandline_variables: bool = False,
         ignore_error: bool = False,
     ) -> Optional[VariableDefinition]:
-
         await self.ensure_initialized()
 
         if name[:2] == "%{" and name[-1] == "}":
@@ -1095,7 +1108,6 @@ class Namespace:
                             )
 
                 elif isinstance(value, VariablesImport):
-
                     if value.name is None:
                         raise NameSpaceError("Variables setting requires value.")
 
@@ -1188,7 +1200,6 @@ class Namespace:
         current_time = time.monotonic()
         self._logger.debug(lambda: f"start imports for {self.document if top_level else source}")
         try:
-
             for imp in imports:
                 if variables is None:
                     variables = await self.get_resolvable_variables()
@@ -1348,7 +1359,7 @@ class Namespace:
         finally:
             self._logger.debug(
                 lambda: "end import imports for "
-                + f"{self.document if top_level else source} in {time.monotonic() - current_time}s"
+                f"{self.document if top_level else source} in {time.monotonic() - current_time}s"
             )
 
     async def _import_default_libraries(self, variables: Optional[Dict[str, Any]] = None) -> None:
@@ -1390,7 +1401,6 @@ class Namespace:
         sentinel: Any = None,
         variables: Optional[Dict[str, Any]] = None,
     ) -> LibraryEntry:
-
         library_doc = await self.imports_manager.get_libdoc_for_library_import(
             name,
             args,
@@ -1496,7 +1506,7 @@ class Namespace:
             return self._imported_keywords
 
     @_logger.call
-    async def iter_all_keywords(self) -> AsyncGenerator[KeywordDoc, None]:
+    async def iter_all_keywords(self) -> AsyncIterator[KeywordDoc]:
         import itertools
 
         libdoc = await self.get_library_doc()
@@ -1511,7 +1521,6 @@ class Namespace:
     async def get_keywords(self) -> List[KeywordDoc]:
         async with self._keywords_lock:
             if self._keywords is None:
-
                 current_time = time.monotonic()
                 self._logger.debug("start collecting keywords")
                 try:
@@ -1621,7 +1630,6 @@ class Namespace:
 
     async def get_finder(self) -> KeywordFinder:
         if self._finder is None:
-
             self._finder = await self.create_finder()
         return self._finder
 
@@ -1646,11 +1654,9 @@ class Namespace:
         result = []
         lines = document.get_lines()
         for line_no, line in enumerate(lines):
-
             comment = EXTRACT_COMMENT_PATTERN.match(line)
             if comment and comment.group("comment"):
                 for match in ROBOTCODE_PATTERN.finditer(comment.group("comment")):
-
                     if match.group("rule") == "ignore":
                         result.append(line_no)
 
@@ -1670,11 +1676,7 @@ class Namespace:
     def __should_ignore(lines: List[int], range: Range) -> bool:
         import builtins
 
-        for line_no in builtins.range(range.start.line, range.end.line + 1):
-            if line_no in lines:
-                return True
-
-        return False
+        return any(line_no in lines for line_no in builtins.range(range.start.line, range.end.line + 1))
 
 
 class DiagnosticsEntry(NamedTuple):
@@ -1718,27 +1720,27 @@ class KeywordFinder:
             if cached is not None:
                 self.diagnostics = cached[1]
                 return cached[0]
-            else:
-                try:
-                    result = self._find_keyword(name)
-                    if result is None:
-                        self.diagnostics.append(
-                            DiagnosticsEntry(
-                                f"No keyword with name {repr(name)} found.",
-                                DiagnosticSeverity.ERROR,
-                                "KeywordNotFoundError",
-                            )
+
+            try:
+                result = self._find_keyword(name)
+                if result is None:
+                    self.diagnostics.append(
+                        DiagnosticsEntry(
+                            f"No keyword with name {repr(name)} found.",
+                            DiagnosticSeverity.ERROR,
+                            "KeywordNotFoundError",
                         )
-                except KeywordError as e:
-                    if raise_keyword_error:
-                        raise
+                    )
+            except KeywordError as e:
+                if raise_keyword_error:
+                    raise
 
-                    result = None
-                    self.diagnostics.append(DiagnosticsEntry(str(e), DiagnosticSeverity.ERROR, "KeywordError"))
+                result = None
+                self.diagnostics.append(DiagnosticsEntry(str(e), DiagnosticSeverity.ERROR, "KeywordError"))
 
-                self._cache[(name, self.handle_bdd_style)] = (result, self.diagnostics)
+            self._cache[(name, self.handle_bdd_style)] = (result, self.diagnostics)
 
-                return result
+            return result
         except CancelSearchError:
             return None
 
@@ -1747,12 +1749,12 @@ class KeywordFinder:
             self.diagnostics.append(
                 DiagnosticsEntry("Keyword name cannot be empty.", DiagnosticSeverity.ERROR, "KeywordError")
             )
-            raise CancelSearchError()
+            raise CancelSearchError
         if not isinstance(name, str):
-            self.diagnostics.append(
+            self.diagnostics.append(  # type: ignore
                 DiagnosticsEntry("Keyword name must be a string.", DiagnosticSeverity.ERROR, "KeywordError")
             )
-            raise CancelSearchError()
+            raise CancelSearchError
 
         result = self._get_keyword_from_self(name)
         if not result and "." in name:
@@ -1762,7 +1764,7 @@ class KeywordFinder:
             result = self._get_implicit_keyword(name)
 
         if not result and self.handle_bdd_style:
-            result = self._get_bdd_style_keyword(name)
+            return self._get_bdd_style_keyword(name)
 
         return result
 
@@ -1781,27 +1783,27 @@ class KeywordFinder:
                             "KeywordError",
                         )
                     )
-                    raise CancelSearchError()
+                    raise CancelSearchError
 
             if len(found) == 1:
                 # TODO warning if keyword found is defined in resource and suite
                 return found[0][1]
 
             return None
-        else:
-            try:
-                return self.self_library_doc.keywords.get(name, None)
-            except KeywordError as e:
-                self.diagnostics.append(
-                    DiagnosticsEntry(
-                        str(e),
-                        DiagnosticSeverity.ERROR,
-                        "KeywordError",
-                    )
-                )
-                raise CancelSearchError() from e
 
-    def _yield_owner_and_kw_names(self, full_name: str) -> Generator[Tuple[str, ...], None, None]:
+        try:
+            return self.self_library_doc.keywords.get(name, None)
+        except KeywordError as e:
+            self.diagnostics.append(
+                DiagnosticsEntry(
+                    str(e),
+                    DiagnosticSeverity.ERROR,
+                    "KeywordError",
+                )
+            )
+            raise CancelSearchError from e
+
+    def _yield_owner_and_kw_names(self, full_name: str) -> Iterator[Tuple[str, ...]]:
         tokens = full_name.split(".")
         for i in range(1, len(tokens)):
             yield ".".join(tokens[:i]), ".".join(tokens[i:])
@@ -1822,15 +1824,13 @@ class KeywordFinder:
                     "KeywordError",
                 )
             )
-            raise CancelSearchError()
+            raise CancelSearchError
 
         return found[0][1] if found else None
 
     def find_keywords(self, owner_name: str, name: str) -> List[Tuple[LibraryEntry, KeywordDoc]]:
         if self._all_keywords is None:
-            self._all_keywords = [
-                v for v in chain(self.namespace._libraries.values(), self.namespace._resources.values())
-            ]
+            self._all_keywords = list(chain(self.namespace._libraries.values(), self.namespace._resources.values()))
 
         if get_robot_version() >= (6, 0, 0):
             result: List[Tuple[LibraryEntry, KeywordDoc]] = []
@@ -1838,14 +1838,14 @@ class KeywordFinder:
                 if eq(v.alias or v.name, owner_name):
                     result.extend((v, kw) for kw in v.library_doc.keywords.get_all(name))
             return result
-        else:
-            result = []
-            for v in self._all_keywords:
-                if eq(v.alias or v.name, owner_name):
-                    kw = v.library_doc.keywords.get(name, None)
-                    if kw is not None:
-                        result.append((v, kw))
-            return result
+
+        result = []
+        for v in self._all_keywords:
+            if eq(v.alias or v.name, owner_name):
+                kw = v.library_doc.keywords.get(name, None)
+                if kw is not None:
+                    result.append((v, kw))
+        return result
 
     def _create_multiple_keywords_found_message(
         self, name: str, found: Sequence[Tuple[Optional[LibraryEntry], KeywordDoc]], implicit: bool = True
@@ -1859,18 +1859,17 @@ class KeywordFinder:
                 error += ". Give the full name of the keyword you want to use"
 
         names = sorted(f"{e[1].name if e[0] is None else f'{e[0].alias or e[0].name}.{e[1].name}'}" for e in found)
-        return "\n    ".join([error + ":"] + names)
+        return "\n    ".join([f"{error}:", *names])
 
     def _get_implicit_keyword(self, name: str) -> Optional[KeywordDoc]:
         result = self._get_keyword_from_resource_files(name)
         if not result:
-            result = self._get_keyword_from_libraries(name)
+            return self._get_keyword_from_libraries(name)
         return result
 
     def _prioritize_same_file_or_public(
         self, entries: List[Tuple[Optional[LibraryEntry], KeywordDoc]]
     ) -> List[Tuple[Optional[LibraryEntry], KeywordDoc]]:
-
         matches = [h for h in entries if h[1].source == self.namespace.source]
         if matches:
             return matches
@@ -1882,7 +1881,6 @@ class KeywordFinder:
     def _select_best_matches(
         self, entries: List[Tuple[Optional[LibraryEntry], KeywordDoc]]
     ) -> List[Tuple[Optional[LibraryEntry], KeywordDoc]]:
-
         normal = [hand for hand in entries if not hand[1].is_embedded]
         if normal:
             return normal
@@ -1914,7 +1912,7 @@ class KeywordFinder:
 
     def _get_keyword_from_resource_files(self, name: str) -> Optional[KeywordDoc]:
         if self._resource_keywords is None:
-            self._resource_keywords = [v for v in chain(self.namespace._resources.values())]
+            self._resource_keywords = list(chain(self.namespace._resources.values()))
 
         if get_robot_version() >= (6, 0, 0):
             found: List[Tuple[Optional[LibraryEntry], KeywordDoc]] = []
@@ -1956,12 +1954,11 @@ class KeywordFinder:
                 "KeywordError",
             )
         )
-        raise CancelSearchError()
+        raise CancelSearchError
 
     def _get_keyword_based_on_search_order(
         self, entries: List[Tuple[Optional[LibraryEntry], KeywordDoc]]
     ) -> List[Tuple[Optional[LibraryEntry], KeywordDoc]]:
-
         for libname in self.namespace.search_order:
             for e in entries:
                 if e[0] is not None and eq(libname, e[0].alias or e[0].name):
@@ -1971,7 +1968,7 @@ class KeywordFinder:
 
     def _get_keyword_from_libraries(self, name: str) -> Optional[KeywordDoc]:
         if self._library_keywords is None:
-            self._library_keywords = [v for v in chain(self.namespace._libraries.values())]
+            self._library_keywords = list(chain(self.namespace._libraries.values()))
 
         if get_robot_version() >= (6, 0, 0):
             found: List[Tuple[Optional[LibraryEntry], KeywordDoc]] = []
@@ -2011,7 +2008,7 @@ class KeywordFinder:
                 "KeywordError",
             )
         )
-        raise CancelSearchError()
+        raise CancelSearchError
 
     def _filter_stdlib_runner(
         self, entry1: Tuple[Optional[LibraryEntry], KeywordDoc], entry2: Tuple[Optional[LibraryEntry], KeywordDoc]
@@ -2059,19 +2056,16 @@ class KeywordFinder:
             lower = name.lower()
             for prefix in ["given ", "when ", "then ", "and ", "but "]:
                 if lower.startswith(prefix):
-                    return self._find_keyword(name[len(prefix) :])  # noqa: E203
+                    return self._find_keyword(name[len(prefix) :])
             return None
 
-        else:
-            parts = name.split()
-            if len(parts) < 2:
-                return None
-            for index in range(1, len(parts)):
-                prefix = " ".join(parts[:index]).title()
-                if prefix.title() in (
-                    self.namespace.languages.bdd_prefixes
-                    if self.namespace.languages is not None
-                    else DEFAULT_BDD_PREFIXES
-                ):
-                    return self._find_keyword(" ".join(parts[index:]))
+        parts = name.split()
+        if len(parts) < 2:
             return None
+        for index in range(1, len(parts)):
+            prefix = " ".join(parts[:index]).title()
+            if prefix.title() in (
+                self.namespace.languages.bdd_prefixes if self.namespace.languages is not None else DEFAULT_BDD_PREFIXES
+            ):
+                return self._find_keyword(" ".join(parts[index:]))
+        return None
