@@ -8,7 +8,7 @@ import os
 from typing import (
     TYPE_CHECKING,
     Any,
-    AsyncGenerator,
+    AsyncIterator,
     Awaitable,
     Callable,
     Dict,
@@ -111,11 +111,7 @@ class RobotCompletionProtocolPart(RobotLanguageServerProtocolPart):
     async def collect(
         self, sender: Any, document: TextDocument, position: Position, context: Optional[CompletionContext]
     ) -> Union[List[CompletionItem], CompletionList, None]:
-
         namespace = await self.parent.documents_cache.get_namespace(document)
-        if namespace is None:
-            return None
-
         model = await self.parent.documents_cache.get_model(document, False)
 
         config = await self.get_config(document)
@@ -245,7 +241,7 @@ class CompletionCollector(ModelHelperMixin):
         self.namespace = namespace
         self.config = config
 
-    async def _find_methods(self, cls: Type[Any]) -> AsyncGenerator[_CompleteMethod, None]:
+    async def _find_methods(self, cls: Type[Any]) -> AsyncIterator[_CompleteMethod]:
         if cls is ast.AST:
             return
 
@@ -264,12 +260,11 @@ class CompletionCollector(ModelHelperMixin):
     async def collect(
         self, position: Position, context: Optional[CompletionContext]
     ) -> Union[List[CompletionItem], CompletionList, None]:
-
         result_nodes = await get_nodes_at_position(self.model, position)
 
         result_nodes.reverse()
 
-        async def iter_results() -> AsyncGenerator[List[CompletionItem], None]:
+        async def iter_results() -> AsyncIterator[List[CompletionItem]]:
             for result_node in result_nodes:
                 async for method in self._find_methods(type(result_node)):
                     r = await method(result_node, result_nodes, position, context)
@@ -340,7 +335,6 @@ class CompletionCollector(ModelHelperMixin):
                                 pass
 
                     elif comp_type in [CompleteResultKind.RESOURCE.name]:
-
                         if (res_id := data.get("id", None)) is not None:
                             try:
                                 lib_doc = next(
@@ -427,7 +421,7 @@ class CompletionCollector(ModelHelperMixin):
                 if self.namespace.languages is not None
                 else None,
                 sort_text=f"100_{s[1]}",
-                insert_text_format=InsertTextFormat.PLAINTEXT,
+                insert_text_format=InsertTextFormat.PLAIN_TEXT,
                 text_edit=TextEdit(
                     range=range,
                     new_text=s[0],
@@ -445,7 +439,7 @@ class CompletionCollector(ModelHelperMixin):
                 kind=CompletionItemKind.VARIABLE,
                 detail="Variable",
                 sort_text=f"035_{s}",
-                insert_text_format=InsertTextFormat.PLAINTEXT,
+                insert_text_format=InsertTextFormat.PLAIN_TEXT,
                 text_edit=TextEdit(
                     range=range,
                     new_text=s,
@@ -469,16 +463,13 @@ class CompletionCollector(ModelHelperMixin):
     async def create_variables_completion_items(
         self, range: Range, nodes: List[ast.AST], position: Position
     ) -> List[CompletionItem]:
-        if self.document is None:
-            return []
-
         return [
             CompletionItem(
                 label=s.name,
                 kind=CompletionItemKind.VARIABLE,
                 detail=f"{s.type.value}",
                 sort_text=f"{self._VARIABLE_COMPLETION_SORT_TEXT_PREFIX.get(s.type, '035')}_{s.name[2:-1]}",
-                insert_text_format=InsertTextFormat.PLAINTEXT,
+                insert_text_format=InsertTextFormat.PLAIN_TEXT,
                 text_edit=TextEdit(
                     range=range,
                     new_text=s.name[2:-1],
@@ -507,7 +498,6 @@ class CompletionCollector(ModelHelperMixin):
         settings = {*settings_class.names, *settings_class.aliases.keys()}
 
         if self.namespace.languages is not None:
-
             if self.config.filter_default_language and len(self.namespace.languages.languages) > 1:
                 languages = self.namespace.languages.languages
 
@@ -529,7 +519,7 @@ class CompletionCollector(ModelHelperMixin):
                 if self.namespace.languages is not None
                 else None,
                 sort_text=f"090_{setting}",
-                insert_text_format=InsertTextFormat.PLAINTEXT,
+                insert_text_format=InsertTextFormat.PLAIN_TEXT,
                 text_edit=TextEdit(range=range, new_text=setting) if range is not None else None,
             )
             for setting in settings
@@ -555,7 +545,6 @@ class CompletionCollector(ModelHelperMixin):
         settings = {*TestCaseSettings.names, *TestCaseSettings.aliases.keys()}
 
         if self.namespace.languages is not None:
-
             if self.config.filter_default_language and len(self.namespace.languages.languages) > 1:
                 languages = self.namespace.languages.languages
 
@@ -577,7 +566,7 @@ class CompletionCollector(ModelHelperMixin):
                 else None,
                 detail="Setting",
                 sort_text=f"070_{setting}",
-                insert_text_format=InsertTextFormat.PLAINTEXT,
+                insert_text_format=InsertTextFormat.PLAIN_TEXT,
                 text_edit=TextEdit(range=range, new_text=f"[{setting}]") if range is not None else None,
             )
             for setting in settings
@@ -595,7 +584,7 @@ class CompletionCollector(ModelHelperMixin):
                 kind=CompletionItemKind.UNIT,
                 detail="BDD Prefix",
                 sort_text=f"080_{prefix}",
-                insert_text_format=InsertTextFormat.PLAINTEXT,
+                insert_text_format=InsertTextFormat.PLAIN_TEXT,
                 text_edit=TextEdit(range=range, new_text=f"{prefix} ") if range is not None else None,
             )
             for prefix in prefixes
@@ -607,7 +596,6 @@ class CompletionCollector(ModelHelperMixin):
         settings = {*KeywordSettings.names, *KeywordSettings.aliases.keys()}
 
         if self.namespace.languages is not None:
-
             if self.config.filter_default_language and len(self.namespace.languages.languages) > 1:
                 languages = self.namespace.languages.languages
 
@@ -629,7 +617,7 @@ class CompletionCollector(ModelHelperMixin):
                 else None,
                 detail="Setting",
                 sort_text=f"070_{setting}",
-                insert_text_format=InsertTextFormat.PLAINTEXT,
+                insert_text_format=InsertTextFormat.PLAIN_TEXT,
                 text_edit=TextEdit(range=range, new_text=f"[{setting}]") if range is not None else None,
             )
             for setting in settings
@@ -675,8 +663,6 @@ class CompletionCollector(ModelHelperMixin):
         add_bdd_prefixes: bool = True,
     ) -> List[CompletionItem]:
         result: List[CompletionItem] = []
-        if self.document is None:
-            return []
 
         r: Optional[Range] = None
 
@@ -713,7 +699,7 @@ class CompletionCollector(ModelHelperMixin):
                         lib_name_index = e
 
                 if lib_name_index >= 0:
-                    library_name = token.value[0 : lib_name_index - r.start.character]  # noqa: E203
+                    library_name = token.value[0 : lib_name_index - r.start.character]
 
                     libraries = await self.namespace.get_libraries()
 
@@ -734,7 +720,7 @@ class CompletionCollector(ModelHelperMixin):
                                     detail=f"{CompleteResultKind.KEYWORD.value} "
                                     f"{f'({kw.libname})' if kw.libname is not None else ''}",
                                     sort_text=f"020_{kw.name}",
-                                    insert_text_format=InsertTextFormat.PLAINTEXT
+                                    insert_text_format=InsertTextFormat.PLAIN_TEXT
                                     if not kw.is_embedded
                                     else InsertTextFormat.SNIPPET,
                                     text_edit=TextEdit(
@@ -776,7 +762,7 @@ class CompletionCollector(ModelHelperMixin):
                                         detail=f"{CompleteResultKind.KEYWORD.value} "
                                         f"{f'({kw.libname})' if kw.libname is not None else ''}",
                                         sort_text=f"020_{kw.name}",
-                                        insert_text_format=InsertTextFormat.PLAINTEXT
+                                        insert_text_format=InsertTextFormat.PLAIN_TEXT
                                         if not kw.is_embedded
                                         else InsertTextFormat.SNIPPET,
                                         text_edit=TextEdit(
@@ -812,7 +798,7 @@ class CompletionCollector(ModelHelperMixin):
                     detail=f"{CompleteResultKind.KEYWORD.value} {f'({kw.libname})' if kw.libname is not None else ''}",
                     deprecated=kw.is_deprecated,
                     sort_text=f"020_{kw.name}",
-                    insert_text_format=InsertTextFormat.PLAINTEXT if not kw.is_embedded else InsertTextFormat.SNIPPET,
+                    insert_text_format=InsertTextFormat.PLAIN_TEXT if not kw.is_embedded else InsertTextFormat.SNIPPET,
                     text_edit=TextEdit(
                         range=r,
                         new_text=kw.name if not kw.is_embedded else self.get_keyword_snipped_text(kw, in_template),
@@ -836,7 +822,7 @@ class CompletionCollector(ModelHelperMixin):
                     detail="Library",
                     sort_text=f"030_{v.name}",
                     deprecated=v.library_doc.is_deprecated,
-                    insert_text_format=InsertTextFormat.PLAINTEXT,
+                    insert_text_format=InsertTextFormat.PLAIN_TEXT,
                     text_edit=TextEdit(range=r, new_text=k),
                     data=CompletionItemImportData(
                         document_uri=str(self.document.uri),
@@ -859,7 +845,7 @@ class CompletionCollector(ModelHelperMixin):
                     detail="Resource",
                     deprecated=v.library_doc.is_deprecated,
                     sort_text=f"030_{v.name}",
-                    insert_text_format=InsertTextFormat.PLAINTEXT,
+                    insert_text_format=InsertTextFormat.PLAIN_TEXT,
                     text_edit=TextEdit(range=r, new_text=v.name),
                     data=CompletionItemImportData(
                         document_uri=str(self.document.uri),
@@ -880,7 +866,7 @@ class CompletionCollector(ModelHelperMixin):
                     label="NONE",
                     kind=CompletionItemKind.KEYWORD,
                     sort_text="998_NONE",
-                    insert_text_format=InsertTextFormat.PLAINTEXT,
+                    insert_text_format=InsertTextFormat.PLAIN_TEXT,
                     text_edit=TextEdit(range=r, new_text="NONE"),
                 )
             )
@@ -897,7 +883,7 @@ class CompletionCollector(ModelHelperMixin):
                         label=k,
                         kind=CompletionItemKind.KEYWORD,
                         sort_text=f"999_{k}",
-                        insert_text_format=InsertTextFormat.PLAINTEXT,
+                        insert_text_format=InsertTextFormat.PLAIN_TEXT,
                         text_edit=TextEdit(range=r, new_text=k),
                     )
                 )
@@ -941,7 +927,7 @@ class CompletionCollector(ModelHelperMixin):
                     and (only_stars or value.startswith("*") or position.character == 0)
                 ):
                     return await self.create_headers_completion_items(r)
-                elif len(statement_node.tokens) > 1 and only_stars:
+                if len(statement_node.tokens) > 1 and only_stars:
                     r1 = range_from_token(statement_node.tokens[1])
                     ws = whitespace_at_begin_of_token(statement_node.tokens[1])
                     if ws > 0:
@@ -1026,7 +1012,7 @@ class CompletionCollector(ModelHelperMixin):
         # TODO should this be configurable?
         if (
             context is not None
-            and context.trigger_kind == CompletionTriggerKind.TRIGGERCHARACTER
+            and context.trigger_kind == CompletionTriggerKind.TRIGGER_CHARACTER
             and context.trigger_character in [" ", "\t"]
         ):
             return None
@@ -1059,7 +1045,7 @@ class CompletionCollector(ModelHelperMixin):
         # TODO should this be configurable?
         if (
             context is not None
-            and context.trigger_kind == CompletionTriggerKind.TRIGGERCHARACTER
+            and context.trigger_kind == CompletionTriggerKind.TRIGGER_CHARACTER
             and context.trigger_character in [" ", "\t"]
         ):
             return None
@@ -1227,7 +1213,7 @@ class CompletionCollector(ModelHelperMixin):
         # TODO should this be configurable?
         if (
             context is not None
-            and context.trigger_kind == CompletionTriggerKind.TRIGGERCHARACTER
+            and context.trigger_kind == CompletionTriggerKind.TRIGGER_CHARACTER
             and context.trigger_character in [" ", "\t"]
         ):
             return None
@@ -1292,7 +1278,6 @@ class CompletionCollector(ModelHelperMixin):
         position: Position,
         context: Optional[CompletionContext],
     ) -> Union[List[CompletionItem], CompletionList, None]:
-
         return await self._complete_SuiteSetup_or_SuiteTeardown_or_TestTemplate(
             node, nodes_at_position, position, context
         )
@@ -1304,7 +1289,6 @@ class CompletionCollector(ModelHelperMixin):
         position: Position,
         context: Optional[CompletionContext],
     ) -> Union[List[CompletionItem], CompletionList, None]:
-
         return await self._complete_SuiteSetup_or_SuiteTeardown_or_TestTemplate(
             node, nodes_at_position, position, context
         )
@@ -1316,7 +1300,6 @@ class CompletionCollector(ModelHelperMixin):
         position: Position,
         context: Optional[CompletionContext],
     ) -> Union[List[CompletionItem], CompletionList, None]:
-
         return await self._complete_SuiteSetup_or_SuiteTeardown_or_TestTemplate(
             node, nodes_at_position, position, context
         )
@@ -1328,7 +1311,6 @@ class CompletionCollector(ModelHelperMixin):
         position: Position,
         context: Optional[CompletionContext],
     ) -> Union[List[CompletionItem], CompletionList, None]:
-
         return await self._complete_SuiteSetup_or_SuiteTeardown_or_TestTemplate(
             node, nodes_at_position, position, context
         )
@@ -1340,7 +1322,6 @@ class CompletionCollector(ModelHelperMixin):
         position: Position,
         context: Optional[CompletionContext],
     ) -> Union[List[CompletionItem], CompletionList, None]:
-
         return await self._complete_SuiteSetup_or_SuiteTeardown_or_TestTemplate(
             node, nodes_at_position, position, context
         )
@@ -1357,7 +1338,7 @@ class CompletionCollector(ModelHelperMixin):
         # TODO should this be configurable?
         if (
             context is not None
-            and context.trigger_kind == CompletionTriggerKind.TRIGGERCHARACTER
+            and context.trigger_kind == CompletionTriggerKind.TRIGGER_CHARACTER
             and context.trigger_character in [" ", "\t"]
         ):
             return None
@@ -1419,7 +1400,6 @@ class CompletionCollector(ModelHelperMixin):
         position: Position,
         context: Optional[CompletionContext],
     ) -> Union[List[CompletionItem], CompletionList, None]:
-
         return await self.complete_Setup_or_Teardown_or_Template(node, nodes_at_position, position, context)
 
     async def complete_Teardown(  # noqa: N802
@@ -1429,7 +1409,6 @@ class CompletionCollector(ModelHelperMixin):
         position: Position,
         context: Optional[CompletionContext],
     ) -> Union[List[CompletionItem], CompletionList, None]:
-
         return await self.complete_Setup_or_Teardown_or_Template(node, nodes_at_position, position, context)
 
     async def complete_Template(  # noqa: N802
@@ -1439,7 +1418,6 @@ class CompletionCollector(ModelHelperMixin):
         position: Position,
         context: Optional[CompletionContext],
     ) -> Union[List[CompletionItem], CompletionList, None]:
-
         return await self.complete_Setup_or_Teardown_or_Template(node, nodes_at_position, position, context)
 
     async def complete_LibraryImport(  # noqa: N802
@@ -1449,13 +1427,9 @@ class CompletionCollector(ModelHelperMixin):
         position: Position,
         context: Optional[CompletionContext],
     ) -> Union[List[CompletionItem], CompletionList, None]:
-
         from robot.parsing.lexer.tokens import Token as RobotToken
         from robot.parsing.model.statements import LibraryImport, Statement
 
-        if self.document is None:
-            return []
-
         import_node = cast(LibraryImport, node)
         import_token = import_node.get_token(RobotToken.LIBRARY)
         if import_token is None:
@@ -1467,9 +1441,6 @@ class CompletionCollector(ModelHelperMixin):
         import_token_index = import_node.tokens.index(import_token)
 
         async def complete_import() -> Optional[List[CompletionItem]]:
-            if self.document is None:
-                return None
-
             if len(import_node.tokens) > import_token_index + 2:
                 name_token = import_node.tokens[import_token_index + 2]
                 if not position.is_in_range(r := range_from_token(name_token)):
@@ -1479,7 +1450,6 @@ class CompletionCollector(ModelHelperMixin):
                 name_token = import_node.tokens[import_token_index + 1]
                 if position.is_in_range(r := range_from_token(name_token)):
                     if whitespace_at_begin_of_token(name_token) > 1:
-
                         ws_b = whitespace_from_begin_of_token(name_token)
                         r.start.character += 2 if ws_b and ws_b[0] != "\t" else 1
 
@@ -1543,7 +1513,7 @@ class CompletionCollector(ModelHelperMixin):
                     else None,
                     detail=e.kind.value,
                     sort_text=f"030_{e}",
-                    insert_text_format=InsertTextFormat.PLAINTEXT,
+                    insert_text_format=InsertTextFormat.PLAIN_TEXT,
                     text_edit=TextEdit(range=r, new_text=e.label) if r is not None else None,
                     data=CompletionItemData(
                         document_uri=str(self.document.uri),
@@ -1555,9 +1525,6 @@ class CompletionCollector(ModelHelperMixin):
             ]
 
         async def complete_arguments() -> Optional[List[CompletionItem]]:
-            if self.document is None:
-                return None
-
             if (
                 import_node.name is None
                 or position <= range_from_token(import_node.get_token(RobotToken.NAME)).extend(end_character=1).end
@@ -1612,8 +1579,8 @@ class CompletionCollector(ModelHelperMixin):
                     equal_index = (argument_token or token_at_position).value.index("=")
                     if completion_range.start.character + equal_index < position.character:
                         return None
-                    else:
-                        completion_range.end.character = completion_range.start.character + equal_index + 1
+
+                    completion_range.end.character = completion_range.start.character + equal_index + 1
                 else:
                     completion_range.end = position
 
@@ -1638,7 +1605,7 @@ class CompletionCollector(ModelHelperMixin):
                             kind=CompletionItemKind.VARIABLE,
                             sort_text=f"010{i}_{e.name}",
                             filter_text=e.name,
-                            insert_text_format=InsertTextFormat.PLAINTEXT,
+                            insert_text_format=InsertTextFormat.PLAIN_TEXT,
                             text_edit=TextEdit(range=completion_range, new_text=f"{e.name}="),
                             data=CompletionItemData(
                                 document_uri=str(self.document.uri),
@@ -1659,9 +1626,6 @@ class CompletionCollector(ModelHelperMixin):
             return None
 
         async def complete_with_name() -> Optional[List[CompletionItem]]:
-            if self.document is None:
-                return None
-
             if context is None or context.trigger_kind != CompletionTriggerKind.INVOKED:
                 return []
 
@@ -1679,7 +1643,7 @@ class CompletionCollector(ModelHelperMixin):
                             kind=CompletionItemKind.KEYWORD,
                             # detail=e.detail,
                             sort_text="03_NAMESPACE_MARKER",
-                            insert_text_format=InsertTextFormat.PLAINTEXT,
+                            insert_text_format=InsertTextFormat.PLAIN_TEXT,
                         )
                     ]
             return []
@@ -1697,13 +1661,9 @@ class CompletionCollector(ModelHelperMixin):
         position: Position,
         context: Optional[CompletionContext],
     ) -> Union[List[CompletionItem], CompletionList, None]:
-
         from robot.parsing.lexer.tokens import Token
         from robot.parsing.model.statements import ResourceImport
 
-        if self.document is None:
-            return []
-
         import_node = cast(ResourceImport, node)
         import_token = import_node.get_token(Token.RESOURCE)
         if import_token is None:
@@ -1723,7 +1683,6 @@ class CompletionCollector(ModelHelperMixin):
             name_token = import_node.tokens[import_token_index + 1]
             if position.is_in_range(r := range_from_token(name_token)):
                 if whitespace_at_begin_of_token(name_token) > 1:
-
                     ws_b = whitespace_from_begin_of_token(name_token)
                     r.start.character += 2 if ws_b and ws_b[0] != "\t" else 1
 
@@ -1784,7 +1743,7 @@ class CompletionCollector(ModelHelperMixin):
                 else None,
                 detail=e.kind.value,
                 sort_text=f"030_{e}",
-                insert_text_format=InsertTextFormat.PLAINTEXT,
+                insert_text_format=InsertTextFormat.PLAIN_TEXT,
                 text_edit=TextEdit(range=r, new_text=e.label) if r is not None else None,
                 data=CompletionItemData(
                     document_uri=str(self.document.uri),
@@ -1802,13 +1761,9 @@ class CompletionCollector(ModelHelperMixin):
         position: Position,
         context: Optional[CompletionContext],
     ) -> Union[List[CompletionItem], CompletionList, None]:
-
         from robot.parsing.lexer.tokens import Token
         from robot.parsing.model.statements import VariablesImport
 
-        if self.document is None:
-            return []
-
         import_node = cast(VariablesImport, node)
         import_token = import_node.get_token(Token.VARIABLES)
 
@@ -1829,7 +1784,6 @@ class CompletionCollector(ModelHelperMixin):
             name_token = import_node.tokens[import_token_index + 1]
             if position.is_in_range(r := range_from_token(name_token)):
                 if whitespace_at_begin_of_token(name_token) > 1:
-
                     ws_b = whitespace_from_begin_of_token(name_token)
                     r.start.character += 2 if ws_b and ws_b[0] != "\t" else 1
 
@@ -1890,7 +1844,7 @@ class CompletionCollector(ModelHelperMixin):
                 else None,
                 detail=e.kind.value,
                 sort_text=f"030_{e}",
-                insert_text_format=InsertTextFormat.PLAINTEXT,
+                insert_text_format=InsertTextFormat.PLAIN_TEXT,
                 text_edit=TextEdit(range=r, new_text=e.label) if r is not None else None,
                 data=CompletionItemData(
                     document_uri=str(self.document.uri),
@@ -1915,9 +1869,6 @@ class CompletionCollector(ModelHelperMixin):
         if context is None or context.trigger_kind != CompletionTriggerKind.INVOKED:
             return []
 
-        if self.document is None:
-            return []
-
         kw_node = cast(Statement, node)
 
         keyword_token = kw_node.get_token(keyword_name_token_type)
@@ -1965,8 +1916,8 @@ class CompletionCollector(ModelHelperMixin):
                 equal_index = (argument_token or token_at_position).value.index("=")
                 if completion_range.start.character + equal_index < position.character:
                     return None
-                else:
-                    completion_range.end.character = completion_range.start.character + equal_index + 1
+
+                completion_range.end.character = completion_range.start.character + equal_index + 1
             else:
                 completion_range.end = position
 
@@ -2001,7 +1952,7 @@ class CompletionCollector(ModelHelperMixin):
                 detail="Argument",
                 filter_text=e.name,
                 sort_text=f"02{i}_{e.name}=",
-                insert_text_format=InsertTextFormat.PLAINTEXT,
+                insert_text_format=InsertTextFormat.PLAIN_TEXT,
                 text_edit=TextEdit(range=completion_range, new_text=f"{e.name}="),
             )
             for i, e in enumerate(result[0].args)
