@@ -4,7 +4,7 @@ import ast
 import asyncio
 from typing import TYPE_CHECKING, Any, List, Optional
 
-from ....utils.async_tools import check_canceled, threaded
+from ....utils.async_tools import check_canceled, create_sub_task, threaded
 from ....utils.logging import LoggingDescriptor
 from ....utils.uri import Uri
 from ...common.decorators import language_id
@@ -51,10 +51,7 @@ class RobotDiagnosticsProtocolPart(RobotLanguageServerProtocolPart):
 
         parent.documents_cache.namespace_invalidated.add(self.namespace_invalidated)
 
-    @language_id("robotframework")
-    @threaded()
-    @_logger.call
-    async def namespace_invalidated(self, sender: Any, namespace: Namespace) -> None:
+    async def namespace_invalidated_task(self, namespace: Namespace) -> None:
         if namespace.document is not None:
             refresh = namespace.document.opened_in_editor
 
@@ -72,6 +69,11 @@ class RobotDiagnosticsProtocolPart(RobotLanguageServerProtocolPart):
             if refresh:
                 await self.parent.diagnostics.refresh()
 
+    @language_id("robotframework")
+    @_logger.call
+    async def namespace_invalidated(self, sender: Any, namespace: Namespace) -> None:
+        create_sub_task(self.namespace_invalidated_task(namespace), loop=self.parent.diagnostics.diagnostics_loop)
+
     @language_id("robotframework")
     @threaded()
     @_logger.call
@@ -81,8 +83,6 @@ class RobotDiagnosticsProtocolPart(RobotLanguageServerProtocolPart):
     async def _collect_namespace_diagnostics(self, document: TextDocument) -> DiagnosticsResult:
         try:
             namespace = await self.parent.documents_cache.get_namespace(document)
-            if namespace is None:
-                return DiagnosticsResult(self.collect_namespace_diagnostics, None)
 
             return DiagnosticsResult(self.collect_namespace_diagnostics, await namespace.get_diagnostisc())
         except (asyncio.CancelledError, SystemExit, KeyboardInterrupt):
@@ -279,8 +279,6 @@ class RobotDiagnosticsProtocolPart(RobotLanguageServerProtocolPart):
     async def _collect_unused_keyword_references(self, document: TextDocument) -> DiagnosticsResult:
         try:
             namespace = await self.parent.documents_cache.get_namespace(document)
-            if namespace is None:
-                return DiagnosticsResult(self.collect_unused_keyword_references, None)
 
             result: List[Diagnostic] = []
             for kw in (await namespace.get_library_doc()).keywords.values():
@@ -293,7 +291,7 @@ class RobotDiagnosticsProtocolPart(RobotLanguageServerProtocolPart):
                             severity=DiagnosticSeverity.WARNING,
                             source=self.source_name,
                             code="KeywordNotUsed",
-                            tags=[DiagnosticTag.Unnecessary],
+                            tags=[DiagnosticTag.UNNECESSARY],
                         )
                     )
 
@@ -340,8 +338,6 @@ class RobotDiagnosticsProtocolPart(RobotLanguageServerProtocolPart):
     async def _collect_unused_variable_references(self, document: TextDocument) -> DiagnosticsResult:
         try:
             namespace = await self.parent.documents_cache.get_namespace(document)
-            if namespace is None:
-                return DiagnosticsResult(self.collect_unused_variable_references, None)
 
             result: List[Diagnostic] = []
 
@@ -356,7 +352,7 @@ class RobotDiagnosticsProtocolPart(RobotLanguageServerProtocolPart):
                             severity=DiagnosticSeverity.WARNING,
                             source=self.source_name,
                             code="VariableNotUsed",
-                            tags=[DiagnosticTag.Unnecessary],
+                            tags=[DiagnosticTag.UNNECESSARY],
                         )
                     )
 
