@@ -10,11 +10,11 @@ from typing import TYPE_CHECKING, Any, Iterator, List, Optional, cast
 
 from ....jsonrpc2.protocol import rpc_method
 from ....utils.async_tools import check_canceled, check_canceled_sync, threaded
+from ....utils.dataclasses import CamelSnakeMixin
 from ....utils.logging import LoggingDescriptor
 from ....utils.uri import Uri
 from ...common.lsp_types import (
     DocumentUri,
-    Model,
     Position,
     Range,
     TextDocumentIdentifier,
@@ -27,26 +27,26 @@ if TYPE_CHECKING:
     from ..protocol import RobotLanguageServerProtocol
 
 
-@dataclass(repr=False)
-class GetAllTestsParams(Model):
+@dataclass
+class GetAllTestsParams(CamelSnakeMixin):
     workspace_folder: str
     paths: Optional[List[str]] = None
     suites: Optional[List[str]] = None
 
 
-@dataclass(repr=False)
-class GetTestsParams(Model):
+@dataclass
+class GetTestsParams(CamelSnakeMixin):
     text_document: TextDocumentIdentifier
     base_name: Optional[str]
 
 
-@dataclass(repr=False)
-class GetTestsFromDocumentParams(Model):
+@dataclass
+class GetTestsFromDocumentParams(CamelSnakeMixin):
     text_document: TextDocumentIdentifier
 
 
-@dataclass(repr=False)
-class TestItem(Model):
+@dataclass
+class TestItem(CamelSnakeMixin):
     type: str
     id: str
     label: str
@@ -119,7 +119,7 @@ class DiscoveringProtocolPart(RobotLanguageServerProtocolPart):
             if self.parent.loop:
                 doc = self.parent.documents.get_sync(Uri.from_path(source).normalized())
                 if doc is not None:
-                    return doc.text_sync()
+                    return doc.text()
 
             return source
 
@@ -137,7 +137,8 @@ class DiscoveringProtocolPart(RobotLanguageServerProtocolPart):
             except (SystemExit, KeyboardInterrupt):
                 raise
             except BaseException as e:
-                self._logger.critical(f"Can't parse {source}: {e}")
+                ex = e
+                self._logger.critical(lambda: f"Can't parse {source}: {ex}")
                 return File(source=source)
 
         def my_get_model_v6(
@@ -149,7 +150,8 @@ class DiscoveringProtocolPart(RobotLanguageServerProtocolPart):
             except (SystemExit, KeyboardInterrupt):
                 raise
             except BaseException as e:
-                self._logger.critical(f"Can't parse {source}: {e}")
+                ex = e
+                self._logger.critical(lambda: f"Can't parse {source}: {ex}")
                 return File(source=source)
 
         my_get_model = my_get_model_v4 if get_robot_version() < (6, 0) else my_get_model_v6
@@ -216,7 +218,7 @@ class DiscoveringProtocolPart(RobotLanguageServerProtocolPart):
                             start=Position(line=test.lineno - 1, character=0),
                             end=Position(line=test.lineno - 1, character=0),
                         ),
-                        tags=[t for t in test.tags],
+                        tags=list(test.tags),
                     )
                 )
 
@@ -238,6 +240,8 @@ class DiscoveringProtocolPart(RobotLanguageServerProtocolPart):
                 else None,
             )
 
+        self._logger.info("Wait for workspace documents loaded...")
+
         await self.parent.robot_workspace.documents_loaded.wait()
 
         start = time.monotonic()
@@ -259,9 +263,7 @@ class DiscoveringProtocolPart(RobotLanguageServerProtocolPart):
             if paths and len(paths):
 
                 def normalize_paths(paths: List[str]) -> Iterator[str]:
-
                     for path in paths:
-
                         p = Path(path)
 
                         if not p.is_absolute():
@@ -271,9 +273,7 @@ class DiscoveringProtocolPart(RobotLanguageServerProtocolPart):
                             yield str(p)
 
                 def nonexisting_paths(paths: List[str]) -> Iterator[str]:
-
                     for path in paths:
-
                         p = Path(path)
 
                         if not p.is_absolute():
@@ -282,7 +282,7 @@ class DiscoveringProtocolPart(RobotLanguageServerProtocolPart):
                         if not p.exists():
                             yield str(p)
 
-                valid_paths = [i for i in normalize_paths(paths)]
+                valid_paths = list(normalize_paths(paths))
 
                 if get_robot_version() >= (6, 1):
                     builder = TestSuiteBuilder(
@@ -325,19 +325,19 @@ class DiscoveringProtocolPart(RobotLanguageServerProtocolPart):
                         ],
                     )
                 ]
+
+            if get_robot_version() >= (6, 1):
+                builder = TestSuiteBuilder(
+                    included_suites=suites if suites else None,
+                    rpa=rpa_mode,
+                    lang=languages,
+                    parsers=parsers,
+                )
+            elif get_robot_version() >= (6, 0):
+                builder = TestSuiteBuilder(included_suites=suites if suites else None, rpa=rpa_mode, lang=languages)
             else:
-                if get_robot_version() >= (6, 1):
-                    builder = TestSuiteBuilder(
-                        included_suites=suites if suites else None,
-                        rpa=rpa_mode,
-                        lang=languages,
-                        parsers=parsers,
-                    )
-                elif get_robot_version() >= (6, 0):
-                    builder = TestSuiteBuilder(included_suites=suites if suites else None, rpa=rpa_mode, lang=languages)
-                else:
-                    builder = TestSuiteBuilder(included_suites=suites if suites else None, rpa=rpa_mode)
-                return [await generate(builder.build(str(workspace_path)))]
+                builder = TestSuiteBuilder(included_suites=suites if suites else None, rpa=rpa_mode)
+            return [await generate(builder.build(str(workspace_path)))]
         except (SystemExit, KeyboardInterrupt):
             raise
         except asyncio.CancelledError:
@@ -345,7 +345,8 @@ class DiscoveringProtocolPart(RobotLanguageServerProtocolPart):
             self._logger.info("Tests discovery canceled")
             raise
         except BaseException as e:
-            self._logger.info(f"Failed to discover tests: {e}")
+            ex = e
+            self._logger.info(lambda: f"Failed to discover tests: {ex}")
             return [
                 TestItem(
                     type="error",
@@ -357,14 +358,13 @@ class DiscoveringProtocolPart(RobotLanguageServerProtocolPart):
             ]
         finally:
             if not canceled:
-                self._logger.info(f"Tests discovery took {time.monotonic() - start}s")
+                self._logger.info(lambda: f"Tests discovery took {time.monotonic() - start}s")
 
     @rpc_method(name="robot/discovering/getTestsFromDocument", param_type=GetTestsParams)
     @threaded()
     async def get_tests_from_document(
         self, text_document: TextDocumentIdentifier, base_name: Optional[str], *args: Any, **kwargs: Any
     ) -> List[TestItem]:
-
         try:
             return await FindTestCasesVisitor().get(
                 text_document.uri,
