@@ -95,9 +95,6 @@ class RobotGotoProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
 
         result_node = result_nodes[-1]
 
-        if result_node is None:
-            return None
-
         result = await self._definition_default(result_nodes, document, position, collect_type)
         if result:
             return result
@@ -114,8 +111,6 @@ class RobotGotoProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
         self, nodes: List[ast.AST], document: TextDocument, position: Position, collect_type: CollectType
     ) -> Union[Location, List[Location], List[LocationLink], None]:
         namespace = await self.parent.documents_cache.get_namespace(document)
-        if namespace is None:
-            return None
 
         if not nodes:
             return None
@@ -161,8 +156,6 @@ class RobotGotoProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
         from robot.parsing.model.statements import IfHeader
 
         namespace = await self.parent.documents_cache.get_namespace(document)
-        if namespace is None:
-            return None
 
         header = cast(IfHeader, node)
 
@@ -202,8 +195,6 @@ class RobotGotoProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
         from robot.parsing.model.statements import WhileHeader
 
         namespace = await self.parent.documents_cache.get_namespace(document)
-        if namespace is None:
-            return None
 
         header = cast(WhileHeader, node)
 
@@ -242,8 +233,6 @@ class RobotGotoProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
         from robot.parsing.model.statements import KeywordName
 
         namespace = await self.parent.documents_cache.get_namespace(document)
-        if namespace is None:
-            return None
 
         kw_node = cast(KeywordName, node)
         name_token = cast(RobotToken, kw_node.get_token(RobotToken.KEYWORD_NAME))
@@ -273,8 +262,6 @@ class RobotGotoProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
         from robot.parsing.model.statements import KeywordCall
 
         namespace = await self.parent.documents_cache.get_namespace(document)
-        if namespace is None:
-            return None
 
         kw_node = cast(KeywordCall, node)
         result = await self.get_keyworddoc_and_token_from_position(
@@ -321,8 +308,8 @@ class RobotGotoProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
                                 target_selection_range=lib_entry.import_range,
                             )
                         ]
-                    else:
-                        return None
+
+                    return None
 
             if position in kw_range and keyword_doc is not None and keyword_doc.source:
                 return [
@@ -343,8 +330,6 @@ class RobotGotoProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
         from robot.parsing.model.statements import Fixture
 
         namespace = await self.parent.documents_cache.get_namespace(document)
-        if namespace is None:
-            return None
 
         fixture_node = cast(Fixture, node)
 
@@ -396,8 +381,8 @@ class RobotGotoProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
                                 target_selection_range=lib_entry.import_range,
                             )
                         ]
-                    else:
-                        return None
+
+                    return None
 
             if position in kw_range and keyword_doc is not None and keyword_doc.source:
                 return [
@@ -424,14 +409,11 @@ class RobotGotoProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
 
         template_node = cast(Union[Template, TestTemplate], template_node)
         if template_node.value:
-
             keyword_token = cast(RobotToken, template_node.get_token(RobotToken.NAME))
             if keyword_token is None or keyword_token.value is None or keyword_token.value.upper() in ("", "NONE"):
                 return None
 
             namespace = await self.parent.documents_cache.get_namespace(document)
-            if namespace is None:
-                return None
 
             if (
                 await namespace.find_keyword(keyword_token.value, raise_keyword_error=False, handle_bdd_style=False)
@@ -440,10 +422,8 @@ class RobotGotoProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
                 keyword_token = self.strip_bdd_prefix(namespace, keyword_token)
 
             if position.is_in_range(range_from_token(keyword_token)):
-
                 keyword_doc = await namespace.find_keyword(template_node.value)
                 if keyword_doc is not None:
-
                     lib_entry, kw_namespace = await self.get_namespace_info_from_keyword(namespace, keyword_token)
 
                     kw_range = range_from_token(keyword_token)
@@ -471,8 +451,8 @@ class RobotGotoProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
                                         target_selection_range=lib_entry.import_range,
                                     )
                                 ]
-                            else:
-                                return None
+
+                            return None
 
                     if keyword_doc.source and not keyword_doc.is_error_handler:
                         return [
@@ -503,15 +483,12 @@ class RobotGotoProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
 
         library_node = cast(LibraryImport, node)
         if library_node.name:
-
             name_token = cast(RobotToken, library_node.get_token(RobotToken.NAME))
             if name_token is None:
                 return None
 
             if position.is_in_range(range_from_token(name_token)):
                 namespace = await self.parent.documents_cache.get_namespace(document)
-                if namespace is None:
-                    return None
 
                 try:
                     libdoc = await namespace.get_imported_library_libdoc(
@@ -526,9 +503,6 @@ class RobotGotoProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
                             variables=await namespace.get_resolvable_variables(),
                         )
 
-                    if libdoc is None:
-                        return None
-
                     python_source = libdoc.source_or_origin
                     if python_source is not None:
                         return [
@@ -553,15 +527,12 @@ class RobotGotoProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
 
         resource_node = cast(ResourceImport, node)
         if resource_node.name:
-
             name_token = cast(RobotToken, resource_node.get_token(RobotToken.NAME))
             if name_token is None:
                 return None
 
             if position.is_in_range(range_from_token(name_token)):
                 namespace = await self.parent.documents_cache.get_namespace(document)
-                if namespace is None:
-                    return None
 
                 try:
                     libdoc = await namespace.get_imported_resource_libdoc(resource_node.name)
@@ -573,9 +544,6 @@ class RobotGotoProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
                             variables=await namespace.get_resolvable_variables(),
                         )
 
-                    if libdoc is None:
-                        return None
-
                     python_source = libdoc.source_or_origin
                     if python_source is not None:
                         return [
@@ -600,15 +568,12 @@ class RobotGotoProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
 
         variables_node = cast(VariablesImport, node)
         if variables_node.name:
-
             name_token = cast(RobotToken, variables_node.get_token(RobotToken.NAME))
             if name_token is None:
                 return None
 
             if position.is_in_range(range_from_token(name_token)):
                 namespace = await self.parent.documents_cache.get_namespace(document)
-                if namespace is None:
-                    return None
 
                 try:
                     libdoc = await namespace.get_imported_variables_libdoc(variables_node.name, variables_node.args)
@@ -621,9 +586,6 @@ class RobotGotoProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
                             variables=await namespace.get_resolvable_variables(),
                         )
 
-                    if libdoc is None:
-                        return None
-
                     python_source = libdoc.source_or_origin
                     if python_source is not None:
                         return [
