@@ -65,10 +65,7 @@ class RobotHoverProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
     @language_id("robotframework")
     @_logger.call
     async def collect(self, sender: Any, document: TextDocument, position: Position) -> Optional[Hover]:
-
         model = await self.parent.documents_cache.get_model(document)
-        if model is None:
-            return None
 
         result_nodes = await get_nodes_at_position(model, position)
 
@@ -90,8 +87,6 @@ class RobotHoverProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
 
     async def _hover_default(self, nodes: List[ast.AST], document: TextDocument, position: Position) -> Optional[Hover]:
         namespace = await self.parent.documents_cache.get_namespace(document)
-        if namespace is None:
-            return None
 
         if not nodes:
             return None
@@ -149,8 +144,6 @@ class RobotHoverProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
         from robot.parsing.model.statements import IfHeader
 
         namespace = await self.parent.documents_cache.get_namespace(document)
-        if namespace is None:
-            return None
 
         header = cast(IfHeader, node)
 
@@ -200,8 +193,6 @@ class RobotHoverProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
         from robot.parsing.model.statements import WhileHeader
 
         namespace = await self.parent.documents_cache.get_namespace(document)
-        if namespace is None:
-            return None
 
         header = cast(WhileHeader, node)
 
@@ -251,8 +242,6 @@ class RobotHoverProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
         from robot.parsing.model.statements import KeywordCall
 
         namespace = await self.parent.documents_cache.get_namespace(document)
-        if namespace is None:
-            return None
 
         kw_node = cast(KeywordCall, node)
         result = await self.get_keyworddoc_and_token_from_position(
@@ -300,8 +289,6 @@ class RobotHoverProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
         from robot.parsing.model.statements import Fixture
 
         namespace = await self.parent.documents_cache.get_namespace(document)
-        if namespace is None:
-            return None
 
         fixture_node = cast(Fixture, node)
 
@@ -355,14 +342,11 @@ class RobotHoverProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
 
         template_node = cast(Union[Template, TestTemplate], node)
         if template_node.value:
-
             keyword_token = cast(RobotToken, template_node.get_token(RobotToken.NAME))
             if keyword_token is None:
                 return None
 
             namespace = await self.parent.documents_cache.get_namespace(document)
-            if namespace is None:
-                return None
 
             if (
                 await namespace.find_keyword(keyword_token.value, raise_keyword_error=False, handle_bdd_style=False)
@@ -374,7 +358,6 @@ class RobotHoverProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
                 keyword_doc = await namespace.find_keyword(template_node.value)
 
                 if keyword_doc is not None:
-
                     lib_entry, kw_namespace = await self.get_namespace_info_from_keyword(namespace, keyword_token)
 
                     kw_range = range_from_token(keyword_token)
@@ -415,7 +398,6 @@ class RobotHoverProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
 
         library_node = cast(LibraryImport, node)
         if library_node.name:
-
             name_token = cast(RobotToken, library_node.get_token(RobotToken.NAME))
             if name_token is None:
                 return None
@@ -423,8 +405,6 @@ class RobotHoverProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
             token_range = range_from_token(name_token)
             if position.is_in_range(token_range):
                 namespace = await self.parent.documents_cache.get_namespace(document)
-                if namespace is None:
-                    return None
 
                 try:
                     libdoc = await namespace.get_imported_library_libdoc(
@@ -463,7 +443,6 @@ class RobotHoverProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
 
         resource_node = cast(ResourceImport, node)
         if resource_node.name:
-
             name_token = cast(RobotToken, resource_node.get_token(RobotToken.NAME))
             if name_token is None:
                 return None
@@ -471,8 +450,6 @@ class RobotHoverProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
             token_range = range_from_token(name_token)
             if position.is_in_range(token_range):
                 namespace = await self.parent.documents_cache.get_namespace(document)
-                if namespace is None:
-                    return None
 
                 try:
                     libdoc = await namespace.get_imported_resource_libdoc(resource_node.name)
@@ -508,7 +485,6 @@ class RobotHoverProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
 
         variables_node = cast(VariablesImport, node)
         if variables_node.name:
-
             name_token = cast(RobotToken, variables_node.get_token(RobotToken.NAME))
             if name_token is None:
                 return None
@@ -516,8 +492,6 @@ class RobotHoverProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
             token_range = range_from_token(name_token)
             if position.is_in_range(token_range):
                 namespace = await self.parent.documents_cache.get_namespace(document)
-                if namespace is None:
-                    return None
 
                 try:
                     libdoc = await namespace.get_imported_variables_libdoc(variables_node.name, variables_node.args)
@@ -553,8 +527,6 @@ class RobotHoverProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
         from robot.parsing.model.statements import KeywordName
 
         namespace = await self.parent.documents_cache.get_namespace(document)
-        if namespace is None:
-            return None
 
         kw_node = cast(KeywordName, node)
         name_token = cast(RobotToken, kw_node.get_token(RobotToken.KEYWORD_NAME))
