@@ -110,7 +110,6 @@ class RobotReferencesProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMi
     async def collect(
         self, sender: Any, document: TextDocument, position: Position, context: ReferenceContext
     ) -> Optional[List[Location]]:
-
         result_nodes = await get_nodes_at_position(await self.parent.documents_cache.get_model(document), position)
 
         if not result_nodes:
@@ -118,9 +117,6 @@ class RobotReferencesProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMi
 
         result_node = result_nodes[-1]
 
-        if result_node is None:
-            return None
-
         result = await self._references_default(result_nodes, document, position, context)
         if result:
             return result
@@ -141,8 +137,7 @@ class RobotReferencesProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMi
         *args: Any,
         **kwargs: Any,
     ) -> List[Location]:
-
-        await self.parent.diagnostics.ensure_workspace_loaded()
+        # await self.parent.diagnostics.ensure_workspace_loaded()
 
         result: List[Location] = []
 
@@ -163,8 +158,6 @@ class RobotReferencesProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMi
         self, nodes: List[ast.AST], document: TextDocument, position: Position, context: ReferenceContext
     ) -> Optional[List[Location]]:
         namespace = await self.parent.documents_cache.get_namespace(document)
-        if namespace is None:
-            return None
 
         all_variable_refs = await namespace.get_variable_references()
         if all_variable_refs:
@@ -229,8 +222,6 @@ class RobotReferencesProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMi
         self, doc: TextDocument, variable: VariableDefinition, include_declaration: bool = True
     ) -> List[Location]:
         namespace = await self.parent.documents_cache.get_namespace(doc)
-        if namespace is None:
-            return []
 
         if (
             variable.source
@@ -245,7 +236,6 @@ class RobotReferencesProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMi
             )
             and not any(e for e in await namespace.get_command_line_variables() if e.source == variable.source)
         ):
-
             return []
 
         result = set()
@@ -266,11 +256,8 @@ class RobotReferencesProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMi
         lib_doc: Optional[LibraryDoc] = None,
         include_declaration: bool = True,
     ) -> List[Location]:
-
         try:
             namespace = await self.parent.documents_cache.get_namespace(doc)
-            if namespace is None:
-                return []
 
             if (
                 lib_doc is not None
@@ -312,10 +299,7 @@ class RobotReferencesProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMi
     async def _find_keyword_references(
         self, document: TextDocument, kw_doc: KeywordDoc, include_declaration: bool = True, stop_at_first: bool = False
     ) -> List[Location]:
-
         namespace = await self.parent.documents_cache.get_namespace(document)
-        if namespace is None:
-            return []
 
         lib_doc = (
             next(
@@ -356,7 +340,6 @@ class RobotReferencesProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMi
         doc: TextDocument,
         library_doc: LibraryDoc,
     ) -> List[Location]:
-
         namespace = await self.parent.documents_cache.get_namespace(doc)
 
         result: List[Location] = []
@@ -376,8 +359,6 @@ class RobotReferencesProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMi
         from robot.parsing.model.statements import LibraryImport
 
         namespace = await self.parent.documents_cache.get_namespace(document)
-        if namespace is None:
-            return None
 
         import_node = cast(LibraryImport, node)
 
@@ -406,7 +387,6 @@ class RobotReferencesProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMi
         doc: TextDocument,
         library_doc: LibraryDoc,
     ) -> List[Location]:
-
         namespace = await self.parent.documents_cache.get_namespace(doc)
 
         result: List[Location] = []
@@ -423,8 +403,6 @@ class RobotReferencesProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMi
         from robot.parsing.model.statements import ResourceImport
 
         namespace = await self.parent.documents_cache.get_namespace(document)
-        if namespace is None:
-            return None
 
         import_node = cast(ResourceImport, node)
 
@@ -450,7 +428,6 @@ class RobotReferencesProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMi
         doc: TextDocument,
         library_doc: LibraryDoc,
     ) -> List[Location]:
-
         namespace = await self.parent.documents_cache.get_namespace(doc)
 
         result: List[Location] = []
@@ -467,8 +444,6 @@ class RobotReferencesProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMi
         from robot.parsing.model.statements import VariablesImport
 
         namespace = await self.parent.documents_cache.get_namespace(document)
-        if namespace is None:
-            return None
 
         import_node = cast(VariablesImport, node)
 
@@ -496,8 +471,6 @@ class RobotReferencesProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMi
         from robot.parsing.model.statements import DefaultTags, ForceTags, Tags
 
         model = await self.parent.documents_cache.get_model(doc)
-        if model is None:
-            return []
 
         result: List[Location] = []
         if not is_normalized:
@@ -516,11 +489,12 @@ class RobotReferencesProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMi
     ) -> Optional[List[Location]]:
         from robot.parsing.lexer.tokens import Token as RobotToken
 
-        token = get_tokens_at_position(cast(HasTokens, node), position)[-1]
-
-        if token is None:
+        tokens = get_tokens_at_position(cast(HasTokens, node), position)
+        if not tokens:
             return None
 
+        token = get_tokens_at_position(cast(HasTokens, node), position)[-1]
+
         if token.type in [RobotToken.ARGUMENT] and token.value:
             return await self.find_tag_references(document, token.value)
 
