@@ -26,18 +26,17 @@ from ...common.lsp_types import (
     OptionalVersionedTextDocumentIdentifier,
     Position,
     PrepareRenameResult,
-    PrepareRenameResultWithPlaceHolder,
+    PrepareRenameResultType1,
     RenameFile,
     TextDocumentEdit,
     WorkspaceEdit,
 )
-from ...common.parts.rename import CantRenameException
+from ...common.parts.rename import CantRenameError
 from ...common.text_document import TextDocument
 from ..diagnostics.entities import VariableDefinition, VariableDefinitionType
 from ..diagnostics.library_doc import KeywordDoc
 from ..utils.ast_utils import (
     HasTokens,
-    Statement,
     Token,
     get_nodes_at_position,
     get_tokens_at_position,
@@ -88,7 +87,6 @@ class RobotRenameProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin)
         position: Position,
         new_name: str,
     ) -> Optional[WorkspaceEdit]:
-
         result_nodes = await get_nodes_at_position(await self.parent.documents_cache.get_model(document), position)
 
         if not result_nodes:
@@ -96,9 +94,6 @@ class RobotRenameProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin)
 
         result_node = result_nodes[-1]
 
-        if result_node is None:
-            return None
-
         result = await self._rename_default(result_nodes, document, position, new_name)
         if result:
             return result
@@ -119,7 +114,6 @@ class RobotRenameProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin)
         document: TextDocument,
         position: Position,
     ) -> Optional[PrepareRenameResult]:
-
         result_nodes = await get_nodes_at_position(await self.parent.documents_cache.get_model(document), position)
 
         if not result_nodes:
@@ -127,9 +121,6 @@ class RobotRenameProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin)
 
         result_node = result_nodes[-1]
 
-        if result_node is None:
-            return None
-
         result = await self._prepare_rename_default(result_nodes, document, position)
         if result:
             return result
@@ -169,7 +160,7 @@ class RobotRenameProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin)
                     "Only references are renamed and you have to rename the variable definition yourself."
                 )
 
-            return PrepareRenameResultWithPlaceHolder(range_from_token(token), token.value)
+            return PrepareRenameResultType1(range_from_token(token), token.value)
 
         return None
 
@@ -197,7 +188,7 @@ class RobotRenameProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin)
                 changes.append(
                     TextDocumentEdit(
                         OptionalVersionedTextDocumentIdentifier(reference.uri, None),
-                        [AnnotatedTextEdit(reference.range, new_name, annotation_id="rename_variable")],
+                        [AnnotatedTextEdit("rename_variable", reference.range, new_name)],
                     )
                 )
 
@@ -214,8 +205,6 @@ class RobotRenameProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin)
         from robot.parsing.lexer.tokens import Token as RobotToken
 
         namespace = await self.parent.documents_cache.get_namespace(document)
-        if namespace is None:
-            return None
 
         if not nodes:
             return None
@@ -241,7 +230,6 @@ class RobotRenameProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin)
 
         if (
             token_and_var is None
-            and isinstance(node, Statement)
             and isinstance(node, self.get_expression_statement_types())
             and (token := node.get_token(RobotToken.ARGUMENT)) is not None
             and position in range_from_token(token)
@@ -264,7 +252,7 @@ class RobotRenameProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin)
             kw_doc, token = result
 
             if kw_doc.is_embedded:
-                raise CantRenameException("Renaming of keywords with embedded parameters is not supported.")
+                raise CantRenameError("Renaming of keywords with embedded parameters is not supported.")
 
             if kw_doc.is_library_keyword:
                 self.parent.window.show_message(
@@ -272,7 +260,7 @@ class RobotRenameProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin)
                     "Only references are renamed and you have to rename the keyword definition yourself."
                 )
 
-            return PrepareRenameResultWithPlaceHolder(range_from_token(token), token.value)
+            return PrepareRenameResultType1(range_from_token(token), token.value)
 
         return None
 
@@ -291,7 +279,7 @@ class RobotRenameProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin)
                 changes.append(
                     TextDocumentEdit(
                         OptionalVersionedTextDocumentIdentifier(reference.uri, None),
-                        [AnnotatedTextEdit(reference.range, new_name, annotation_id="rename_keyword")],
+                        [AnnotatedTextEdit("rename_keyword", reference.range, new_name)],
                     )
                 )
 
@@ -319,8 +307,6 @@ class RobotRenameProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin)
         from robot.parsing.model.statements import KeywordCall
 
         namespace = await self.parent.documents_cache.get_namespace(document)
-        if namespace is None:
-            return None
 
         kw_node = cast(KeywordCall, node)
         result = await self.get_keyworddoc_and_token_from_position(
@@ -389,8 +375,6 @@ class RobotRenameProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin)
         from robot.parsing.model.statements import KeywordName
 
         namespace = await self.parent.documents_cache.get_namespace(document)
-        if namespace is None:
-            return None
 
         kw_node = cast(KeywordName, node)
 
@@ -428,8 +412,6 @@ class RobotRenameProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin)
         from robot.parsing.model.statements import Fixture
 
         namespace = await self.parent.documents_cache.get_namespace(document)
-        if namespace is None:
-            return None
 
         fixture_node = cast(Fixture, node)
 
@@ -490,14 +472,11 @@ class RobotRenameProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin)
 
         template_node = cast(Union[Template, TestTemplate], node)
         if template_node.value:
-
             keyword_token = cast(RobotToken, template_node.get_token(RobotToken.NAME))
             if keyword_token is None or keyword_token.value is None or keyword_token.value.upper() in ("", "NONE"):
                 return None
 
             namespace = await self.parent.documents_cache.get_namespace(document)
-            if namespace is None:
-                return None
 
             if (
                 await namespace.find_keyword(keyword_token.value, raise_keyword_error=False, handle_bdd_style=False)
@@ -506,11 +485,9 @@ class RobotRenameProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin)
                 keyword_token = self.strip_bdd_prefix(namespace, keyword_token)
 
             if position.is_in_range(range_from_token(keyword_token), False):
-
                 keyword_doc = await namespace.find_keyword(template_node.value)
 
                 if keyword_doc is not None:
-
                     lib_entry, kw_namespace = await self.get_namespace_info_from_keyword(namespace, keyword_token)
 
                     kw_range = range_from_token(keyword_token)
@@ -562,18 +539,19 @@ class RobotRenameProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin)
             document, new_name, await self._find_Template_or_TestTemplate(node, document, position)
         )
 
-    async def _prepare_rename_tags(  # noqa: N802
+    async def _prepare_rename_tags(
         self, node: ast.AST, document: TextDocument, position: Position
     ) -> Optional[PrepareRenameResult]:
         from robot.parsing.lexer.tokens import Token as RobotToken
 
-        token = get_tokens_at_position(cast(HasTokens, node), position)[-1]
-
-        if token is None:
+        tokens = get_tokens_at_position(cast(HasTokens, node), position)
+        if not tokens:
             return None
 
+        token = tokens[-1]
+
         if token.type in [RobotToken.ARGUMENT] and token.value:
-            return PrepareRenameResultWithPlaceHolder(range_from_token(token), token.value)
+            return PrepareRenameResultType1(range_from_token(token), token.value)
 
         return None
 
@@ -592,17 +570,17 @@ class RobotRenameProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin)
     ) -> Optional[PrepareRenameResult]:
         return await self._prepare_rename_tags(node, document, position)
 
-    async def _rename_tags(  # noqa: N802
+    async def _rename_tags(
         self, node: ast.AST, document: TextDocument, position: Position, new_name: str
     ) -> Optional[WorkspaceEdit]:
-
         from robot.parsing.lexer.tokens import Token as RobotToken
 
-        token = get_tokens_at_position(cast(HasTokens, node), position)[-1]
-
-        if token is None:
+        tokens = get_tokens_at_position(cast(HasTokens, node), position)
+        if not tokens:
             return None
 
+        token = tokens[-1]
+
         if token.type in [RobotToken.ARGUMENT] and token.value:
             references = await self.parent.robot_references.find_tag_references(document, token.value)
 
@@ -612,7 +590,7 @@ class RobotRenameProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin)
                 changes.append(
                     TextDocumentEdit(
                         OptionalVersionedTextDocumentIdentifier(reference.uri, None),
-                        [AnnotatedTextEdit(reference.range, new_name, annotation_id="rename_tag")],
+                        [AnnotatedTextEdit("rename_tag", reference.range, new_name)],
                     )
                 )
 
