@@ -9,7 +9,7 @@ from functools import reduce
 from typing import (
     TYPE_CHECKING,
     Any,
-    AsyncGenerator,
+    AsyncIterator,
     Dict,
     FrozenSet,
     List,
@@ -135,8 +135,8 @@ class RobotSemanticTokenProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
 
     def __init__(self, parent: RobotLanguageServerProtocol) -> None:
         super().__init__(parent)
-        parent.semantic_tokens.token_types += [e for e in RobotSemTokenTypes]
-        parent.semantic_tokens.token_modifiers += [e for e in RobotSemTokenModifiers]
+        parent.semantic_tokens.token_types += list(RobotSemTokenTypes)
+        parent.semantic_tokens.token_modifiers += list(RobotSemTokenModifiers)
 
         parent.semantic_tokens.collect_full.add(self.collect_full)
         # parent.semantic_tokens.collect_range.add(self.collect_range)
@@ -263,7 +263,7 @@ class RobotSemanticTokenProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
         node: ast.AST,
         col_offset: Optional[int] = None,
         length: Optional[int] = None,
-    ) -> AsyncGenerator[SemTokenInfo, None]:
+    ) -> AsyncIterator[SemTokenInfo]:
         from robot.parsing.lexer.tokens import Token as RobotToken
         from robot.parsing.model.statements import (
             Arguments,
@@ -374,7 +374,6 @@ class RobotSemanticTokenProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
                 kw: str = token.value
 
                 for lib, name in iter_over_keyword_names_and_owners(token.value):
-
                     if lib is not None and (
                         any(k for k in libraries_matchers.keys() if k == lib)
                         or any(k for k in resources_matchers.keys() if k == lib)
@@ -485,13 +484,12 @@ class RobotSemanticTokenProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
         builtin_library_doc: Optional[LibraryDoc],
         libraries_matchers: Dict[KeywordMatcher, LibraryEntry],
         resources_matchers: Dict[KeywordMatcher, ResourceEntry],
-    ) -> AsyncGenerator[SemTokenInfo, None]:
+    ) -> AsyncIterator[SemTokenInfo]:
         from robot.parsing.lexer.tokens import Token as RobotToken
         from robot.parsing.model.statements import Variable
         from robot.utils.escaping import split_from_equals
 
         if token.type in {RobotToken.ARGUMENT, RobotToken.TESTCASE_NAME, RobotToken.KEYWORD_NAME}:
-
             if isinstance(node, Variable) and token.type == RobotToken.ARGUMENT and node.name and node.name[0] == "&":
                 name, value = split_from_equals(token.value)
                 if value is not None:
@@ -533,14 +531,13 @@ class RobotSemanticTokenProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
         kw_token: Token,
         arguments: List[Token],
         node: ast.AST,
-    ) -> AsyncGenerator[Tuple[Token, ast.AST], None]:
+    ) -> AsyncIterator[Tuple[Token, ast.AST]]:
         from robot.parsing.lexer import Token as RobotToken
         from robot.utils.escaping import unescape
 
-        async def skip_non_data_tokens() -> AsyncGenerator[Tuple[Token, ast.AST], None]:
+        async def skip_non_data_tokens() -> AsyncIterator[Tuple[Token, ast.AST]]:
             nonlocal arguments
             while arguments and arguments[0] and arguments[0].type in RobotToken.NON_DATA_TOKENS:
-
                 yield arguments[0], node,
                 arguments = arguments[1:]
 
@@ -627,7 +624,7 @@ class RobotSemanticTokenProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
                         yield e
             elif kw_doc.is_run_keyword_if() and len(arguments) > 0:
 
-                async def generate_run_kw_if() -> AsyncGenerator[Tuple[Token, ast.AST], None]:
+                async def generate_run_kw_if() -> AsyncIterator[Tuple[Token, ast.AST]]:
                     nonlocal arguments
 
                     yield arguments[0], node,
@@ -711,7 +708,7 @@ class RobotSemanticTokenProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
         arguments: List[Token],
         node: ast.AST,
         kw_doc: Optional[KeywordDoc] = None,
-    ) -> AsyncGenerator[Tuple[Token, ast.AST], None]:
+    ) -> AsyncIterator[Tuple[Token, ast.AST]]:
         from robot.parsing.lexer import Token as RobotToken
         from robot.utils.escaping import split_from_equals
 
@@ -749,7 +746,6 @@ class RobotSemanticTokenProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
         libraries_matchers: Dict[KeywordMatcher, LibraryEntry],
         resources_matchers: Dict[KeywordMatcher, ResourceEntry],
     ) -> Union[SemanticTokens, SemanticTokensPartialResult, None]:
-
         from robot.parsing.lexer.tokens import Token as RobotToken
         from robot.parsing.model.statements import Fixture, KeywordCall, LibraryImport
         from robot.utils.escaping import split_from_equals
@@ -758,14 +754,13 @@ class RobotSemanticTokenProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
         last_line = 0
         last_col = 0
 
-        async def get_tokens() -> AsyncGenerator[Tuple[Token, ast.AST], None]:
+        async def get_tokens() -> AsyncIterator[Tuple[Token, ast.AST]]:
             async for node in async_ast.iter_nodes(model):
                 if isinstance(node, HasTokens):
                     if isinstance(node, LibraryImport):
                         lib_doc = await namespace.get_imported_library_libdoc(node.name, node.args, node.alias)
                         kw_doc = lib_doc.inits.keywords[0] if lib_doc and lib_doc.inits else None
                         if lib_doc is not None:
-
                             for token in node.tokens:
                                 if token.type == RobotToken.ARGUMENT:
                                     name, value = split_from_equals(token.value)
@@ -898,7 +893,6 @@ class RobotSemanticTokenProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
     async def _collect(
         self, document: TextDocument, range: Optional[Range]
     ) -> Union[SemanticTokens, SemanticTokensPartialResult, None]:
-
         model = await self.parent.documents_cache.get_model(document, False)
         namespace = await self.parent.documents_cache.get_namespace(document)
 
