@@ -2,7 +2,7 @@ import os
 import sys
 from dataclasses import dataclass, field
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, Dict, List, Optional
+from typing import TYPE_CHECKING, Any, Dict, Final, List, Optional
 
 from ...__version__ import __version__
 from ...jsonrpc2.protocol import (
@@ -10,9 +10,9 @@ from ...jsonrpc2.protocol import (
     JsonRPCErrors,
     ProtocolPartDescriptor,
 )
-from ...utils.dataclasses import from_dict
+from ...utils.dataclasses import CamelSnakeMixin, from_dict
 from ...utils.logging import LoggingDescriptor
-from ..common.lsp_types import InitializeError, Model
+from ..common.lsp_types import InitializeError
 from ..common.parts.document_symbols import symbol_information_label
 from ..common.protocol import LanguageDefinition, LanguageServerProtocol
 from .configuration import RobotConfig
@@ -45,15 +45,15 @@ if TYPE_CHECKING:
     from .server import RobotLanguageServer
 
 
-class RobotCodeException(Exception):
+class RobotCodeError(Exception):
     pass
 
 
-class RobotModuleNotFoundError(RobotCodeException):
+class RobotModuleNotFoundError(RobotCodeError):
     pass
 
 
-class RobotVersionDontMatchError(RobotCodeException):
+class RobotVersionDontMatchError(RobotCodeError):
     pass
 
 
@@ -70,7 +70,7 @@ def check_robotframework() -> None:
 
 
 @dataclass
-class Options(Model):
+class Options(CamelSnakeMixin):
     storage_uri: Optional[str] = None
     global_storage_uri: Optional[str] = None
     python_path: List[str] = field(default_factory=list)
@@ -79,7 +79,7 @@ class Options(Model):
 
 @symbol_information_label("robotframework")
 class RobotLanguageServerProtocol(LanguageServerProtocol):
-    _logger = LoggingDescriptor()
+    _logger: Final = LoggingDescriptor()
 
     documents_cache = ProtocolPartDescriptor(DocumentsCache)
     robot_diagnostics = ProtocolPartDescriptor(RobotDiagnosticsProtocolPart)
@@ -112,7 +112,7 @@ class RobotLanguageServerProtocol(LanguageServerProtocol):
 
     file_extensions = {"robot", "resource", "py", "yaml", "yml", "feature"}
 
-    languages: List[LanguageDefinition] = [
+    languages = [
         LanguageDefinition(
             id="robotframework",
             extensions=[".robot", ".resource"],
@@ -159,14 +159,14 @@ class RobotLanguageServerProtocol(LanguageServerProtocol):
 
         try:
             check_robotframework()
-        except RobotCodeException as e:
+        except RobotCodeError as e:
             raise JsonRPCErrorException(
                 JsonRPCErrors.INTERNAL_ERROR, f"Can't start language server: {e}", InitializeError(retry=False)
             ) from e
 
         self.workspace.did_change_configuration.add(self._on_did_change_configuration)
 
-        self._logger.critical(f"initialized with {repr(self.options)}")
+        self._logger.info(lambda: f"initialized with {repr(self.options)}")
 
     async def _on_did_change_configuration(self, sender: Any, settings: Dict[str, Any]) -> None:
         pass
