@@ -14,7 +14,6 @@ from concurrent.futures import ThreadPoolExecutor
 from types import TracebackType
 from typing import (
     Any,
-    AsyncGenerator,
     AsyncIterator,
     Awaitable,
     Callable,
@@ -37,6 +36,8 @@ from ..utils.inspect import ensure_coroutine
 
 _T = TypeVar("_T")
 
+# TODO try to use new ParamSpec feature in Python 3.10
+
 _TResult = TypeVar("_TResult")
 _TCallable = TypeVar("_TCallable", bound=Callable[..., Any])
 
@@ -72,8 +73,8 @@ class AsyncEventResultIteratorBase(Generic[_TCallable, _TResult]):
     def __contains__(self, obj: Any) -> bool:
         if inspect.ismethod(obj):
             return weakref.WeakMethod(obj) in self._listeners
-        else:
-            return weakref.ref(obj) in self._listeners
+
+        return weakref.ref(obj) in self._listeners
 
     def __len__(self) -> int:
         return len(self._listeners)
@@ -91,7 +92,6 @@ class AsyncEventResultIteratorBase(Generic[_TCallable, _TResult]):
     async def _notify(
         self, *args: Any, callback_filter: Optional[Callable[[_TCallable], bool]] = None, **kwargs: Any
     ) -> AsyncIterator[_TResult]:
-
         for method in filter(
             lambda x: callback_filter(x) if callback_filter is not None else True,
             set(self),
@@ -146,12 +146,12 @@ class async_event_iterator(  # noqa: N801
     AsyncEventDescriptorBase[_TCallable, Any, AsyncEventIterator[_TCallable, Any]]
 ):
     def __init__(self, _func: _TCallable) -> None:
-        super().__init__(_func, AsyncEventIterator[_TCallable, _TResult])
+        super().__init__(_func, AsyncEventIterator[_TCallable, Any])
 
 
 class async_event(AsyncEventDescriptorBase[_TCallable, Any, AsyncEvent[_TCallable, Any]]):  # noqa: N801
     def __init__(self, _func: _TCallable) -> None:
-        super().__init__(_func, AsyncEvent[_TCallable, _TResult])
+        super().__init__(_func, AsyncEvent[_TCallable, Any])
 
 
 _F = TypeVar("_F", bound=Callable[..., Any])
@@ -183,7 +183,7 @@ class AsyncTaskingEventResultIteratorBase(AsyncEventResultIteratorBase[_TCallabl
         callback_filter: Optional[Callable[[_TCallable], bool]] = None,
         threaded: Optional[bool] = True,
         **kwargs: Any,
-    ) -> AsyncGenerator[Union[_TResult, BaseException], None]:
+    ) -> AsyncIterator[Union[_TResult, BaseException]]:
         def _done(f: asyncio.Future[_TResult]) -> None:
             if result_callback is not None:
                 try:
@@ -199,11 +199,10 @@ class AsyncTaskingEventResultIteratorBase(AsyncEventResultIteratorBase[_TCallabl
             set(self),
         ):
             if method is not None:
-                if threaded and isinstance(method, HasThreaded) and cast(HasThreaded, method).__threaded__:
-                    future = run_coroutine_in_thread(ensure_coroutine(method), *args, **kwargs)
+                if threaded and isinstance(method, HasThreaded) and method.__threaded__:  # type: ignore
+                    future = run_coroutine_in_thread(ensure_coroutine(method), *args, **kwargs)  # type: ignore
                 else:
                     future = create_sub_task(ensure_coroutine(method)(*args, **kwargs))
-
                 awaitables.append(future)
 
                 if result_callback is not None:
@@ -223,7 +222,7 @@ class AsyncTaskingEventResultIteratorBase(AsyncEventResultIteratorBase[_TCallabl
 
 
 class AsyncTaskingEventIterator(AsyncTaskingEventResultIteratorBase[_TCallable, _TResult]):
-    def __call__(self, *args: Any, **kwargs: Any) -> AsyncGenerator[Union[_TResult, BaseException], None]:
+    def __call__(self, *args: Any, **kwargs: Any) -> AsyncIterator[Union[_TResult, BaseException]]:
         return self._notify(*args, **kwargs)
 
 
@@ -262,11 +261,11 @@ async def check_canceled() -> bool:
 def check_canceled_sync() -> bool:
     info = get_current_future_info()
     if info is not None and info.canceled():
-        raise asyncio.CancelledError()
+        raise asyncio.CancelledError
     return True
 
 
-# __executor = ThreadPoolExecutor(thread_name_prefix="global_sub_asyncio")
+__executor = ThreadPoolExecutor(thread_name_prefix="global_sub_asyncio")
 
 
 def run_in_thread(func: Callable[..., _T], /, *args: Any, **kwargs: Any) -> asyncio.Future[_T]:
@@ -275,19 +274,19 @@ def run_in_thread(func: Callable[..., _T], /, *args: Any, **kwargs: Any) -> asyn
     ctx = contextvars.copy_context()
     func_call = functools.partial(ctx.run, func, *args, **kwargs)
 
-    # return cast(
-    #     "asyncio.Future[_T]",
-    #     loop.run_in_executor(__executor, cast(Callable[..., _T], func_call)),
-    # )
+    return cast(
+        "asyncio.Future[_T]",
+        loop.run_in_executor(__executor, cast(Callable[..., _T], func_call)),
+    )
 
-    executor = ThreadPoolExecutor(max_workers=1, thread_name_prefix="sub_asyncio")
-    try:
-        return cast(
-            "asyncio.Future[_T]",
-            loop.run_in_executor(executor, cast(Callable[..., _T], func_call)),
-        )
-    finally:
-        executor.shutdown(wait=False)
+    # executor = ThreadPoolExecutor(max_workers=1, thread_name_prefix="sub_asyncio")
+    # try:
+    #     return cast(
+    #         "asyncio.Future[_T]",
+    #         loop.run_in_executor(executor, cast(Callable[..., _T], func_call)),
+    #     )
+    # finally:
+    #     executor.shutdown(wait=False)
 
 
 def run_coroutine_in_thread(
@@ -319,9 +318,12 @@ def run_coroutine_in_thread(
         return await inner_task
 
     def run(coro: Callable[..., Coroutine[Any, Any, _T]], *args: Any, **kwargs: Any) -> _T:
+        old_name = threading.current_thread().name
         threading.current_thread().name = coro.__qualname__
-
-        return asyncio.run(create_inner_task(coro, *args, **kwargs))
+        try:
+            return asyncio.run(create_inner_task(coro, *args, **kwargs))
+        finally:
+            threading.current_thread().name = old_name
 
     cti = get_current_future_info()
     result = run_in_thread(run, coro, *args, **kwargs)
@@ -350,8 +352,7 @@ class Event:
 
     def __init__(self, value: bool = False) -> None:
         self._waiters: Deque[asyncio.Future[Any]] = deque()
-        self._value = value
-        self._lock = threading.RLock()
+        self._value = [value]  # make value atomic according to GIL
 
     def __repr__(self) -> str:
         res = super().__repr__()
@@ -361,55 +362,51 @@ class Event:
         return f"<{res[1:-1]} [{extra}]>"
 
     def is_set(self) -> bool:
-        with self._lock:
-            return self._value
+        return self._value[0]
 
     def set(self) -> None:
-        with self._lock:
-            if not self._value:
-                self._value = True
+        if not self._value[0]:
+            self._value[0] = True
 
-                while self._waiters:
-                    fut = self._waiters.popleft()
+            while self._waiters:
+                fut = self._waiters.popleft()
 
-                    if not fut.done():
-                        if fut.get_loop() == asyncio.get_running_loop():
-                            if not fut.done():
-                                fut.set_result(True)
-                        else:
+                if not fut.done():
+                    if fut.get_loop() == asyncio.get_running_loop():
+                        if not fut.done():
+                            fut.set_result(True)
+                    else:
 
-                            def set_result(w: asyncio.Future[Any], ev: threading.Event) -> None:
-                                try:
-                                    if not w.done():
-                                        w.set_result(True)
-                                finally:
-                                    ev.set()
+                        def set_result(w: asyncio.Future[Any], ev: threading.Event) -> None:
+                            try:
+                                if not w.done():
+                                    w.set_result(True)
+                            finally:
+                                ev.set()
 
-                            done = threading.Event()
+                        done = threading.Event()
 
-                            fut.get_loop().call_soon_threadsafe(set_result, fut, done)
+                        fut.get_loop().call_soon_threadsafe(set_result, fut, done)
 
-                            start = time.monotonic()
-                            while not done.is_set():
-                                check_canceled_sync()
+                        start = time.monotonic()
+                        while not done.is_set():
+                            check_canceled_sync()
 
-                                if time.monotonic() - start > 120:
-                                    warnings.warn("Can't set future result.")
-                                    break
+                            if time.monotonic() - start > 120:
+                                warnings.warn("Can't set future result.")
+                                break
 
-                                time.sleep(0.001)
+                            time.sleep(0.001)
 
     def clear(self) -> None:
-        with self._lock:
-            self._value = False
+        self._value[0] = False
 
     async def wait(self, timeout: Optional[float] = None) -> bool:
-        with self._lock:
-            if self._value:
-                return True
+        if self._value[0]:
+            return True
 
-            fut = create_sub_future()
-            self._waiters.append(fut)
+        fut = create_sub_future()
+        self._waiters.append(fut)
 
         try:
             await asyncio.wait_for(fut, timeout)
@@ -423,8 +420,7 @@ class Lock:
 
     def __init__(self) -> None:
         self._waiters: Optional[Deque[asyncio.Future[Any]]] = None
-        self._locked = False
-        self._lock = threading.RLock()
+        self._locked = [False]  # make locked atomic according to GIL
         self._locker: Optional[asyncio.Task[Any]] = None
 
     async def __aenter__(self) -> None:
@@ -444,20 +440,23 @@ class Lock:
 
     @property
     def locked(self) -> bool:
-        return self._locked
+        return self._locked[0]
+
+    def _set_locked(self, value: bool) -> None:
+        self._locked[0] = value
+        self._locker = asyncio.current_task() if value else None
 
     async def acquire(self) -> bool:
-        with self._lock:
-            if not self._locked and (self._waiters is None or all(w.cancelled() for w in self._waiters)):
-                self._locked = True
-                self._locker = asyncio.current_task()
-                return True
+        if not self.locked and (self._waiters is None or all(w.cancelled() for w in self._waiters)):
+            self._set_locked(True)
 
-            if self._waiters is None:
-                self._waiters = deque()
+            return True
 
-            fut = create_sub_future()
-            self._waiters.append(fut)
+        if self._waiters is None:
+            self._waiters = deque()
+
+        fut = create_sub_future()
+        self._waiters.append(fut)
 
         try:
             try:
@@ -466,46 +465,37 @@ class Lock:
                     warnings.warn(f"Lock {self} takes to long {threading.current_thread()}\n, try to cancel...")
                     fut.cancel()
 
-                h = fut.get_loop().call_later(120, aaa, fut)
+                h = fut.get_loop().call_later(60, aaa, fut)
                 try:
                     await fut
                 finally:
                     h.cancel()
             finally:
-                with self._lock:
-                    self._waiters.remove(fut)
+                self._waiters.remove(fut)
         except asyncio.CancelledError:
-            with self._lock:
-                if not self._locked:
-                    self._wake_up_first()
-                raise
+            if not self.locked:
+                self._wake_up_first()
+            raise
 
-        with self._lock:
-            self._locked = True
-            self._locker = asyncio.current_task()
+        self._set_locked(True)
 
         return True
 
     def release(self) -> None:
-        with self._lock:
-            wake_up = False
-            if self._locked:
-                self._locked = False
-                self._locker = None
-                wake_up = True
-
-        if wake_up:
+        if self.locked:
+            self._set_locked(False)
             self._wake_up_first()
+        else:
+            raise RuntimeError("Lock is not acquired.")
 
     def _wake_up_first(self) -> None:
         if not self._waiters:
             return
 
-        with self._lock:
-            try:
-                fut = next(iter(self._waiters))
-            except StopIteration:
-                return
+        try:
+            fut = next(iter(self._waiters))
+        except StopIteration:
+            return
 
         if fut.get_loop().is_running() and not fut.get_loop().is_closed():
             if fut.get_loop() == asyncio.get_running_loop():
@@ -527,7 +517,6 @@ class Lock:
 
                     start = time.monotonic()
                     while not done.is_set():
-
                         if time.monotonic() - start > 120:
                             warnings.warn("Can't set future result.")
                             break
@@ -535,8 +524,7 @@ class Lock:
                         time.sleep(0.001)
         else:
             warnings.warn(f"Future {repr(fut)} loop is closed")
-            with self._lock:
-                self._waiters.remove(fut)
+            self._waiters.remove(fut)
             self._wake_up_first()
 
 
@@ -590,9 +578,14 @@ _running_tasks: weakref.WeakKeyDictionary[asyncio.Future[Any], FutureInfo] = wea
 
 
 def get_current_future_info() -> Optional[FutureInfo]:
-    ct = asyncio.current_task()
+    try:
+        ct = asyncio.current_task()
 
-    if ct is None:
+        if ct is None:
+            return None
+    except (SystemExit, KeyboardInterrupt):
+        raise
+    except BaseException:
         return None
 
     if ct not in _running_tasks:
@@ -604,7 +597,6 @@ def get_current_future_info() -> Optional[FutureInfo]:
 def create_sub_task(
     coro: Coroutine[Any, Any, _T], *, name: Optional[str] = None, loop: Optional[asyncio.AbstractEventLoop] = None
 ) -> asyncio.Task[_T]:
-
     ct = get_current_future_info()
 
     if loop is not None:
@@ -642,7 +634,6 @@ def create_delayed_sub_task(
 
 
 def create_sub_future(loop: Optional[asyncio.AbstractEventLoop] = None) -> asyncio.Future[Any]:
-
     ct = get_current_future_info()
 
     if loop is None:
