@@ -8,7 +8,18 @@ import os
 import reprlib
 import time
 from enum import Enum
-from typing import Any, Callable, List, Optional, Type, TypeVar, Union, cast, overload
+from typing import (
+    Any,
+    Callable,
+    ClassVar,
+    List,
+    Optional,
+    Type,
+    TypeVar,
+    Union,
+    cast,
+    overload,
+)
 
 __all__ = ["LoggingDescriptor"]
 
@@ -73,7 +84,7 @@ _FUNC_TYPE = Union[Callable[[], logging.Logger], Callable[[], None], staticmetho
 _F = TypeVar("_F", bound=Callable[..., Any])
 
 
-class LoggerException(Exception):
+class LoggerError(Exception):
     pass
 
 
@@ -90,7 +101,7 @@ logging.addLevelName(TRACE, "TRACE")
 class LoggingDescriptor:
     __func: _FUNC_TYPE = None
     __name: Optional[str] = None
-    __level: int = logging.NOTSET
+    __level: int = 0
     __owner: Any = None
     __owner_name: Optional[str] = None
     __postfix: str = ""
@@ -107,7 +118,7 @@ class LoggingDescriptor:
         self.__func = _func
 
         if _func is not None:
-            functools.update_wrapper(self, _func)  # type: ignore
+            functools.update_wrapper(self, cast(Callable[..., Any], _func))
 
         self.__name = name
         self.__level = level
@@ -118,9 +129,8 @@ class LoggingDescriptor:
             returned_logger = None
 
             if self.__func is not None:
-
                 if isinstance(self.__func, staticmethod):
-                    returned_logger = self.__func.__func__()
+                    returned_logger = self.__func.__func__()  # type: ignore
                 else:
                     returned_logger = self.__func()
 
@@ -154,7 +164,7 @@ class LoggingDescriptor:
             self.__init_logger()
 
         if self.__logger is None:
-            raise LoggerException("Logger not initialized")
+            raise LoggerError("Logger not initialized")
 
         return self.__logger
 
@@ -181,7 +191,7 @@ class LoggingDescriptor:
         **kwargs: Any,
     ) -> None:
         if self.is_enabled_for(level) and condition is not None and condition() or condition is None:
-            return self.logger.log(level, msg() if callable(msg) else msg, *args, stacklevel=stacklevel, **kwargs)
+            self.logger.log(level, msg() if callable(msg) else msg, *args, stacklevel=stacklevel, **kwargs)
 
     def debug(
         self,
@@ -257,16 +267,16 @@ class LoggingDescriptor:
                 stacklevel=stacklevel,
                 **kwargs,
             )
-        else:
-            return self.log(
-                logging.ERROR if level is None else level,
-                msg,
-                condition,
-                *args,
-                exc_info=exc_info,
-                stacklevel=stacklevel,
-                **kwargs,
-            )
+
+        return self.log(
+            logging.ERROR if level is None else level,
+            msg,
+            condition,
+            *args,
+            exc_info=exc_info,
+            stacklevel=stacklevel,
+            **kwargs,
+        )
 
     def critical(
         self,
@@ -299,10 +309,10 @@ class LoggingDescriptor:
         level = logging.getLevelName(logger.getEffectiveLevel())
         return f"{self.__class__.__name__}(name={repr(logger.name)}, level={repr(level)})"
 
-    _call_tracing_enabled = (
+    _call_tracing_enabled: ClassVar = (
         "ROBOT_CALL_TRACING_ENABLED" in os.environ and os.environ["ROBOT_CALL_TRACING_ENABLED"] != "0"
     )
-    _call_tracing_default_level = (
+    _call_tracing_default_level: ClassVar = (
         logging.getLevelName(os.environ["ROBOT_CALL_TRACING_LEVEL"])
         if "ROBOT_CALL_TRACING_LEVEL" in os.environ
         else TRACE
@@ -347,7 +357,6 @@ class LoggingDescriptor:
         timed: bool = False,
         **kwargs: Any,
     ) -> Callable[[_F], _F]:
-
         if level is None:
             level = type(self)._call_tracing_default_level
 
@@ -370,7 +379,6 @@ class LoggingDescriptor:
 
             @functools.wraps(func)
             def _wrapper(*wrapper_args: Any, **wrapper_kwargs: Any) -> Any:
-
                 if isinstance(unwrapped_func, staticmethod):
                     real_args = wrapper_args[1:]
                     real_func = unwrapped_func.__func__
@@ -388,12 +396,12 @@ class LoggingDescriptor:
                             if self.__owner or self.__name is None
                             else unwrapped_func.__func__.__name__
                         )
-                    else:
-                        return (
-                            str(unwrapped_func.__qualname__)
-                            if self.__owner is None or self.__name
-                            else str(unwrapped_func.__name__)
-                        )
+
+                    return (
+                        str(unwrapped_func.__qualname__)
+                        if self.__owner is None or self.__name
+                        else str(unwrapped_func.__name__)
+                    )
 
                 def _log(
                     message: Callable[[], str],
